/* $TOG: XmStrDefs.ht /main/2 1997/06/18 17:50:15 samborn $ */
#ifndef _XmStrDefs_h_
#define _XmStrDefs_h_

#include <X11/Intrinsic.h>

#ifndef _XmConst
#define _XmConst /**/
#endif

#ifdef __cplusplus
extern "C" {
#endif

/* $TOG: makestrs.c /main/11 1998/02/06 11:24:15 kaleb $ */
/* This file is automatically generated. */
/* Default ABI version -- Do not edit */
/* TOG: xmstring.list /main/5 1997/06/20 08:37:02 samborn */

#ifdef XMSTRINGDEFINES
#define XmS ""
#define XmCAccelerator "Accelerator"
#define XmCAcceleratorText "AcceleratorText"
#define XmCAdjustLast "AdjustLast"
#define XmCAdjustMargin "AdjustMargin"
#define XmCAlignment "Alignment"
#define XmCAllowOverlap "AllowOverlap"
#define XmCAllowUnusedSpace "AllowUnusedSpace"
#define XmCAnimationMask "AnimationMask"
#define XmCAnimationPixmap "AnimationPixmap"
#define XmCAnimationPixmapDepth "AnimationPixmapDepth"
#define XmCAnimationStyle "AnimationStyle"
#define XmCApplyLabelString "ApplyLabelString"
#define XmCArmCallback "ArmCallback"
#define XmCArmColor "ArmColor"
#define XmCArmPixmap "ArmPixmap"
#define XmCArrowDirection "ArrowDirection"
#define XmCAttachment "Attachment"
#define XmCAudibleWarning "AudibleWarning"
#define XmCAutoShowCursorPosition "AutoShowCursorPosition"
#define XmCAutoUnmanage "AutoUnmanage"
#define XmCAutomaticSelection "AutomaticSelection"
#define XmCAvailability "Availability"
#define XmCBackgroundPixmap "BackgroundPixmap"
#define XmCBlendModel "BlendModel"
#define XmCBlinkRate "BlinkRate"
#define XmCBottomShadowColor "BottomShadowColor"
#define XmCBottomShadowPixmap "BottomShadowPixmap"
#define XmCButtonAcceleratorText "ButtonAcceleratorText"
#define XmCButtonAccelerators "ButtonAccelerators"
#define XmCButtonCount "ButtonCount"
#define XmCButtonFontList "ButtonFontList"
#define XmCButtonMnemonicCharSets "ButtonMnemonicCharSets"
#define XmCButtonMnemonics "ButtonMnemonics"
#define XmCButtonSet "ButtonSet"
#define XmCButtonType "ButtonType"
#define XmCButtons "Buttons"
#define XmCCancelLabelString "CancelLabelString"
#define XmCChildHorizontalAlignment "ChildHorizontalAlignment"
#define XmCChildHorizontalSpacing "ChildHorizontalSpacing"
#define XmCChildPlacement "ChildPlacement"
#define XmCChildType "ChildType"
#define XmCChildVerticalAlignment "ChildVerticalAlignment"
#define XmCChildren "Children"
#define XmCClientData "ClientData"
#define XmCClipWindow "ClipWindow"
#define XmCColumns "Columns"
#define XmCCommandWindow "CommandWindow"
#define XmCCommandWindowLocation "CommandWindowLocation"
#define XmCConvertProc "ConvertProc"
#define XmCCursorBackground "CursorBackground"
#define XmCCursorForeground "CursorForeground"
#define XmCCursorPosition "CursorPosition"
#define XmCCursorPositionVisible "CursorPositionVisible"
#define XmCDarkThreshold "DarkThreshold"
#define XmCDecimalPoints "DecimalPoints"
#define XmCDefaultButtonShadowThickness "DefaultButtonShadowThickness"
#define XmCDefaultButtonType "DefaultButtonType"
#define XmCDefaultCopyCursorIcon "DefaultCopyCursorIcon"
#define XmCDefaultFontList "DefaultFontList"
#define XmCDefaultInvalidCursorIcon "DefaultInvalidCursorIcon"
#define XmCDefaultLinkCursorIcon "DefaultLinkCursorIcon"
#define XmCDefaultMoveCursorIcon "DefaultMoveCursorIcon"
#define XmCDefaultNoneCursorIcon "DefaultNoneCursorIcon"
#define XmCDefaultPosition "DefaultPosition"
#define XmCDefaultSourceCursorIcon "DefaultSourceCursorIcon"
#define XmCDefaultValidCursorIcon "DefaultValidCursorIcon"
#define XmCDeleteResponse "DeleteResponse"
#define XmCDesktopParent "DesktopParent"
#define XmCDialogStyle "DialogStyle"
#define XmCDialogTitle "DialogTitle"
#define XmCDialogType "DialogType"
#define XmCDirListItemCount "DirListItemCount"
#define XmCDirListItems "DirListItems"
#define XmCDirListLabelString "DirListLabelString"
#define XmCDirMask "DirMask"
#define XmCDirSearchProc "DirSearchProc"
#define XmCDirSpec "DirSpec"
#define XmCDirectory "Directory"
#define XmCDirectoryValid "DirectoryValid"
#define XmCDisarmCallback "DisarmCallback"
#define XmCDoubleClickInterval "DoubleClickInterval"
#define XmCDragContextClass "DragContextClass"
#define XmCDragDropFinishCallback "DragDropFinishCallback"
#define XmCDragIconClass "DragIconClass"
#define XmCDragInitiatorProtocolStyle "DragInitiatorProtocolStyle"
#define XmCDragMotionCallback "DragMotionCallback"
#define XmCDragOperations "DragOperations"
#define XmCDragOverMode "DragOverMode"
#define XmCDragProc "DragProc"
#define XmCDragReceiverProtocolStyle "DragReceiverProtocolStyle"
#define XmCDropProc "DropProc"
#define XmCDropRectangles "DropRectangles"
#define XmCDropSiteActivity "DropSiteActivity"
#define XmCDropSiteEnterCallback "DropSiteEnterCallback"
#define XmCDropSiteLeaveCallback "DropSiteLeaveCallback"
#define XmCDropSiteManagerClass "DropSiteManagerClass"
#define XmCDropSiteOperations "DropSiteOperations"
#define XmCDropSiteType "DropSiteType"
#define XmCDropStartCallback "DropStartCallback"
#define XmCDropTransferClass "DropTransferClass"
#define XmCDropTransfers "DropTransfers"
#define XmCEditable "Editable"
#define XmCEntryBorder "EntryBorder"
#define XmCEntryClass "EntryClass"
#define XmCExportTargets "ExportTargets"
#define XmCExposeCallback "ExposeCallback"
#define XmCExtensionType "ExtensionType"
#define XmCFileListItemCount "FileListItemCount"
#define XmCFileListItems "FileListItems"
#define XmCFileListLabelString "FileListLabelString"
#define XmCFileSearchProc "FileSearchProc"
#define XmCFileTypeMask "FileTypeMask"
#define XmCFillOnArm "FillOnArm"
#define XmCFillOnSelect "FillOnSelect"
#define XmCFilterLabelString "FilterLabelString"
#define XmCFontList "FontList"
#define XmCForegroundThreshold "ForegroundThreshold"
#define XmCHelpLabelString "HelpLabelString"
#define XmCHighlightColor "HighlightColor"
#define XmCHighlightOnEnter "HighlightOnEnter"
#define XmCHighlightPixmap "HighlightPixmap"
#define XmCHighlightThickness "HighlightThickness"
#define XmCHorizontalFontUnit "HorizontalFontUnit"
#define XmCHorizontalScrollBar "HorizontalScrollBar"
#define XmCHot "Hot"
#define XmCICCHandle "ICCHandle"
#define XmCImportTargets "ImportTargets"
#define XmCIncrement "Increment"
#define XmCIncremental "Incremental"
#define XmCIndicatorOn "IndicatorOn"
#define XmCIndicatorSize "IndicatorSize"
#define XmCIndicatorType "IndicatorType"
#define XmCInitialDelay "InitialDelay"
#define XmCInitialFocus "InitialFocus"
#define XmCInputCreate "InputCreate"
#define XmCInputMethod "InputMethod"
#define XmCInvalidCursorForeground "InvalidCursorForeground"
#define XmCIsAligned "IsAligned"
#define XmCIsHomogeneous "IsHomogeneous"
#define XmCItemCount "ItemCount"
#define XmCItems "Items"
#define XmCKeyboardFocusPolicy "KeyboardFocusPolicy"
#define XmCLabelFontList "LabelFontList"
#define XmCLabelInsensitivePixmap "LabelInsensitivePixmap"
#define XmCLabelPixmap "LabelPixmap"
#define XmCLabelString "LabelString"
#define XmCLabelType "LabelType"
#define XmCLightThreshold "LightThreshold"
#define XmCListLabelString "ListLabelString"
#define XmCListMarginHeight "ListMarginHeight"
#define XmCListMarginWidth "ListMarginWidth"
#define XmCListSizePolicy "ListSizePolicy"
#define XmCListSpacing "ListSpacing"
#define XmCListUpdated "ListUpdated"
#define XmCLogicalParent "LogicalParent"
#define XmCMainWindowMarginHeight "MainWindowMarginHeight"
#define XmCMainWindowMarginWidth "MainWindowMarginWidth"
#define XmCMappingDelay "MappingDelay"
#define XmCMarginBottom "MarginBottom"
#define XmCMarginHeight "MarginHeight"
#define XmCMarginLeft "MarginLeft"
#define XmCMarginRight "MarginRight"
#define XmCMarginTop "MarginTop"
#define XmCMarginWidth "MarginWidth"
#define XmCMask "Mask"
#define XmCMaxItems "MaxItems"
#define XmCMaxLength "MaxLength"
#define XmCMaxValue "MaxValue"
#define XmCMaximum "Maximum"
#define XmCMenuBar "MenuBar"
#define XmCMenuPost "MenuPost"
#define XmCMenuWidget "MenuWidget"
#define XmCMessageProc "MessageProc"
#define XmCMessageWindow "MessageWindow"
#define XmCMinimizeButtons "MinimizeButtons"
#define XmCMinimum "Minimum"
#define XmCMnemonic "Mnemonic"
#define XmCMnemonicCharSet "MnemonicCharSet"
#define XmCMoveOpaque "MoveOpaque"
#define XmCMultiClick "MultiClick"
#define XmCMustMatch "MustMatch"
#define XmCMwmDecorations "MwmDecorations"
#define XmCMwmFunctions "MwmFunctions"
#define XmCMwmInputMode "MwmInputMode"
#define XmCMwmMenu "MwmMenu"
#define XmCMwmMessages "MwmMessages"
#define XmCNavigationType "NavigationType"
#define XmCNeedsMotion "NeedsMotion"
#define XmCNoMatchString "NoMatchString"
#define XmCNoResize "NoResize"
#define XmCNoneCursorForeground "NoneCursorForeground"
#define XmCNotifyProc "NotifyProc"
#define XmCNumChildren "NumChildren"
#define XmCNumColumns "NumColumns"
#define XmCNumDropRectangles "NumDropRectangles"
#define XmCNumDropTransfers "NumDropTransfers"
#define XmCNumExportTargets "NumExportTargets"
#define XmCNumImportTargets "NumImportTargets"
#define XmCOffset "Offset"
#define XmCOkLabelString "OkLabelString"
#define XmCOperationChangedCallback "OperationChangedCallback"
#define XmCOperationCursorIcon "OperationCursorIcon"
#define XmCOptionLabel "OptionLabel"
#define XmCOptionMnemonic "OptionMnemonic"
#define XmCOutputCreate "OutputCreate"
#define XmCPacking "Packing"
#define XmCPageIncrement "PageIncrement"
#define XmCPaneMaximum "PaneMaximum"
#define XmCPaneMinimum "PaneMinimum"
#define XmCPattern "Pattern"
#define XmCPendingDelete "PendingDelete"
#define XmCPopupEnabled "PopupEnabled"
#define XmCPositionIndex "PositionIndex"
#define XmCPostFromButton "PostFromButton"
#define XmCPostFromCount "PostFromCount"
#define XmCPostFromList "PostFromList"
#define XmCPreeditType "PreeditType"
#define XmCProcessingDirection "ProcessingDirection"
#define XmCPromptString "PromptString"
#define XmCProtocolCallback "ProtocolCallback"
#define XmCPushButtonEnabled "PushButtonEnabled"
#define XmCQualifySearchDataProc "QualifySearchDataProc"
#define XmCRadioAlwaysOne "RadioAlwaysOne"
#define XmCRadioBehavior "RadioBehavior"
#define XmCRecomputeSize "RecomputeSize"
#define XmCRectangles "Rectangles"
#define XmCRepeatDelay "RepeatDelay"
#define XmCResizeCallback "ResizeCallback"
#define XmCResizeHeight "ResizeHeight"
#define XmCResizePolicy "ResizePolicy"
#define XmCResizeWidth "ResizeWidth"
#define XmCRowColumnType "RowColumnType"
#define XmCRows "Rows"
#define XmCRubberPositioning "RubberPositioning"
#define XmCSashHeight "SashHeight"
#define XmCSashIndent "SashIndent"
#define XmCSashWidth "SashWidth"
#define XmCScaleHeight "ScaleHeight"
#define XmCScaleMultiple "ScaleMultiple"
#define XmCScaleWidth "ScaleWidth"
#define XmCScroll "Scroll"
#define XmCScrollBarDisplayPolicy "ScrollBarDisplayPolicy"
#define XmCScrollBarPlacement "ScrollBarPlacement"
#define XmCScrollSide "ScrollSide"
#define XmCScrolledWindowMarginHeight "ScrolledWindowMarginHeight"
#define XmCScrolledWindowMarginWidth "ScrolledWindowMarginWidth"
#define XmCScrollingPolicy "ScrollingPolicy"
#define XmCSelectColor "SelectColor"
#define XmCSelectInsensitivePixmap "SelectInsensitivePixmap"
#define XmCSelectPixmap "SelectPixmap"
#define XmCSelectThreshold "SelectThreshold"
#define XmCSelectedItemCount "SelectedItemCount"
#define XmCSelectedItems "SelectedItems"
#define XmCSelectionArrayCount "SelectionArrayCount"
#define XmCSelectionLabelString "SelectionLabelString"
#define XmCSelectionPolicy "SelectionPolicy"
#define XmCSeparatorOn "SeparatorOn"
#define XmCSeparatorType "SeparatorType"
#define XmCSet "Set"
#define XmCShadowThickness "ShadowThickness"
#define XmCShadowType "ShadowType"
#define XmCShellUnitType "ShellUnitType"
#define XmCShowArrows "ShowArrows"
#define XmCShowAsDefault "ShowAsDefault"
#define XmCShowSeparator "ShowSeparator"
#define XmCShowValue "ShowValue"
#define XmCSimpleCheckBox "SimpleCheckBox"
#define XmCSimpleMenuBar "SimpleMenuBar"
#define XmCSimpleOptionMenu "SimpleOptionMenu"
#define XmCSimplePopupMenu "SimplePopupMenu"
#define XmCSimplePulldownMenu "SimplePulldownMenu"
#define XmCSimpleRadioBox "SimpleRadioBox"
#define XmCSizePolicy "SizePolicy"
#define XmCSliderSize "SliderSize"
#define XmCSource "Source"
#define XmCSourceCursorIcon "SourceCursorIcon"
#define XmCSourceIsExternal "SourceIsExternal"
#define XmCSourcePixmapIcon "SourcePixmapIcon"
#define XmCSourceWidget "SourceWidget"
#define XmCSourceWindow "SourceWindow"
#define XmCSpacing "Spacing"
#define XmCStartTime "StartTime"
#define XmCStateCursorIcon "StateCursorIcon"
#define XmCStringDirection "StringDirection"
#define XmCTearOffModel "TearOffModel"
#define XmCTextFontList "TextFontList"
#define XmCTextString "TextString"
#define XmCTextValue "TextValue"
#define XmCTitleString "TitleString"
#define XmCTopCharacter "TopCharacter"
#define XmCTopItemPosition "TopItemPosition"
#define XmCTopLevelEnterCallback "TopLevelEnterCallback"
#define XmCTopLevelLeaveCallback "TopLevelLeaveCallback"
#define XmCTopShadowColor "TopShadowColor"
#define XmCTopShadowPixmap "TopShadowPixmap"
#define XmCTransferProc "TransferProc"
#define XmCTransferStatus "TransferStatus"
#define XmCTraversalOn "TraversalOn"
#define XmCTraversalType "TraversalType"
#define XmCTreeUpdateProc "TreeUpdateProc"
#define XmCTroughColor "TroughColor"
#define XmCUnitType "UnitType"
#define XmCUnpostBehavior "UnpostBehavior"
#define XmCUnselectPixmap "UnselectPixmap"
#define XmCUpdateSliderSize "UpdateSliderSize"
#define XmCUseAsyncGeometry "UseAsyncGeometry"
#define XmCUserData "UserData"
#define XmCValidCursorForeground "ValidCursorForeground"
#define XmCValueChangedCallback "ValueChangedCallback"
#define XmCValueWcs "ValueWcs"
#define XmCVerifyBell "VerifyBell"
#define XmCVerticalAlignment "VerticalAlignment"
#define XmCVerticalFontUnit "VerticalFontUnit"
#define XmCVerticalScrollBar "VerticalScrollBar"
#define XmCVisibleItemCount "VisibleItemCount"
#define XmCVisibleWhenOff "VisibleWhenOff"
#define XmCVisualPolicy "VisualPolicy"
#define XmCWhichButton "WhichButton"
#define XmCWordWrap "WordWrap"
#define XmCWorkWindow "WorkWindow"
#define XmCXmString "XmString"
#define XmNaccelerator "accelerator"
#define XmNacceleratorText "acceleratorText"
#define XmNactivateCallback "activateCallback"
#define XmNadjustLast "adjustLast"
#define XmNadjustMargin "adjustMargin"
#define XmNalignment "alignment"
#define XmNallowOverlap "allowOverlap"
#define XmNallowResize "allowResize"
#define XmNallowUnusedSpace "allowUnusedSpace"
#define XmNanimationMask "animationMask"
#define XmNanimationPixmap "animationPixmap"
#define XmNanimationPixmapDepth "animationPixmapDepth"
#define XmNanimationStyle "animationStyle"
#define XmNapplyCallback "applyCallback"
#define XmNapplyLabelString "applyLabelString"
#define XmNarmCallback "armCallback"
#define XmNarmColor "armColor"
#define XmNarmPixmap "armPixmap"
#define XmNarrowDirection "arrowDirection"
#define XmNattachment "attachment"
#define XmNaudibleWarning "audibleWarning"
#define XmNautoShowCursorPosition "autoShowCursorPosition"
#define XmNautoUnmanage "autoUnmanage"
#define XmNautomaticSelection "automaticSelection"
#define XmNavailability "availability"
#define XmNblendModel "blendModel"
#define XmNblinkRate "blinkRate"
#define XmNbottomAttachment "bottomAttachment"
#define XmNbottomOffset "bottomOffset"
#define XmNbottomPosition "bottomPosition"
#define XmNbottomShadowColor "bottomShadowColor"
#define XmNbottomShadowPixmap "bottomShadowPixmap"
#define XmNbottomWidget "bottomWidget"
#define XmNbrowseSelectionCallback "browseSelectionCallback"
#define XmNbuttonAcceleratorText "buttonAcceleratorText"
#define XmNbuttonAccelerators "buttonAccelerators"
#define XmNbuttonCount "buttonCount"
#define XmNbuttonFontList "buttonFontList"
#define XmNbuttonMnemonicCharSets "buttonMnemonicCharSets"
#define XmNbuttonMnemonics "buttonMnemonics"
#define XmNbuttonSet "buttonSet"
#define XmNbuttonType "buttonType"
#define XmNbuttons "buttons"
#define XmNcancelButton "cancelButton"
#define XmNcancelCallback "cancelCallback"
#define XmNcancelLabelString "cancelLabelString"
#define XmNcascadePixmap "cascadePixmap"
#define XmNcascadingCallback "cascadingCallback"
#define XmNchildHorizontalAlignment "childHorizontalAlignment"
#define XmNchildHorizontalSpacing "childHorizontalSpacing"
#define XmNchildPlacement "childPlacement"
#define XmNchildPosition "childPosition"
#define XmNchildType "childType"
#define XmNchildVerticalAlignment "childVerticalAlignment"
#define XmNclientData "clientData"
#define XmNclipWindow "clipWindow"
#define XmNcolumns "columns"
#define XmNcommand "command"
#define XmNcommandChangedCallback "commandChangedCallback"
#define XmNcommandEnteredCallback "commandEnteredCallback"
#define XmNcommandWindow "commandWindow"
#define XmNcommandWindowLocation "commandWindowLocation"
#define XmNconvertProc "convertProc"
#define XmNcursorBackground "cursorBackground"
#define XmNcursorForeground "cursorForeground"
#define XmNcursorPosition "cursorPosition"
#define XmNcursorPositionVisible "cursorPositionVisible"
#define XmNdarkThreshold "darkThreshold"
#define XmNdecimalPoints "decimalPoints"
#define XmNdecrementCallback "decrementCallback"
#define XmNdefaultActionCallback "defaultActionCallback"
#define XmNdefaultButton "defaultButton"
#define XmNdefaultButtonShadowThickness "defaultButtonShadowThickness"
#define XmNdefaultButtonType "defaultButtonType"
#define XmNdefaultCopyCursorIcon "defaultCopyCursorIcon"
#define XmNdefaultFontList "defaultFontList"
#define XmNdefaultInvalidCursorIcon "defaultInvalidCursorIcon"
#define XmNdefaultLinkCursorIcon "defaultLinkCursorIcon"
#define XmNdefaultMoveCursorIcon "defaultMoveCursorIcon"
#define XmNdefaultNoneCursorIcon "defaultNoneCursorIcon"
#define XmNdefaultPosition "defaultPosition"
#define XmNdefaultSourceCursorIcon "defaultSourceCursorIcon"
#define XmNdefaultValidCursorIcon "defaultValidCursorIcon"
#define XmNdeleteResponse "deleteResponse"
#define XmNdesktopParent "desktopParent"
#define XmNdialogStyle "dialogStyle"
#define XmNdialogTitle "dialogTitle"
#define XmNdialogType "dialogType"
#define XmNdirListItemCount "dirListItemCount"
#define XmNdirListItems "dirListItems"
#define XmNdirListLabelString "dirListLabelString"
#define XmNdirMask "dirMask"
#define XmNdirSearchProc "dirSearchProc"
#define XmNdirSpec "dirSpec"
#define XmNdirectory "directory"
#define XmNdirectoryValid "directoryValid"
#define XmNdisarmCallback "disarmCallback"
#define XmNdoubleClickInterval "doubleClickInterval"
#define XmNdragCallback "dragCallback"
#define XmNdragContextClass "dragContextClass"
#define XmNdragDropFinishCallback "dragDropFinishCallback"
#define XmNdragIconClass "dragIconClass"
#define XmNdragInitiatorProtocolStyle "dragInitiatorProtocolStyle"
#define XmNdragMotionCallback "dragMotionCallback"
#define XmNdragOperations "dragOperations"
#define XmNdragOverMode "dragOverMode"
#define XmNdragProc "dragProc"
#define XmNdragReceiverProtocolStyle "dragReceiverProtocolStyle"
#define XmNdropFinishCallback "dropFinishCallback"
#define XmNdropProc "dropProc"
#define XmNdropRectangles "dropRectangles"
#define XmNdropSiteActivity "dropSiteActivity"
#define XmNdropSiteEnterCallback "dropSiteEnterCallback"
#define XmNdropSiteLeaveCallback "dropSiteLeaveCallback"
#define XmNdropSiteManagerClass "dropSiteManagerClass"
#define XmNdropSiteOperations "dropSiteOperations"
#define XmNdropSiteType "dropSiteType"
#define XmNdropStartCallback "dropStartCallback"
#define XmNdropTransferClass "dropTransferClass"
#define XmNdropTransfers "dropTransfers"
#define XmNeditMode "editMode"
#define XmNeditable "editable"
#define XmNentryAlignment "entryAlignment"
#define XmNentryBorder "entryBorder"
#define XmNentryCallback "entryCallback"
#define XmNentryClass "entryClass"
#define XmNentryVerticalAlignment "entryVerticalAlignment"
#define XmNexportTargets "exportTargets"
#define XmNexposeCallback "exposeCallback"
#define XmNextendedSelectionCallback "extendedSelectionCallback"
#define XmNextensionType "extensionType"
#define XmNfileListItemCount "fileListItemCount"
#define XmNfileListItems "fileListItems"
#define XmNfileListLabelString "fileListLabelString"
#define XmNfileSearchProc "fileSearchProc"
#define XmNfileTypeMask "fileTypeMask"
#define XmNfillOnArm "fillOnArm"
#define XmNfillOnSelect "fillOnSelect"
#define XmNfilterLabelString "filterLabelString"
#define XmNfocusCallback "focusCallback"
#define XmNfocusMovedCallback "focusMovedCallback"
#define XmNfocusPolicyChanged "focusPolicyChanged"
#define XmNfontList "fontList"
#define XmNforegroundThreshold "foregroundThreshold"
#define XmNfractionBase "fractionBase"
#define XmNgainPrimaryCallback "gainPrimaryCallback"
#define XmNhelpCallback "helpCallback"
#define XmNhelpLabelString "helpLabelString"
#define XmNhighlightColor "highlightColor"
#define XmNhighlightOnEnter "highlightOnEnter"
#define XmNhighlightPixmap "highlightPixmap"
#define XmNhighlightThickness "highlightThickness"
#define XmNhistoryItemCount "historyItemCount"
#define XmNhistoryItems "historyItems"
#define XmNhistoryMaxItems "historyMaxItems"
#define XmNhistoryVisibleItemCount "historyVisibleItemCount"
#define XmNhorizontalFontUnit "horizontalFontUnit"
#define XmNhorizontalScrollBar "horizontalScrollBar"
#define XmNhorizontalSpacing "horizontalSpacing"
#define XmNhotX "hotX"
#define XmNhotY "hotY"
#define XmNiccHandle "iccHandle"
#define XmNimportTargets "importTargets"
#define XmNincrement "increment"
#define XmNincrementCallback "incrementCallback"
#define XmNincremental "incremental"
#define XmNindicatorOn "indicatorOn"
#define XmNindicatorSize "indicatorSize"
#define XmNindicatorType "indicatorType"
#define XmNinitialDelay "initialDelay"
#define XmNinitialFocus "initialFocus"
#define XmNinputCallback "inputCallback"
#define XmNinputCreate "inputCreate"
#define XmNinputMethod "inputMethod"
#define XmNinvalidCursorForeground "invalidCursorForeground"
#define XmNisAligned "isAligned"
#define XmNisHomogeneous "isHomogeneous"
#define XmNitemCount "itemCount"
#define XmNitems "items"
#define XmNkeyboardFocusPolicy "keyboardFocusPolicy"
#define XmNlabelFontList "labelFontList"
#define XmNlabelInsensitivePixmap "labelInsensitivePixmap"
#define XmNlabelPixmap "labelPixmap"
#define XmNlabelString "labelString"
#define XmNlabelType "labelType"
#define XmNleftAttachment "leftAttachment"
#define XmNleftOffset "leftOffset"
#define XmNleftPosition "leftPosition"
#define XmNleftWidget "leftWidget"
#define XmNlightThreshold "lightThreshold"
#define XmNlineSpace "lineSpace"
#define XmNlistItemCount "listItemCount"
#define XmNlistItems "listItems"
#define XmNlistLabelString "listLabelString"
#define XmNlistMarginHeight "listMarginHeight"
#define XmNlistMarginWidth "listMarginWidth"
#define XmNlistSizePolicy "listSizePolicy"
#define XmNlistSpacing "listSpacing"
#define XmNlistUpdated "listUpdated"
#define XmNlistVisibleItemCount "listVisibleItemCount"
#define XmNlogicalParent "logicalParent"
#define XmNlosePrimaryCallback "losePrimaryCallback"
#define XmNlosingFocusCallback "losingFocusCallback"
#define XmNmainWindowMarginHeight "mainWindowMarginHeight"
#define XmNmainWindowMarginWidth "mainWindowMarginWidth"
#define XmNmapCallback "mapCallback"
#define XmNmappingDelay "mappingDelay"
#define XmNmargin "margin"
#define XmNmarginBottom "marginBottom"
#define XmNmarginHeight "marginHeight"
#define XmNmarginLeft "marginLeft"
#define XmNmarginRight "marginRight"
#define XmNmarginTop "marginTop"
#define XmNmarginWidth "marginWidth"
#define XmNmask "mask"
#define XmNmaxLength "maxLength"
#define XmNmaximum "maximum"
#define XmNmenuAccelerator "menuAccelerator"
#define XmNmenuBar "menuBar"
#define XmNmenuCursor "menuCursor"
#define XmNmenuHelpWidget "menuHelpWidget"
#define XmNmenuHistory "menuHistory"
#define XmNmenuPost "menuPost"
#define XmNmessageAlignment "messageAlignment"
#define XmNmessageProc "messageProc"
#define XmNmessageString "messageString"
#define XmNmessageWindow "messageWindow"
#define XmNminimizeButtons "minimizeButtons"
#define XmNminimum "minimum"
#define XmNmnemonic "mnemonic"
#define XmNmnemonicCharSet "mnemonicCharSet"
#define XmNmodifyVerifyCallback "modifyVerifyCallback"
#define XmNmodifyVerifyCallbackWcs "modifyVerifyCallbackWcs"
#define XmNmotionVerifyCallback "motionVerifyCallback"
#define XmNmoveOpaque "moveOpaque"
#define XmNmultiClick "multiClick"
#define XmNmultipleSelectionCallback "multipleSelectionCallback"
#define XmNmustMatch "mustMatch"
#define XmNmwmDecorations "mwmDecorations"
#define XmNmwmFunctions "mwmFunctions"
#define XmNmwmInputMode "mwmInputMode"
#define XmNmwmMenu "mwmMenu"
#define XmNmwmMessages "mwmMessages"
#define XmNnavigationType "navigationType"
#define XmNneedsMotion "needsMotion"
#define XmNnoMatchCallback "noMatchCallback"
#define XmNnoMatchString "noMatchString"
#define XmNnoResize "noResize"
#define XmNnoneCursorForeground "noneCursorForeground"
#define XmNnotifyProc "notifyProc"
#define XmNnumColumns "numColumns"
#define XmNnumDropRectangles "numDropRectangles"
#define XmNnumDropTransfers "numDropTransfers"
#define XmNnumExportTargets "numExportTargets"
#define XmNnumImportTargets "numImportTargets"
#define XmNnumRectangles "numRectangles"
#define XmNoffsetX "offsetX"
#define XmNoffsetY "offsetY"
#define XmNokCallback "okCallback"
#define XmNokLabelString "okLabelString"
#define XmNoperationChangedCallback "operationChangedCallback"
#define XmNoperationCursorIcon "operationCursorIcon"
#define XmNoptionLabel "optionLabel"
#define XmNoptionMnemonic "optionMnemonic"
#define XmNoutputCreate "outputCreate"
#define XmNpacking "packing"
#define XmNpageDecrementCallback "pageDecrementCallback"
#define XmNpageIncrement "pageIncrement"
#define XmNpageIncrementCallback "pageIncrementCallback"
#define XmNpaneMaximum "paneMaximum"
#define XmNpaneMinimum "paneMinimum"
#define XmNpattern "pattern"
#define XmNpendingDelete "pendingDelete"
#define XmNpopupEnabled "popupEnabled"
#define XmNpositionIndex "positionIndex"
#define XmNpostFromButton "postFromButton"
#define XmNpostFromCount "postFromCount"
#define XmNpostFromList "postFromList"
#define XmNpreeditType "preeditType"
#define XmNprocessingDirection "processingDirection"
#define XmNpromptString "promptString"
#define XmNprotocolCallback "protocolCallback"
#define XmNpushButtonEnabled "pushButtonEnabled"
#define XmNqualifySearchDataProc "qualifySearchDataProc"
#define XmNradioAlwaysOne "radioAlwaysOne"
#define XmNradioBehavior "radioBehavior"
#define XmNrealizeCallback "realizeCallback"
#define XmNrecomputeSize "recomputeSize"
#define XmNrectangles "rectangles"
#define XmNrefigureMode "refigureMode"
#define XmNrepeatDelay "repeatDelay"
#define XmNresizable "resizable"
#define XmNresizeCallback "resizeCallback"
#define XmNresizeHeight "resizeHeight"
#define XmNresizePolicy "resizePolicy"
#define XmNresizeWidth "resizeWidth"
#define XmNrightAttachment "rightAttachment"
#define XmNrightOffset "rightOffset"
#define XmNrightPosition "rightPosition"
#define XmNrightWidget "rightWidget"
#define XmNrowColumnType "rowColumnType"
#define XmNrows "rows"
#define XmNrubberPositioning "rubberPositioning"
#define XmNsashHeight "sashHeight"
#define XmNsashIndent "sashIndent"
#define XmNsashShadowThickness "sashShadowThickness"
#define XmNsashWidth "sashWidth"
#define XmNscaleHeight "scaleHeight"
#define XmNscaleMultiple "scaleMultiple"
#define XmNscaleWidth "scaleWidth"
#define XmNscrollBarDisplayPolicy "scrollBarDisplayPolicy"
#define XmNscrollBarPlacement "scrollBarPlacement"
#define XmNscrollHorizontal "scrollHorizontal"
#define XmNscrollLeftSide "scrollLeftSide"
#define XmNscrollTopSide "scrollTopSide"
#define XmNscrollVertical "scrollVertical"
#define XmNscrolledWindowMarginHeight "scrolledWindowMarginHeight"
#define XmNscrolledWindowMarginWidth "scrolledWindowMarginWidth"
#define XmNscrollingPolicy "scrollingPolicy"
#define XmNselectColor "selectColor"
#define XmNselectInsensitivePixmap "selectInsensitivePixmap"
#define XmNselectPixmap "selectPixmap"
#define XmNselectThreshold "selectThreshold"
#define XmNselectedItemCount "selectedItemCount"
#define XmNselectedItems "selectedItems"
#define XmNselectionArrayCount "selectionArrayCount"
#define XmNselectionLabelString "selectionLabelString"
#define XmNselectionPolicy "selectionPolicy"
#define XmNseparatorOn "separatorOn"
#define XmNseparatorType "separatorType"
#define XmNset "set"
#define XmNshadow "shadow"
#define XmNshadowThickness "shadowThickness"
#define XmNshadowType "shadowType"
#define XmNshellUnitType "shellUnitType"
#define XmNshowArrows "showArrows"
#define XmNshowAsDefault "showAsDefault"
#define XmNshowSeparator "showSeparator"
#define XmNshowValue "showValue"
#define XmNsimpleCallback "simpleCallback"
#define XmNsingleSelectionCallback "singleSelectionCallback"
#define XmNsizePolicy "sizePolicy"
#define XmNskipAdjust "skipAdjust"
#define XmNsliderSize "sliderSize"
#define XmNsource "source"
#define XmNsourceCursorIcon "sourceCursorIcon"
#define XmNsourceIsExternal "sourceIsExternal"
#define XmNsourcePixmapIcon "sourcePixmapIcon"
#define XmNsourceWidget "sourceWidget"
#define XmNsourceWindow "sourceWindow"
#define XmNspacing "spacing"
#define XmNspotLocation "spotLocation"
#define XmNstartTime "startTime"
#define XmNstateCursorIcon "stateCursorIcon"
#define XmNstringDirection "stringDirection"
#define XmNsubMenuId "subMenuId"
#define XmNsymbolPixmap "symbolPixmap"
#define XmNtearOffMenuActivateCallback "tearOffMenuActivateCallback"
#define XmNtearOffMenuDeactivateCallback "tearOffMenuDeactivateCallback"
#define XmNtearOffModel "tearOffModel"
#define XmNtextAccelerators "textAccelerators"
#define XmNtextColumns "textColumns"
#define XmNtextFontList "textFontList"
#define XmNtextString "textString"
#define XmNtextTranslations "textTranslations"
#define XmNtextValue "textValue"
#define XmNtitleString "titleString"
#define XmNtoBottomCallback "toBottomCallback"
#define XmNtoPositionCallback "toPositionCallback"
#define XmNtoTopCallback "toTopCallback"
#define XmNtopAttachment "topAttachment"
#define XmNtopCharacter "topCharacter"
#define XmNtopItemPosition "topItemPosition"
#define XmNtopLevelEnterCallback "topLevelEnterCallback"
#define XmNtopLevelLeaveCallback "topLevelLeaveCallback"
#define XmNtopOffset "topOffset"
#define XmNtopPosition "topPosition"
#define XmNtopShadowColor "topShadowColor"
#define XmNtopShadowPixmap "topShadowPixmap"
#define XmNtopWidget "topWidget"
#define XmNtransferProc "transferProc"
#define XmNtransferStatus "transferStatus"
#define XmNtraversalCallback "traversalCallback"
#define XmNtraversalOn "traversalOn"
#define XmNtraversalType "traversalType"
#define XmNtraverseObscuredCallback "traverseObscuredCallback"
#define XmNtreeUpdateProc "treeUpdateProc"
#define XmNtroughColor "troughColor"
#define XmNunitType "unitType"
#define XmNunmapCallback "unmapCallback"
#define XmNunpostBehavior "unpostBehavior"
#define XmNunselectPixmap "unselectPixmap"
#define XmNupdateSliderSize "updateSliderSize"
#define XmNuseAsyncGeometry "useAsyncGeometry"
#define XmNuserData "userData"
#define XmNvalidCursorForeground "validCursorForeground"
#define XmNvalueChangedCallback "valueChangedCallback"
#define XmNvalueWcs "valueWcs"
#define XmNverifyBell "verifyBell"
#define XmNverticalFontUnit "verticalFontUnit"
#define XmNverticalScrollBar "verticalScrollBar"
#define XmNverticalSpacing "verticalSpacing"
#define XmNvisibleItemCount "visibleItemCount"
#define XmNvisibleWhenOff "visibleWhenOff"
#define XmNvisualPolicy "visualPolicy"
#define XmNwhichButton "whichButton"
#define XmNwordWrap "wordWrap"
#define XmNworkWindow "workWindow"
#define XmRAlignment "Alignment"
#define XmRAnimationMask "AnimationMask"
#define XmRAnimationPixmap "AnimationPixmap"
#define XmRAnimationStyle "AnimationStyle"
#define XmRArrowDirection "ArrowDirection"
#define XmRAtomList "AtomList"
#define XmRAttachment "Attachment"
#define XmRAudibleWarning "AudibleWarning"
#define XmRAvailability "Availability"
#define XmRBackgroundPixmap "BackgroundPixmap"
#define XmRBlendModel "BlendModel"
#define XmRBooleanDimension "BooleanDimension"
#define XmRBottomShadowPixmap "BottomShadowPixmap"
#define XmRButtonType "ButtonType"
#define XmRCallbackProc "CallbackProc"
#define XmRChar "Char"
#define XmRCharSetTable "CharSetTable"
#define XmRChildHorizontalAlignment "ChildHorizontalAlignment"
#define XmRChildPlacement "ChildPlacement"
#define XmRChildType "ChildType"
#define XmRChildVerticalAlignment "ChildVerticalAlignment"
#define XmRCommandWindowLocation "CommandWindowLocation"
#define XmRCompoundText "CompoundText"
#define XmRDefaultButtonType "DefaultButtonType"
#define XmRDeleteResponse "DeleteResponse"
#define XmRDialogStyle "DialogStyle"
#define XmRDialogType "DialogType"
#define XmRDoubleClickInterval "DoubleClickInterval"
#define XmRDragInitiatorProtocolStyle "DragInitiatorProtocolStyle"
#define XmRDragReceiverProtocolStyle "DragReceiverProtocolStyle"
#define XmRDropSiteActivity "DropSiteActivity"
#define XmRDropSiteOperations "DropSiteOperations"
#define XmRDropSiteType "DropSiteType"
#define XmRDropTransfers "DropTransfers"
#define XmRExtensionType "ExtensionType"
#define XmRFileTypeMask "FileTypeMask"
#define XmRFontList "FontList"
#define XmRGadgetPixmap "GadgetPixmap"
#define XmRHighlightPixmap "HighlightPixmap"
#define XmRHorizontalDimension "HorizontalDimension"
#define XmRHorizontalInt "HorizontalInt"
#define XmRHorizontalPosition "HorizontalPosition"
#define XmRIconAttachment "IconAttachment"
#define XmRImportTargets "ImportTargets"
#define XmRIndicatorType "IndicatorType"
#define XmRItemCount "ItemCount"
#define XmRItems "Items"
#define XmRKeySym "KeySym"
#define XmRKeySymTable "KeySymTable"
#define XmRKeyboardFocusPolicy "KeyboardFocusPolicy"
#define XmRLabelType "LabelType"
#define XmRListMarginHeight "ListMarginHeight"
#define XmRListMarginWidth "ListMarginWidth"
#define XmRListSizePolicy "ListSizePolicy"
#define XmRListSpacing "ListSpacing"
#define XmRManBottomShadowPixmap "ManBottomShadowPixmap"
#define XmRManForegroundPixmap "ManForegroundPixmap"
#define XmRManHighlightPixmap "ManHighlightPixmap"
#define XmRManTopShadowPixmap "ManTopShadowPixmap"
#define XmRMenuWidget "MenuWidget"
#define XmRMnemonic "Mnemonic"
#define XmRMultiClick "MultiClick"
#define XmRNavigationType "NavigationType"
#define XmRPacking "Packing"
#define XmRPrimForegroundPixmap "PrimForegroundPixmap"
#define XmRProc "Proc"
#define XmRProcessingDirection "ProcessingDirection"
#define XmRRectangleList "RectangleList"
#define XmRResizePolicy "ResizePolicy"
#define XmRRowColumnType "RowColumnType"
#define XmRScrollBarDisplayPolicy "ScrollBarDisplayPolicy"
#define XmRScrollBarPlacement "ScrollBarPlacement"
#define XmRScrollingPolicy "ScrollingPolicy"
#define XmRSelectedItemCount "SelectedItemCount"
#define XmRSelectedItems "SelectedItems"
#define XmRSelectionPolicy "SelectionPolicy"
#define XmRSelectionType "SelectionType"
#define XmRSeparatorType "SeparatorType"
#define XmRShadowType "ShadowType"
#define XmRShellHorizDim "ShellHorizDim"
#define XmRShellHorizPos "ShellHorizPos"
#define XmRShellUnitType "ShellUnitType"
#define XmRShellVertDim "ShellVertDim"
#define XmRShellVertPos "ShellVertPos"
#define XmRSizePolicy "SizePolicy"
#define XmRStringDirection "StringDirection"
#define XmRTearOffModel "TearOffModel"
#define XmRTopShadowPixmap "TopShadowPixmap"
#define XmRTransferStatus "TransferStatus"
#define XmRTraversalType "TraversalType"
#define XmRUnitType "UnitType"
#define XmRUnpostBehavior "UnpostBehavior"
#define XmRValueWcs "ValueWcs"
#define XmRVerticalAlignment "VerticalAlignment"
#define XmRVerticalDimension "VerticalDimension"
#define XmRVerticalInt "VerticalInt"
#define XmRVerticalPosition "VerticalPosition"
#define XmRVirtualBinding "VirtualBinding"
#define XmRVisibleItemCount "VisibleItemCount"
#define XmRVisualPolicy "VisualPolicy"
#define XmRWhichButton "WhichButton"
#define XmRXmBackgroundPixmap "XmBackgroundPixmap"
#define XmRXmString "XmString"
#define XmRXmStringCharSet "XmStringCharSet"
#define XmRXmStringTable "XmStringTable"
#define XmVosfActivate "osfActivate"
#define XmVosfAddMode "osfAddMode"
#define XmVosfBackSpace "osfBackSpace"
#define XmVosfBeginLine "osfBeginLine"
#define XmVosfCancel "osfCancel"
#define XmVosfClear "osfClear"
#define XmVosfCopy "osfCopy"
#define XmVosfCut "osfCut"
#define XmVosfDelete "osfDelete"
#define XmVosfDown "osfDown"
#define XmVosfEndLine "osfEndLine"
#define XmVosfHelp "osfHelp"
#define XmVosfInsert "osfInsert"
#define XmVosfLeft "osfLeft"
#define XmVosfMenu "osfMenu"
#define XmVosfMenuBar "osfMenuBar"
#define XmVosfPageDown "osfPageDown"
#define XmVosfPageLeft "osfPageLeft"
#define XmVosfPageRight "osfPageRight"
#define XmVosfPageUp "osfPageUp"
#define XmVosfPaste "osfPaste"
#define XmVosfPrimaryPaste "osfPrimaryPaste"
#define XmVosfQuickPaste "osfQuickPaste"
#define XmVosfRight "osfRight"
#define XmVosfSelect "osfSelect"
#define XmVosfUndo "osfUndo"
#define XmVosfUp "osfUp"
#define XmSFONTLIST_DEFAULT_TAG_STRING "FONTLIST_DEFAULT_TAG_STRING"
#define XmSXmFONTLIST_DEFAULT_TAG_STRING "XmFONTLIST_DEFAULT_TAG_STRING"
#define XmRTopItemPosition "TopItemPosition"
#define XmNtearOffTitle "tearOffTitle"
#define XmCTearOffTitle "TearOffTitle"
#define XmNpopupHandlerCallback "popupHandlerCallback"
#define XmNconvertCallback "convertCallback"
#define XmNdestinationCallback "destinationCallback"
#define XmNselectedItem "selectedItem"
#define XmCSelectedItem "SelectedItem"
#define XmNselectionCallback "selectionCallback"
#define XmNmatchBehavior "matchBehavior"
#define XmCMatchBehavior "MatchBehavior"
#define XmNnoFontCallback "noFontCallback"
#define XmNtextPath "textPath"
#define XmNeditingPath "editingPath"
#define XmCEditingPath "EditingPath"
#define XmNbidirectionalCursor "bidirectionalCursor"
#define XmCBidirectionalCursor "BidirectionalCursor"
#define XmNcollapsedStatePixmap "collapsedStatePixmap"
#define XmNdetailColumnHeading "detailColumnHeading"
#define XmNdetailCount "detailCount"
#define XmNdetailTabList "detailTabList"
#define XmNexpandedStatePixmap "expandedStatePixmap"
#define XmNlargeCellHeight "largeCellHeight"
#define XmNlargeCellWidth "largeCellWidth"
#define XmNlayoutType "layoutType"
#define XmNoutlineIndentation "outlineIndentation"
#define XmNoutlineLineStyle "outlineLineStyle"
#define XmNprimaryOwnership "primaryOwnership"
#define XmNselectionTechnique "selectionTechnique"
#define XmNsmallCellHeight "smallCellHeight"
#define XmNsmallCellWidth "smallCellWidth"
#define XmNspatialStyle "spatialStyle"
#define XmNentryParent "entryParent"
#define XmNlargeIconX "largeIconX"
#define XmNlargeIconY "largeIconY"
#define XmNsmallIconX "smallIconX"
#define XmNsmallIconY "smallIconY"
#define XmCCollapsedStatePixmap "CollapsedStatePixmap"
#define XmCDetailColumnHeading "DetailColumnHeading"
#define XmCDetailCount "DetailCount"
#define XmCDetailMask "DetailMask"
#define XmCEntryViewType "EntryViewType"
#define XmCLineStyle "LineStyle"
#define XmCDetailTabList "DetailTabList"
#define XmCExpandedStatePixmap "ExpandedStatePixmap"
#define XmCIncludeModel "IncludeModel"
#define XmCCellHeight "CellHeight"
#define XmCCellWidth "CellWidth"
#define XmCLayoutType "LayoutType"
#define XmCOutlineIndentation "OutlineIndentation"
#define XmCPlaceModel "PlaceModel"
#define XmCPrimaryOwnership "PrimaryOwnership"
#define XmCSelectionTechnique "SelectionTechnique"
#define XmCSpatialStyle "SpatialStyle"
#define XmCEntryDetail "EntryDetail"
#define XmCExpandState "ExpandState"
#define XmNlargeIcon "largeIcon"
#define XmNlargeIconMask "largeIconMask"
#define XmNlargeIconPixmap "largeIconPixmap"
#define XmNsmallIcon "smallIcon"
#define XmNsmallIconMask "smallIconMask"
#define XmNsmallIconPixmap "smallIconPixmap"
#define XmCIcon "Icon"
#define XmCViewType "ViewType"
#define XmCVisualEmphasis "VisualEmphasis"
#define XmNcurrentPageNumber "currentPageNumber"
#define XmNfirstPageNumber "firstPageNumber"
#define XmNlastPageNumber "lastPageNumber"
#define XmNbackPagePlacement "backPagePlacement"
#define XmNbackPageNumber "backPageNumber"
#define XmNbackPageSize "backPageSize"
#define XmNbackPageForeground "backPageForeground"
#define XmNbackPageBackground "backPageBackground"
#define XmNframeBackground "frameBackground"
#define XmNbindingType "bindingType"
#define XmNbindingPixmap "bindingPixmap"
#define XmNbindingWidth "bindingWidth"
#define XmNmajorTabSpacing "majorTabSpacing"
#define XmNminorTabSpacing "minorTabSpacing"
#define XmNinnerMarginWidth "innerMarginWidth"
#define XmNinnerMarginHeight "innerMarginHeight"
#define XmNframeShadowThickness "frameShadowThickness"
#define XmNpageNumber "pageNumber"
#define XmCCurrentPageNumber "CurrentPageNumber"
#define XmCFirstPageNumber "FirstPageNumber"
#define XmCLastPageNumber "LastPageNumber"
#define XmCBackPagePlacement "BackPagePlacement"
#define XmCBackPageNumber "BackPageNumber"
#define XmCBackPageSize "BackPageSize"
#define XmCBackPageForeground "BackPageForeground"
#define XmCBackPageBackground "BackPageBackground"
#define XmCFrameBackground "FrameBackground"
#define XmCBindingType "BindingType"
#define XmCBindingPixmap "BindingPixmap"
#define XmCBindingWidth "BindingWidth"
#define XmCMajorTabSpacing "MajorTabSpacing"
#define XmCMinorTabSpacing "MinorTabSpacing"
#define XmCInnerMarginWidth "InnerMarginWidth"
#define XmCInnerMarginHeight "InnerMarginHeight"
#define XmCPageChangeCallback "PageChangeCallback"
#define XmCPageNumber "PageNumber"
#define XmRArrowLayout "ArrowLayout"
#define XmRArrowSensitivity "ArrowSensitivity"
#define XmRSpinBoxChildType "SpinBoxChildType"
#define XmNarrowLayout "arrowLayout"
#define XmCArrowLayout "ArrowLayout"
#define XmNarrowSensitivity "arrowSensitivity"
#define XmCArrowSensitivity "ArrowSensitivity"
#define XmNdefaultArrowSensitivity "defaultArrowSensitivity"
#define XmCDefaultArrowSensitivity "DefaultArrowSensitivity"
#define XmNarrowSize "arrowSize"
#define XmCArrowSize "ArrowSize"
#define XmNspinBoxChildType "spinBoxChildType"
#define XmCSpinBoxChildType "SpinBoxChildType"
#define XmNposition "position"
#define XmNnumValues "numValues"
#define XmCNumValues "NumValues"
#define XmNvalues "values"
#define XmCValues "Values"
#define XmNminimumValue "minimumValue"
#define XmCMinimumValue "MinimumValue"
#define XmNmaximumValue "maximumValue"
#define XmCMaximumValue "MaximumValue"
#define XmNincrementValue "incrementValue"
#define XmCIncrementValue "IncrementValue"
#define XmRAutomaticSelection "AutomaticSelection"
#define XmRLineStyle "LineStyle"
#define XmREntryViewType "EntryViewType"
#define XmRDirection "Direction"
#define XmRLayoutType "LayoutType"
#define XmRPrimaryOwnership "PrimaryOwnership"
#define XmRSelectionTechnique "SelectionTechnique"
#define XmRSpatialStyle "SpatialStyle"
#define XmRTabList "TabList"
#define XmRViewType "ViewType"
#define XmRVisualEmphasis "VisualEmphasis"
#define XmRBindingType "BindingType"
#define XmRNBChildType "NBChildType"
#define XmNentryViewType "entryViewType"
#define XmNinsensitiveStippleBitmap "insensitiveStippleBitmap"
#define XmNlayoutDirection "layoutDirection"
#define XmNviewType "viewType"
#define XmNvisualEmphasis "visualEmphasis"
#define XmCLayoutDirection "LayoutDirection"
#define XmNsnapBackMultiple "snapBackMultiple"
#define XmNslidingMode "slidingMode"
#define XmNsliderVisual "sliderVisual"
#define XmNautoDragModel "autoDragModel"
#define XmNcolorCalculationProc "colorCalculationProc"
#define XmNbitmapConversionModel "bitmapConversionModel"
#define XmNcolorAllocationProc "colorAllocationProc"
#define XmNselectionMode "selectionMode"
#define XmNselectedPositions "selectedPositions"
#define XmNselectedPositionCount "selectedPositionCount"
#define XmCSnapBackMultiple "SnapBackMultiple"
#define XmCSliderVisual "SliderVisual"
#define XmCSlidingMode "SlidingMode"
#define XmCAutoDragModel "AutoDragModel"
#define XmCColorCalculationProc "ColorCalculationProc"
#define XmCBitmapConversionModel "BitmapConversionModel"
#define XmCColorAllocationProc "ColorAllocationProc"
#define XmCInsensitiveStippleBitmap "InsensitiveStippleBitmap"
#define XmCSelectionMode "SelectionMode"
#define XmCSelectedPositions "SelectedPositions"
#define XmCSelectedPositionCount "SelectedPositionCount"
#define XmRSlidingMode "SlidingMode"
#define XmRShowArrows "ShowArrows"
#define XmRSliderVisual "SliderVisual"
#define XmRShowValue "ShowValue"
#define XmRAutoDragModel "AutoDragModel"
#define XmRSWChildType "SWChildType"
#define XmRBitmapConversionModel "BitmapConversionModel"
#define XmRSelectionMode "SelectionMode"
#define XmNinputPolicy "inputPolicy"
#define XmCInputPolicy "InputPolicy"
#define XmRInputPolicy "InputPolicy"
#define XmNtoggleMode "toggleMode"
#define XmCToggleMode "ToggleMode"
#define XmRToggleMode "ToggleMode"
#define XmRIndicatorOn "IndicatorOn"
#define XmRSet "Set"
#define XmNindeterminatePixmap "indeterminatePixmap"
#define XmCIndeterminatePixmap "IndeterminatePixmap"
#define XmNunselectColor "unselectColor"
#define XmCUnselectColor "UnselectColor"
#define XmNselectedPosition "selectedPosition"
#define XmNarrowSpacing "arrowSpacing"
#define XmCArrowSpacing "ArrowSpacing"
#define XmRMatchBehavior "MatchBehavior"
#define XmRComboBoxType "ComboBoxType"
#define XmCSelectedPosition "SelectedPosition"
#define XmNenableWarp "enableWarp"
#define XmCEnableWarp "EnableWarp"
#define XmREnableWarp "EnableWarp"
#define XmNmotifVersion "motifVersion"
#define XmCMotifVersion "MotifVersion"
#define XmNdefaultGlyphPixmap "defaultGlyphPixmap"
#define XmCDefaultGlyphPixmap "DefaultGlyphPixmap"
#define XmCRendition "Rendition"
#define XmNtag "tag"
#define XmCTag "Tag"
#define XmNfontName "fontName"
#define XmCFontName "FontName"
#define XmNfontType "fontType"
#define XmCFontType "FontType"
#define XmRFontType "FontType"
#define XmNloadModel "loadModel"
#define XmCLoadModel "LoadModel"
#define XmRLoadModel "LoadModel"
#define XmNtabList "tabList"
#define XmCTabList "TabList"
#define XmRRenditionPixel "RenditionPixel"
#define XmNunderlineType "underlineType"
#define XmCUnderlineType "UnderlineType"
#define XmNstrikethruType "strikethruType"
#define XmCStrikethruType "StrikethruType"
#define XmRLineType "LineType"
#define XmNrenderTable "renderTable"
#define XmCRenderTable "RenderTable"
#define XmRRenderTable "RenderTable"
#define XmNbuttonRenderTable "buttonRenderTable"
#define XmCButtonRenderTable "ButtonRenderTable"
#define XmRButtonRenderTable "ButtonRenderTable"
#define XmNlabelRenderTable "labelRenderTable"
#define XmCLabelRenderTable "LabelRenderTable"
#define XmRLabelRenderTable "LabelRenderTable"
#define XmNtextRenderTable "textRenderTable"
#define XmCTextRenderTable "TextRenderTable"
#define XmRTextRenderTable "TextRenderTable"
#define XmNdragStartCallback "dragStartCallback"
#define XmNnoRenditionCallback "noRenditionCallback"
#define XmSXmAS_IS "XmAS_IS"
#define XmMIsWhiteSpaceMethod "IsWhiteSpaceMethod"
#define XmMIsScanBreakMethod "IsScanBreakMethod"
#define XmMCharDirection "CharDirection"
#define XmMInitialCharsDirection "InitialCharsDirection"
#define XmNpatternType "patternType"
#define XmNsubstitute "substitute"
#define XmNinvokeParseProc "invokeParseProc"
#define XmNincludeStatus "includeStatus"
#define XmVosfBackTab "osfBackTab"
#define XmVosfBeginData "osfBeginData"
#define XmVosfDeselectAll "osfDeselectAll"
#define XmVosfEndData "osfEndData"
#define XmVosfEscape "osfEscape"
#define XmVosfExtend "osfExtend"
#define XmVosfLeftLine "osfLeftLine"
#define XmVosfNext "osfNext"
#define XmVosfNextField "osfNextField"
#define XmVosfNextMenu "osfNextMenu"
#define XmVosfNextMinor "osfNextMinor"
#define XmVosfPrevField "osfPrevField"
#define XmVosfPrevMenu "osfPrevMenu"
#define XmVosfPrior "osfPrior"
#define XmVosfPriorMinor "osfPriorMinor"
#define XmVosfReselect "osfReselect"
#define XmVosfRestore "osfRestore"
#define XmVosfRightLine "osfRightLine"
#define XmVosfSelectAll "osfSelectAll"
#define XmVosfSwitchDirection "osfSwitchDirection"
#define XmNnotebookChildType "notebookChildType"
#define XmCNotebookChildType "NotebookChildType"
#define XmRNotebookChildType "NotebookChildType"
#define XmNscrolledWindowChildType "scrolledWindowChildType"
#define XmCScrolledWindowChildType "ScrolledWindowChildType"
#define XmRScrolledWindowChildType "ScrolledWindowChildType"
#define XmNselectedObjects "selectedObjects"
#define XmCSelectedObjects "SelectedObjects"
#define XmNselectedObjectCount "selectedObjectCount"
#define XmCSelectedObjectCount "SelectedObjectCount"
#define XmNcomboBoxType "comboBoxType"
#define XmCComboBoxType "ComboBoxType"
#define XmNtabValue "tabValue"
#define XmNoffsetModel "offsetModel"
#define XmNdecimal "decimal"
#define XmNdetail "detail"
#define XmCDetail "Detail"
#define XmNdetailCount "detailCount"
#define XmCDetailCount "DetailCount"
#define XmNcontainerID "containerID"
#define XmCContainerID "ContainerID"
#define XmSCLIENT_WINDOW "CLIENT_WINDOW"
#define XmSCLIP_TEMPORARY "CLIP_TEMPORARY"
#define XmSCLIPBOARD "CLIPBOARD"
#define XmSCOMPOUND_TEXT "COMPOUND_TEXT"
#define XmSDELETE "DELETE"
#define XmSFILE "FILE"
#define XmSFILE_NAME "FILE_NAME"
#define XmSINCR "INCR"
#define XmSINSERT_PROPERTY "INSERT_PROPERTY"
#define XmSINSERT_SELECTION "INSERT_SELECTION"
#define XmSLENGTH "LENGTH"
#define XmSLINK_SELECTION "LINK_SELECTION"
#define XmS_MOTIF_ATOM_0 "_MOTIF_ATOM_0"
#define XmS_MOTIF_BINDINGS "_MOTIF_BINDINGS"
#define XmS_MOTIF_DEFAULT_BINDINGS "_MOTIF_DEFAULT_BINDINGS"
#define XmS_MOTIF_CANCEL_DROP_EFFECT "_MOTIF_CANCEL_DROP_EFFECT"
#define XmS_MOTIF_CLIP_HEADER "_MOTIF_CLIP_HEADER"
#define XmS_MOTIF_CLIP_DATA_REQUEST "_MOTIF_CLIP_DATA_REQUEST"
#define XmS_MOTIF_CLIP_DATA_DELETE "_MOTIF_CLIP_DATA_DELETE"
#define XmS_MOTIF_CLIP_ITEM "_MOTIF_CLIP_ITEM"
#define XmS_MOTIF_CLIP_LOCK "_MOTIF_CLIP_LOCK"
#define XmS_MOTIF_CLIP_LOCK_ACCESS_VALID "_MOTIF_CLIP_LOCK_ACCESS_VALID"
#define XmS_MOTIF_CLIP_MESSAGE "_MOTIF_CLIP_MESSAGE"
#define XmS_MOTIF_CLIP_NEXT_ID "_MOTIF_CLIP_NEXT_ID"
#define XmS_MOTIF_CLIP_TIME "_MOTIF_CLIP_TIME"
#define XmS_MOTIF_CLIPBOARD_TARGETS "_MOTIF_CLIPBOARD_TARGETS"
#define XmS_MOTIF_COMPOUND_STRING "_MOTIF_COMPOUND_STRING"
#define XmS_MOTIF_DEFERRED_CLIPBOARD_TARGETS "_MOTIF_DEFERRED_CLIPBOARD_TARGETS"
#define XmS_MOTIF_DESTINATION "_MOTIF_DESTINATION"
#define XmS_MOTIF_DRAG_OFFSET "_MOTIF_DRAG_OFFSET"
#define XmS_MOTIF_DROP "_MOTIF_DROP"
#define XmS_MOTIF_ENCODING_REGISTRY "_MOTIF_ENCODING_REGISTRY"
#define XmS_MOTIF_EXPORT_TARGETS "_MOTIF_EXPORT_TARGETS"
#define XmS_MOTIF_LOSE_SELECTION "_MOTIF_LOSE_SELECTION"
#define XmS_MOTIF_RENDER_TABLE "_MOTIF_RENDER_TABLE"
#define XmS_MOTIF_WM_QUERY "_MOTIF_WM_QUERY"
#define XmS_MOTIF_WM_ALL_CLIENTS "_MOTIF_WM_ALL_CLIENTS"
#define XmSMULTIPLE "MULTIPLE"
#define XmSNULL "NULL"
#define XmSTARGETS "TARGETS"
#define XmSTEXT "TEXT"
#define XmSTIMESTAMP "TIMESTAMP"
#define XmSWM_STATE "WM_STATE"
#define XmSTRANSFER_SUCCESS "XmTRANSFER_SUCCESS"
#define XmSTRANSFER_FAILURE "XmTRANSFER_FAILURE"
#define XmNpathMode "pathMode"
#define XmRPathMode "PathMode"
#define XmCPathMode "PathMode"
#define XmNfileFilterStyle "fileFilterStyle"
#define XmRFileFilterStyle "FileFilterStyle"
#define XmCFileFilterStyle "FileFilterStyle"
#define XmNdirTextLabelString "dirTextLabelString"
#define XmCDirTextLabelString "DirTextLabelString"
#define XmNenableBtn1Transfer "enableBtn1Transfer"
#define XmCEnableBtn1Transfer "EnableBtn1Transfer"
#define XmNenableButtonTab "enableButtonTab"
#define XmCEnableButtonTab "EnableButtonTab"
#define XmNenableEtchedInMenu "enableEtchedInMenu"
#define XmCEnableEtchedInMenu "EnableEtchedInMenu"
#define XmNdefaultButtonEmphasis "defaultButtonEmphasis"
#define XmCDefaultButtonEmphasis "DefaultButtonEmphasis"
#define XmRDefaultButtonEmphasis "DefaultButtonEmphasis"
#define XmNenableToggleColor "enableToggleColor"
#define XmCEnableToggleColor "EnableToggleColor"
#define XmNenableToggleVisual "enableToggleVisual"
#define XmCEnableToggleVisual "EnableToggleVisual"
#define XmNenableDragIcon "enableDragIcon"
#define XmCEnableDragIcon "EnableDragIcon"
#define XmNenableUnselectableDrag "enableUnselectableDrag"
#define XmCEnableUnselectableDrag "EnableUnselectableDrag"
#define XmNdragOverActiveMode "dragOverActiveMode"
#define XmCDragOverActiveMode "DragOverActiveMode"
#define XmNinstallColormap "installColormap"
#define XmCInstallColormap "InstallColormap"
#define XmCOwnerEvents "OwnerEvents"
#define XmNownerEvents "ownerEvents"
#define XmCGrabStyle "GrabStyle"
#define XmNgrabStyle "grabStyle"
#define XmNforegroundState "foregroundState"
#define XmNbackgroundState "backgroundState"
#define XmCGroundState "GroundState"
#define XmRGroundState "GroundState"
#define XmRSelectColor "SelectColor"
#define XmRLargeIconPixmap "LargeIconPixmap"
#define XmRSmallIconPixmap "SmallIconPixmap"
#define XmNoutlineState "outlineState"
#define XmCOutlineState "OutlineState"
#define XmROutlineState "OutlineState"
#define XmNspatialIncludeModel "spatialIncludeModel"
#define XmCSpatialIncludeModel "SpatialIncludeModel"
#define XmRSpatialIncludeModel "SpatialIncludeModel"
#define XmNspatialResizeModel "spatialResizeModel"
#define XmCSpatialResizeModel "SpatialResizeModel"
#define XmRSpatialResizeModel "SpatialResizeModel"
#define XmNspatialSnapModel "spatialSnapModel"
#define XmCSpatialSnapModel "SpatialSnapModel"
#define XmRSpatialSnapModel "SpatialSnapModel"
#define XmNdetailColumnHeadingCount "detailColumnHeadingCount"
#define XmCDetailColumnHeadingCount "DetailColumnHeadingCount"
#define XmNdetailOrder "detailOrder"
#define XmCDetailOrder "DetailOrder"
#define XmRCardinalList "CardinalList"
#define XmNdetailOrderCount "detailOrderCount"
#define XmCDetailOrderCount "DetailOrderCount"
#define XmNoutlineColumnWidth "outlineColumnWidth"
#define XmCOutlineColumnWidth "OutlineColumnWidth"
#define XmNoutlineChangedCallback "outlineChangedCallback"
#define XmCOutlineChangedCallback "OutlineChangedCallback"
#define XmNoutlineButtonPolicy "outlineButtonPolicy"
#define XmCOutlineButtonPolicy "OutlineButtonPolicy"
#define XmROutlineButtonPolicy "OutlineButtonPolicy"
#define XmCDefaultVirtualBindings "DefaultVirtualBindings"
#define XmNdefaultVirtualBindings "defaultVirtualBindings"
#define XmCResizable "Resizable"
#define XmRDynamicPixmap "DynamicPixmap"
#define XmNpageChangedCallback "pageChangedCallback"
#define XmNarea "area"
#define XmNdetailShadowThickness "detailShadowThickness"
#define XmNsliderMark "sliderMark"
#define XmCSliderMark "SliderMark"
#define XmRSliderMark "SliderMark"
#define XmREnableBtn1Transfer "EnableBtn1Transfer"
#define XmNrenditionBackground "renditionBackground"
#define XmNrenditionForeground "renditionForeground"
#define XmCRenditionBackground "RenditionBackground"
#define XmCRenditionForeground "RenditionForeground"
#define XmNindeterminateInsensitivePixmap "indeterminateInsensitivePixmap"
#define XmCIndeterminateInsensitivePixmap "IndeterminateInsensitivePixmap"
#define XmNframeChildType "frameChildType"
#define XmCFrameChildType "FrameChildType"
#define XmNtextField "textField"
#define XmCTextField "TextField"
#define XmNenableThinThickness "enableThinThickness"
#define XmCEnableThinThickness "EnableThinThickness"
#define XmNprimaryColorSetId "primaryColorSetId"
#define XmCPrimaryColorSetId "PrimaryColorSetId"
#define XmNsecondaryColorSetId "secondaryColorSetId"
#define XmCSecondaryColorSetId "SecondaryColorSetId"
#define XmNtextColorSetId "textColorSetId"
#define XmCTextColorSetId "TextColorSetId"
#define XmNactiveColorSetId "activeColorSetId"
#define XmCActiveColorSetId "ActiveColorSetId"
#define XmNinactiveColorSetId "inactiveColorSetId"
#define XmCInactiveColorSetId "InactiveColorSetId"
#define XmNuseColorObj "useColorObj"
#define XmCUseColorObj "UseColorObj"
#define XmNuseTextColor "useTextColor"
#define XmCUseTextColor "UseTextColor"
#define XmNuseTextColorForList "useTextColorForList"
#define XmCUseTextColorForList "UseTextColorForList"
#define XmNuseMask "useMask"
#define XmCUseMask "UseMask"
#define XmNuseMultiColorIcons "useMultiColorIcons"
#define XmCUseMultiColorIcons "UseMultiColorIcons"
#define XmNuseIconFileCache "useIconFileCache"
#define XmCUseIconFileCache "UseIconFileCache"
#define XmSPIXEL_SET "Pixel Sets"
#define XmSCUSTOMIZE_DATA "Customize Data:"
#define XmSCOLOR_SRV_NAME "ColorServer"
#define XmNlist "list"
#define XmCList "List"
#define XmNarrowOrientation "arrowOrientation"
#define XmCArrowOrientation "ArrowOrientation"
#define XmRArrowOrientation "ArrowOrientation"
#define XmNpositionType "positionType"
#define XmCPositionType "PositionType"
#define XmRPositionType "PositionType"
#define XmNwrap "wrap"
#define XmCWrap "Wrap"
#define XmNpositionMode "positionMode"
#define XmCPositionMode "PositionMode"
#define XmRPositionMode "PositionMode"
#define XmNprintOrientation "printOrientation"
#define XmCPrintOrientation "PrintOrientation"
#define XmNprintOrientations "printOrientations"
#define XmCPrintOrientations "PrintOrientations"
#define XmNprintResolution "printResolution"
#define XmCPrintResolution "PrintResolution"
#define XmNprintResolutions "printResolutions"
#define XmCPrintResolutions "PrintResolutions"
#define XmNdefaultPixmapResolution "defaultPixmapResolution"
#define XmCDefaultPixmapResolution "DefaultPixmapResolution"
#define XmNstartJobCallback "startJobCallback"
#define XmNendJobCallback "endJobCallback"
#define XmNpageSetupCallback "pageSetupCallback"
#define XmNpdmNotificationCallback "pdmNotificationCallback"
#define XmNminX "minX"
#define XmNminY "minY"
#define XmNmaxX "maxX"
#define XmNmaxY "maxY"
#define XmCMinX "MinX"
#define XmCMinY "MinY"
#define XmCMaxX "MaxX"
#define XmCMaxY "MaxY"
#define XmNpreeditStartCallback "preeditStartCallback"
#define XmNpreeditDoneCallback "preeditDoneCallback"
#define XmNpreeditDrawCallback "preeditDrawCallback"
#define XmNpreeditCaretCallback "preeditCaretCallback"
#define XmNverifyPreedit "verifyPreedit"
#define XmCVerifyPreedit "VerifyPreedit"
#define XmNenableMultiKeyBindings "enableMultiKeyBindings"
#define XmCEnableMultiKeyBindings "EnableMultiKeyBindings"
#define XmRButtonFontList "ButtonFontList"
#define XmRLabelFontList "LabelFontList"
#define XmRTextFontList "TextFontList"
#define XmSPIXEL_SET_PROP "SDT Pixel Set"
#define XmS50_foreground "50_foreground"
#define XmSunspecified_pixmap "unspecified_pixmap"
#else
externalref _XmConst char _XmStrings[];
#ifndef XmS
#define XmS ((char*)&_XmStrings[0])
#endif
#ifndef XmCAccelerator
#define XmCAccelerator ((char*)&_XmStrings[1])
#endif
#ifndef XmCAcceleratorText
#define XmCAcceleratorText ((char*)&_XmStrings[13])
#endif
#ifndef XmCAdjustLast
#define XmCAdjustLast ((char*)&_XmStrings[29])
#endif
#ifndef XmCAdjustMargin
#define XmCAdjustMargin ((char*)&_XmStrings[40])
#endif
#ifndef XmCAlignment
#define XmCAlignment ((char*)&_XmStrings[53])
#endif
#ifndef XmCAllowOverlap
#define XmCAllowOverlap ((char*)&_XmStrings[63])
#endif
#ifndef XmCAllowUnusedSpace
#define XmCAllowUnusedSpace ((char*)&_XmStrings[76])
#endif
#ifndef XmCAnimationMask
#define XmCAnimationMask ((char*)&_XmStrings[93])
#endif
#ifndef XmCAnimationPixmap
#define XmCAnimationPixmap ((char*)&_XmStrings[107])
#endif
#ifndef XmCAnimationPixmapDepth
#define XmCAnimationPixmapDepth ((char*)&_XmStrings[123])
#endif
#ifndef XmCAnimationStyle
#define XmCAnimationStyle ((char*)&_XmStrings[144])
#endif
#ifndef XmCApplyLabelString
#define XmCApplyLabelString ((char*)&_XmStrings[159])
#endif
#ifndef XmCArmCallback
#define XmCArmCallback ((char*)&_XmStrings[176])
#endif
#ifndef XmCArmColor
#define XmCArmColor ((char*)&_XmStrings[188])
#endif
#ifndef XmCArmPixmap
#define XmCArmPixmap ((char*)&_XmStrings[197])
#endif
#ifndef XmCArrowDirection
#define XmCArrowDirection ((char*)&_XmStrings[207])
#endif
#ifndef XmCAttachment
#define XmCAttachment ((char*)&_XmStrings[222])
#endif
#ifndef XmCAudibleWarning
#define XmCAudibleWarning ((char*)&_XmStrings[233])
#endif
#ifndef XmCAutoShowCursorPosition
#define XmCAutoShowCursorPosition ((char*)&_XmStrings[248])
#endif
#ifndef XmCAutoUnmanage
#define XmCAutoUnmanage ((char*)&_XmStrings[271])
#endif
#ifndef XmCAutomaticSelection
#define XmCAutomaticSelection ((char*)&_XmStrings[284])
#endif
#ifndef XmCAvailability
#define XmCAvailability ((char*)&_XmStrings[303])
#endif
#ifndef XmCBackgroundPixmap
#define XmCBackgroundPixmap ((char*)&_XmStrings[316])
#endif
#ifndef XmCBlendModel
#define XmCBlendModel ((char*)&_XmStrings[333])
#endif
#ifndef XmCBlinkRate
#define XmCBlinkRate ((char*)&_XmStrings[344])
#endif
#ifndef XmCBottomShadowColor
#define XmCBottomShadowColor ((char*)&_XmStrings[354])
#endif
#ifndef XmCBottomShadowPixmap
#define XmCBottomShadowPixmap ((char*)&_XmStrings[372])
#endif
#ifndef XmCButtonAcceleratorText
#define XmCButtonAcceleratorText ((char*)&_XmStrings[391])
#endif
#ifndef XmCButtonAccelerators
#define XmCButtonAccelerators ((char*)&_XmStrings[413])
#endif
#ifndef XmCButtonCount
#define XmCButtonCount ((char*)&_XmStrings[432])
#endif
#ifndef XmCButtonFontList
#define XmCButtonFontList ((char*)&_XmStrings[444])
#endif
#ifndef XmCButtonMnemonicCharSets
#define XmCButtonMnemonicCharSets ((char*)&_XmStrings[459])
#endif
#ifndef XmCButtonMnemonics
#define XmCButtonMnemonics ((char*)&_XmStrings[482])
#endif
#ifndef XmCButtonSet
#define XmCButtonSet ((char*)&_XmStrings[498])
#endif
#ifndef XmCButtonType
#define XmCButtonType ((char*)&_XmStrings[508])
#endif
#ifndef XmCButtons
#define XmCButtons ((char*)&_XmStrings[519])
#endif
#ifndef XmCCancelLabelString
#define XmCCancelLabelString ((char*)&_XmStrings[527])
#endif
#ifndef XmCChildHorizontalAlignment
#define XmCChildHorizontalAlignment ((char*)&_XmStrings[545])
#endif
#ifndef XmCChildHorizontalSpacing
#define XmCChildHorizontalSpacing ((char*)&_XmStrings[570])
#endif
#ifndef XmCChildPlacement
#define XmCChildPlacement ((char*)&_XmStrings[593])
#endif
#ifndef XmCChildType
#define XmCChildType ((char*)&_XmStrings[608])
#endif
#ifndef XmCChildVerticalAlignment
#define XmCChildVerticalAlignment ((char*)&_XmStrings[618])
#endif
#ifndef XmCChildren
#define XmCChildren ((char*)&_XmStrings[641])
#endif
#ifndef XmCClientData
#define XmCClientData ((char*)&_XmStrings[650])
#endif
#ifndef XmCClipWindow
#define XmCClipWindow ((char*)&_XmStrings[661])
#endif
#ifndef XmCColumns
#define XmCColumns ((char*)&_XmStrings[672])
#endif
#ifndef XmCCommandWindow
#define XmCCommandWindow ((char*)&_XmStrings[680])
#endif
#ifndef XmCCommandWindowLocation
#define XmCCommandWindowLocation ((char*)&_XmStrings[694])
#endif
#ifndef XmCConvertProc
#define XmCConvertProc ((char*)&_XmStrings[716])
#endif
#ifndef XmCCursorBackground
#define XmCCursorBackground ((char*)&_XmStrings[728])
#endif
#ifndef XmCCursorForeground
#define XmCCursorForeground ((char*)&_XmStrings[745])
#endif
#ifndef XmCCursorPosition
#define XmCCursorPosition ((char*)&_XmStrings[762])
#endif
#ifndef XmCCursorPositionVisible
#define XmCCursorPositionVisible ((char*)&_XmStrings[777])
#endif
#ifndef XmCDarkThreshold
#define XmCDarkThreshold ((char*)&_XmStrings[799])
#endif
#ifndef XmCDecimalPoints
#define XmCDecimalPoints ((char*)&_XmStrings[813])
#endif
#ifndef XmCDefaultButtonShadowThickness
#define XmCDefaultButtonShadowThickness ((char*)&_XmStrings[827])
#endif
#ifndef XmCDefaultButtonType
#define XmCDefaultButtonType ((char*)&_XmStrings[856])
#endif
#ifndef XmCDefaultCopyCursorIcon
#define XmCDefaultCopyCursorIcon ((char*)&_XmStrings[874])
#endif
#ifndef XmCDefaultFontList
#define XmCDefaultFontList ((char*)&_XmStrings[896])
#endif
#ifndef XmCDefaultInvalidCursorIcon
#define XmCDefaultInvalidCursorIcon ((char*)&_XmStrings[912])
#endif
#ifndef XmCDefaultLinkCursorIcon
#define XmCDefaultLinkCursorIcon ((char*)&_XmStrings[937])
#endif
#ifndef XmCDefaultMoveCursorIcon
#define XmCDefaultMoveCursorIcon ((char*)&_XmStrings[959])
#endif
#ifndef XmCDefaultNoneCursorIcon
#define XmCDefaultNoneCursorIcon ((char*)&_XmStrings[981])
#endif
#ifndef XmCDefaultPosition
#define XmCDefaultPosition ((char*)&_XmStrings[1003])
#endif
#ifndef XmCDefaultSourceCursorIcon
#define XmCDefaultSourceCursorIcon ((char*)&_XmStrings[1019])
#endif
#ifndef XmCDefaultValidCursorIcon
#define XmCDefaultValidCursorIcon ((char*)&_XmStrings[1043])
#endif
#ifndef XmCDeleteResponse
#define XmCDeleteResponse ((char*)&_XmStrings[1066])
#endif
#ifndef XmCDesktopParent
#define XmCDesktopParent ((char*)&_XmStrings[1081])
#endif
#ifndef XmCDialogStyle
#define XmCDialogStyle ((char*)&_XmStrings[1095])
#endif
#ifndef XmCDialogTitle
#define XmCDialogTitle ((char*)&_XmStrings[1107])
#endif
#ifndef XmCDialogType
#define XmCDialogType ((char*)&_XmStrings[1119])
#endif
#ifndef XmCDirListItemCount
#define XmCDirListItemCount ((char*)&_XmStrings[1130])
#endif
#ifndef XmCDirListItems
#define XmCDirListItems ((char*)&_XmStrings[1147])
#endif
#ifndef XmCDirListLabelString
#define XmCDirListLabelString ((char*)&_XmStrings[1160])
#endif
#ifndef XmCDirMask
#define XmCDirMask ((char*)&_XmStrings[1179])
#endif
#ifndef XmCDirSearchProc
#define XmCDirSearchProc ((char*)&_XmStrings[1187])
#endif
#ifndef XmCDirSpec
#define XmCDirSpec ((char*)&_XmStrings[1201])
#endif
#ifndef XmCDirectory
#define XmCDirectory ((char*)&_XmStrings[1209])
#endif
#ifndef XmCDirectoryValid
#define XmCDirectoryValid ((char*)&_XmStrings[1219])
#endif
#ifndef XmCDisarmCallback
#define XmCDisarmCallback ((char*)&_XmStrings[1234])
#endif
#ifndef XmCDoubleClickInterval
#define XmCDoubleClickInterval ((char*)&_XmStrings[1249])
#endif
#ifndef XmCDragContextClass
#define XmCDragContextClass ((char*)&_XmStrings[1269])
#endif
#ifndef XmCDragDropFinishCallback
#define XmCDragDropFinishCallback ((char*)&_XmStrings[1286])
#endif
#ifndef XmCDragIconClass
#define XmCDragIconClass ((char*)&_XmStrings[1309])
#endif
#ifndef XmCDragInitiatorProtocolStyle
#define XmCDragInitiatorProtocolStyle ((char*)&_XmStrings[1323])
#endif
#ifndef XmCDragMotionCallback
#define XmCDragMotionCallback ((char*)&_XmStrings[1350])
#endif
#ifndef XmCDragOperations
#define XmCDragOperations ((char*)&_XmStrings[1369])
#endif
#ifndef XmCDragOverMode
#define XmCDragOverMode ((char*)&_XmStrings[1384])
#endif
#ifndef XmCDragProc
#define XmCDragProc ((char*)&_XmStrings[1397])
#endif
#ifndef XmCDragReceiverProtocolStyle
#define XmCDragReceiverProtocolStyle ((char*)&_XmStrings[1406])
#endif
#ifndef XmCDropProc
#define XmCDropProc ((char*)&_XmStrings[1432])
#endif
#ifndef XmCDropRectangles
#define XmCDropRectangles ((char*)&_XmStrings[1441])
#endif
#ifndef XmCDropSiteActivity
#define XmCDropSiteActivity ((char*)&_XmStrings[1456])
#endif
#ifndef XmCDropSiteEnterCallback
#define XmCDropSiteEnterCallback ((char*)&_XmStrings[1473])
#endif
#ifndef XmCDropSiteLeaveCallback
#define XmCDropSiteLeaveCallback ((char*)&_XmStrings[1495])
#endif
#ifndef XmCDropSiteManagerClass
#define XmCDropSiteManagerClass ((char*)&_XmStrings[1517])
#endif
#ifndef XmCDropSiteOperations
#define XmCDropSiteOperations ((char*)&_XmStrings[1538])
#endif
#ifndef XmCDropSiteType
#define XmCDropSiteType ((char*)&_XmStrings[1557])
#endif
#ifndef XmCDropStartCallback
#define XmCDropStartCallback ((char*)&_XmStrings[1570])
#endif
#ifndef XmCDropTransferClass
#define XmCDropTransferClass ((char*)&_XmStrings[1588])
#endif
#ifndef XmCDropTransfers
#define XmCDropTransfers ((char*)&_XmStrings[1606])
#endif
#ifndef XmCEditable
#define XmCEditable ((char*)&_XmStrings[1620])
#endif
#ifndef XmCEntryBorder
#define XmCEntryBorder ((char*)&_XmStrings[1629])
#endif
#ifndef XmCEntryClass
#define XmCEntryClass ((char*)&_XmStrings[1641])
#endif
#ifndef XmCExportTargets
#define XmCExportTargets ((char*)&_XmStrings[1652])
#endif
#ifndef XmCExposeCallback
#define XmCExposeCallback ((char*)&_XmStrings[1666])
#endif
#ifndef XmCExtensionType
#define XmCExtensionType ((char*)&_XmStrings[1681])
#endif
#ifndef XmCFileListItemCount
#define XmCFileListItemCount ((char*)&_XmStrings[1695])
#endif
#ifndef XmCFileListItems
#define XmCFileListItems ((char*)&_XmStrings[1713])
#endif
#ifndef XmCFileListLabelString
#define XmCFileListLabelString ((char*)&_XmStrings[1727])
#endif
#ifndef XmCFileSearchProc
#define XmCFileSearchProc ((char*)&_XmStrings[1747])
#endif
#ifndef XmCFileTypeMask
#define XmCFileTypeMask ((char*)&_XmStrings[1762])
#endif
#ifndef XmCFillOnArm
#define XmCFillOnArm ((char*)&_XmStrings[1775])
#endif
#ifndef XmCFillOnSelect
#define XmCFillOnSelect ((char*)&_XmStrings[1785])
#endif
#ifndef XmCFilterLabelString
#define XmCFilterLabelString ((char*)&_XmStrings[1798])
#endif
#ifndef XmCFontList
#define XmCFontList ((char*)&_XmStrings[1816])
#endif
#ifndef XmCForegroundThreshold
#define XmCForegroundThreshold ((char*)&_XmStrings[1825])
#endif
#ifndef XmCHelpLabelString
#define XmCHelpLabelString ((char*)&_XmStrings[1845])
#endif
#ifndef XmCHighlightColor
#define XmCHighlightColor ((char*)&_XmStrings[1861])
#endif
#ifndef XmCHighlightOnEnter
#define XmCHighlightOnEnter ((char*)&_XmStrings[1876])
#endif
#ifndef XmCHighlightPixmap
#define XmCHighlightPixmap ((char*)&_XmStrings[1893])
#endif
#ifndef XmCHighlightThickness
#define XmCHighlightThickness ((char*)&_XmStrings[1909])
#endif
#ifndef XmCHorizontalFontUnit
#define XmCHorizontalFontUnit ((char*)&_XmStrings[1928])
#endif
#ifndef XmCHorizontalScrollBar
#define XmCHorizontalScrollBar ((char*)&_XmStrings[1947])
#endif
#ifndef XmCHot
#define XmCHot ((char*)&_XmStrings[1967])
#endif
#ifndef XmCICCHandle
#define XmCICCHandle ((char*)&_XmStrings[1971])
#endif
#ifndef XmCImportTargets
#define XmCImportTargets ((char*)&_XmStrings[1981])
#endif
#ifndef XmCIncrement
#define XmCIncrement ((char*)&_XmStrings[1995])
#endif
#ifndef XmCIncremental
#define XmCIncremental ((char*)&_XmStrings[2005])
#endif
#ifndef XmCIndicatorOn
#define XmCIndicatorOn ((char*)&_XmStrings[2017])
#endif
#ifndef XmCIndicatorSize
#define XmCIndicatorSize ((char*)&_XmStrings[2029])
#endif
#ifndef XmCIndicatorType
#define XmCIndicatorType ((char*)&_XmStrings[2043])
#endif
#ifndef XmCInitialDelay
#define XmCInitialDelay ((char*)&_XmStrings[2057])
#endif
#ifndef XmCInitialFocus
#define XmCInitialFocus ((char*)&_XmStrings[2070])
#endif
#ifndef XmCInputCreate
#define XmCInputCreate ((char*)&_XmStrings[2083])
#endif
#ifndef XmCInputMethod
#define XmCInputMethod ((char*)&_XmStrings[2095])
#endif
#ifndef XmCInvalidCursorForeground
#define XmCInvalidCursorForeground ((char*)&_XmStrings[2107])
#endif
#ifndef XmCIsAligned
#define XmCIsAligned ((char*)&_XmStrings[2131])
#endif
#ifndef XmCIsHomogeneous
#define XmCIsHomogeneous ((char*)&_XmStrings[2141])
#endif
#ifndef XmCItemCount
#define XmCItemCount ((char*)&_XmStrings[2155])
#endif
#ifndef XmCItems
#define XmCItems ((char*)&_XmStrings[2165])
#endif
#ifndef XmCKeyboardFocusPolicy
#define XmCKeyboardFocusPolicy ((char*)&_XmStrings[2171])
#endif
#ifndef XmCLabelFontList
#define XmCLabelFontList ((char*)&_XmStrings[2191])
#endif
#ifndef XmCLabelInsensitivePixmap
#define XmCLabelInsensitivePixmap ((char*)&_XmStrings[2205])
#endif
#ifndef XmCLabelPixmap
#define XmCLabelPixmap ((char*)&_XmStrings[2228])
#endif
#ifndef XmCLabelString
#define XmCLabelString ((char*)&_XmStrings[2240])
#endif
#ifndef XmCLabelType
#define XmCLabelType ((char*)&_XmStrings[2252])
#endif
#ifndef XmCLightThreshold
#define XmCLightThreshold ((char*)&_XmStrings[2262])
#endif
#ifndef XmCListLabelString
#define XmCListLabelString ((char*)&_XmStrings[2277])
#endif
#ifndef XmCListMarginHeight
#define XmCListMarginHeight ((char*)&_XmStrings[2293])
#endif
#ifndef XmCListMarginWidth
#define XmCListMarginWidth ((char*)&_XmStrings[2310])
#endif
#ifndef XmCListSizePolicy
#define XmCListSizePolicy ((char*)&_XmStrings[2326])
#endif
#ifndef XmCListSpacing
#define XmCListSpacing ((char*)&_XmStrings[2341])
#endif
#ifndef XmCListUpdated
#define XmCListUpdated ((char*)&_XmStrings[2353])
#endif
#ifndef XmCLogicalParent
#define XmCLogicalParent ((char*)&_XmStrings[2365])
#endif
#ifndef XmCMainWindowMarginHeight
#define XmCMainWindowMarginHeight ((char*)&_XmStrings[2379])
#endif
#ifndef XmCMainWindowMarginWidth
#define XmCMainWindowMarginWidth ((char*)&_XmStrings[2402])
#endif
#ifndef XmCMappingDelay
#define XmCMappingDelay ((char*)&_XmStrings[2424])
#endif
#ifndef XmCMarginBottom
#define XmCMarginBottom ((char*)&_XmStrings[2437])
#endif
#ifndef XmCMarginHeight
#define XmCMarginHeight ((char*)&_XmStrings[2450])
#endif
#ifndef XmCMarginLeft
#define XmCMarginLeft ((char*)&_XmStrings[2463])
#endif
#ifndef XmCMarginRight
#define XmCMarginRight ((char*)&_XmStrings[2474])
#endif
#ifndef XmCMarginTop
#define XmCMarginTop ((char*)&_XmStrings[2486])
#endif
#ifndef XmCMarginWidth
#define XmCMarginWidth ((char*)&_XmStrings[2496])
#endif
#ifndef XmCMask
#define XmCMask ((char*)&_XmStrings[2508])
#endif
#ifndef XmCMaxItems
#define XmCMaxItems ((char*)&_XmStrings[2513])
#endif
#ifndef XmCMaxLength
#define XmCMaxLength ((char*)&_XmStrings[2522])
#endif
#ifndef XmCMaxValue
#define XmCMaxValue ((char*)&_XmStrings[2532])
#endif
#ifndef XmCMaximum
#define XmCMaximum ((char*)&_XmStrings[2541])
#endif
#ifndef XmCMenuBar
#define XmCMenuBar ((char*)&_XmStrings[2549])
#endif
#ifndef XmCMenuPost
#define XmCMenuPost ((char*)&_XmStrings[2557])
#endif
#ifndef XmCMenuWidget
#define XmCMenuWidget ((char*)&_XmStrings[2566])
#endif
#ifndef XmCMessageProc
#define XmCMessageProc ((char*)&_XmStrings[2577])
#endif
#ifndef XmCMessageWindow
#define XmCMessageWindow ((char*)&_XmStrings[2589])
#endif
#ifndef XmCMinimizeButtons
#define XmCMinimizeButtons ((char*)&_XmStrings[2603])
#endif
#ifndef XmCMinimum
#define XmCMinimum ((char*)&_XmStrings[2619])
#endif
#ifndef XmCMnemonic
#define XmCMnemonic ((char*)&_XmStrings[2627])
#endif
#ifndef XmCMnemonicCharSet
#define XmCMnemonicCharSet ((char*)&_XmStrings[2636])
#endif
#ifndef XmCMoveOpaque
#define XmCMoveOpaque ((char*)&_XmStrings[2652])
#endif
#ifndef XmCMultiClick
#define XmCMultiClick ((char*)&_XmStrings[2663])
#endif
#ifndef XmCMustMatch
#define XmCMustMatch ((char*)&_XmStrings[2674])
#endif
#ifndef XmCMwmDecorations
#define XmCMwmDecorations ((char*)&_XmStrings[2684])
#endif
#ifndef XmCMwmFunctions
#define XmCMwmFunctions ((char*)&_XmStrings[2699])
#endif
#ifndef XmCMwmInputMode
#define XmCMwmInputMode ((char*)&_XmStrings[2712])
#endif
#ifndef XmCMwmMenu
#define XmCMwmMenu ((char*)&_XmStrings[2725])
#endif
#ifndef XmCMwmMessages
#define XmCMwmMessages ((char*)&_XmStrings[2733])
#endif
#ifndef XmCNavigationType
#define XmCNavigationType ((char*)&_XmStrings[2745])
#endif
#ifndef XmCNeedsMotion
#define XmCNeedsMotion ((char*)&_XmStrings[2760])
#endif
#ifndef XmCNoMatchString
#define XmCNoMatchString ((char*)&_XmStrings[2772])
#endif
#ifndef XmCNoResize
#define XmCNoResize ((char*)&_XmStrings[2786])
#endif
#ifndef XmCNoneCursorForeground
#define XmCNoneCursorForeground ((char*)&_XmStrings[2795])
#endif
#ifndef XmCNotifyProc
#define XmCNotifyProc ((char*)&_XmStrings[2816])
#endif
#ifndef XmCNumChildren
#define XmCNumChildren ((char*)&_XmStrings[2827])
#endif
#ifndef XmCNumColumns
#define XmCNumColumns ((char*)&_XmStrings[2839])
#endif
#ifndef XmCNumDropRectangles
#define XmCNumDropRectangles ((char*)&_XmStrings[2850])
#endif
#ifndef XmCNumDropTransfers
#define XmCNumDropTransfers ((char*)&_XmStrings[2868])
#endif
#ifndef XmCNumExportTargets
#define XmCNumExportTargets ((char*)&_XmStrings[2885])
#endif
#ifndef XmCNumImportTargets
#define XmCNumImportTargets ((char*)&_XmStrings[2902])
#endif
#ifndef XmCOffset
#define XmCOffset ((char*)&_XmStrings[2919])
#endif
#ifndef XmCOkLabelString
#define XmCOkLabelString ((char*)&_XmStrings[2926])
#endif
#ifndef XmCOperationChangedCallback
#define XmCOperationChangedCallback ((char*)&_XmStrings[2940])
#endif
#ifndef XmCOperationCursorIcon
#define XmCOperationCursorIcon ((char*)&_XmStrings[2965])
#endif
#ifndef XmCOptionLabel
#define XmCOptionLabel ((char*)&_XmStrings[2985])
#endif
#ifndef XmCOptionMnemonic
#define XmCOptionMnemonic ((char*)&_XmStrings[2997])
#endif
#ifndef XmCOutputCreate
#define XmCOutputCreate ((char*)&_XmStrings[3012])
#endif
#ifndef XmCPacking
#define XmCPacking ((char*)&_XmStrings[3025])
#endif
#ifndef XmCPageIncrement
#define XmCPageIncrement ((char*)&_XmStrings[3033])
#endif
#ifndef XmCPaneMaximum
#define XmCPaneMaximum ((char*)&_XmStrings[3047])
#endif
#ifndef XmCPaneMinimum
#define XmCPaneMinimum ((char*)&_XmStrings[3059])
#endif
#ifndef XmCPattern
#define XmCPattern ((char*)&_XmStrings[3071])
#endif
#ifndef XmCPendingDelete
#define XmCPendingDelete ((char*)&_XmStrings[3079])
#endif
#ifndef XmCPopupEnabled
#define XmCPopupEnabled ((char*)&_XmStrings[3093])
#endif
#ifndef XmCPositionIndex
#define XmCPositionIndex ((char*)&_XmStrings[3106])
#endif
#ifndef XmCPostFromButton
#define XmCPostFromButton ((char*)&_XmStrings[3120])
#endif
#ifndef XmCPostFromCount
#define XmCPostFromCount ((char*)&_XmStrings[3135])
#endif
#ifndef XmCPostFromList
#define XmCPostFromList ((char*)&_XmStrings[3149])
#endif
#ifndef XmCPreeditType
#define XmCPreeditType ((char*)&_XmStrings[3162])
#endif
#ifndef XmCProcessingDirection
#define XmCProcessingDirection ((char*)&_XmStrings[3174])
#endif
#ifndef XmCPromptString
#define XmCPromptString ((char*)&_XmStrings[3194])
#endif
#ifndef XmCProtocolCallback
#define XmCProtocolCallback ((char*)&_XmStrings[3207])
#endif
#ifndef XmCPushButtonEnabled
#define XmCPushButtonEnabled ((char*)&_XmStrings[3224])
#endif
#ifndef XmCQualifySearchDataProc
#define XmCQualifySearchDataProc ((char*)&_XmStrings[3242])
#endif
#ifndef XmCRadioAlwaysOne
#define XmCRadioAlwaysOne ((char*)&_XmStrings[3264])
#endif
#ifndef XmCRadioBehavior
#define XmCRadioBehavior ((char*)&_XmStrings[3279])
#endif
#ifndef XmCRecomputeSize
#define XmCRecomputeSize ((char*)&_XmStrings[3293])
#endif
#ifndef XmCRectangles
#define XmCRectangles ((char*)&_XmStrings[3307])
#endif
#ifndef XmCRepeatDelay
#define XmCRepeatDelay ((char*)&_XmStrings[3318])
#endif
#ifndef XmCResizeCallback
#define XmCResizeCallback ((char*)&_XmStrings[3330])
#endif
#ifndef XmCResizeHeight
#define XmCResizeHeight ((char*)&_XmStrings[3345])
#endif
#ifndef XmCResizePolicy
#define XmCResizePolicy ((char*)&_XmStrings[3358])
#endif
#ifndef XmCResizeWidth
#define XmCResizeWidth ((char*)&_XmStrings[3371])
#endif
#ifndef XmCRowColumnType
#define XmCRowColumnType ((char*)&_XmStrings[3383])
#endif
#ifndef XmCRows
#define XmCRows ((char*)&_XmStrings[3397])
#endif
#ifndef XmCRubberPositioning
#define XmCRubberPositioning ((char*)&_XmStrings[3402])
#endif
#ifndef XmCSashHeight
#define XmCSashHeight ((char*)&_XmStrings[3420])
#endif
#ifndef XmCSashIndent
#define XmCSashIndent ((char*)&_XmStrings[3431])
#endif
#ifndef XmCSashWidth
#define XmCSashWidth ((char*)&_XmStrings[3442])
#endif
#ifndef XmCScaleHeight
#define XmCScaleHeight ((char*)&_XmStrings[3452])
#endif
#ifndef XmCScaleMultiple
#define XmCScaleMultiple ((char*)&_XmStrings[3464])
#endif
#ifndef XmCScaleWidth
#define XmCScaleWidth ((char*)&_XmStrings[3478])
#endif
#ifndef XmCScroll
#define XmCScroll ((char*)&_XmStrings[3489])
#endif
#ifndef XmCScrollBarDisplayPolicy
#define XmCScrollBarDisplayPolicy ((char*)&_XmStrings[3496])
#endif
#ifndef XmCScrollBarPlacement
#define XmCScrollBarPlacement ((char*)&_XmStrings[3519])
#endif
#ifndef XmCScrollSide
#define XmCScrollSide ((char*)&_XmStrings[3538])
#endif
#ifndef XmCScrolledWindowMarginHeight
#define XmCScrolledWindowMarginHeight ((char*)&_XmStrings[3549])
#endif
#ifndef XmCScrolledWindowMarginWidth
#define XmCScrolledWindowMarginWidth ((char*)&_XmStrings[3576])
#endif
#ifndef XmCScrollingPolicy
#define XmCScrollingPolicy ((char*)&_XmStrings[3602])
#endif
#ifndef XmCSelectColor
#define XmCSelectColor ((char*)&_XmStrings[3618])
#endif
#ifndef XmCSelectInsensitivePixmap
#define XmCSelectInsensitivePixmap ((char*)&_XmStrings[3630])
#endif
#ifndef XmCSelectPixmap
#define XmCSelectPixmap ((char*)&_XmStrings[3654])
#endif
#ifndef XmCSelectThreshold
#define XmCSelectThreshold ((char*)&_XmStrings[3667])
#endif
#ifndef XmCSelectedItemCount
#define XmCSelectedItemCount ((char*)&_XmStrings[3683])
#endif
#ifndef XmCSelectedItems
#define XmCSelectedItems ((char*)&_XmStrings[3701])
#endif
#ifndef XmCSelectionArrayCount
#define XmCSelectionArrayCount ((char*)&_XmStrings[3715])
#endif
#ifndef XmCSelectionLabelString
#define XmCSelectionLabelString ((char*)&_XmStrings[3735])
#endif
#ifndef XmCSelectionPolicy
#define XmCSelectionPolicy ((char*)&_XmStrings[3756])
#endif
#ifndef XmCSeparatorOn
#define XmCSeparatorOn ((char*)&_XmStrings[3772])
#endif
#ifndef XmCSeparatorType
#define XmCSeparatorType ((char*)&_XmStrings[3784])
#endif
#ifndef XmCSet
#define XmCSet ((char*)&_XmStrings[3798])
#endif
#ifndef XmCShadowThickness
#define XmCShadowThickness ((char*)&_XmStrings[3802])
#endif
#ifndef XmCShadowType
#define XmCShadowType ((char*)&_XmStrings[3818])
#endif
#ifndef XmCShellUnitType
#define XmCShellUnitType ((char*)&_XmStrings[3829])
#endif
#ifndef XmCShowArrows
#define XmCShowArrows ((char*)&_XmStrings[3843])
#endif
#ifndef XmCShowAsDefault
#define XmCShowAsDefault ((char*)&_XmStrings[3854])
#endif
#ifndef XmCShowSeparator
#define XmCShowSeparator ((char*)&_XmStrings[3868])
#endif
#ifndef XmCShowValue
#define XmCShowValue ((char*)&_XmStrings[3882])
#endif
#ifndef XmCSimpleCheckBox
#define XmCSimpleCheckBox ((char*)&_XmStrings[3892])
#endif
#ifndef XmCSimpleMenuBar
#define XmCSimpleMenuBar ((char*)&_XmStrings[3907])
#endif
#ifndef XmCSimpleOptionMenu
#define XmCSimpleOptionMenu ((char*)&_XmStrings[3921])
#endif
#ifndef XmCSimplePopupMenu
#define XmCSimplePopupMenu ((char*)&_XmStrings[3938])
#endif
#ifndef XmCSimplePulldownMenu
#define XmCSimplePulldownMenu ((char*)&_XmStrings[3954])
#endif
#ifndef XmCSimpleRadioBox
#define XmCSimpleRadioBox ((char*)&_XmStrings[3973])
#endif
#ifndef XmCSizePolicy
#define XmCSizePolicy ((char*)&_XmStrings[3988])
#endif
#ifndef XmCSliderSize
#define XmCSliderSize ((char*)&_XmStrings[3999])
#endif
#ifndef XmCSource
#define XmCSource ((char*)&_XmStrings[4010])
#endif
#ifndef XmCSourceCursorIcon
#define XmCSourceCursorIcon ((char*)&_XmStrings[4017])
#endif
#ifndef XmCSourceIsExternal
#define XmCSourceIsExternal ((char*)&_XmStrings[4034])
#endif
#ifndef XmCSourcePixmapIcon
#define XmCSourcePixmapIcon ((char*)&_XmStrings[4051])
#endif
#ifndef XmCSourceWidget
#define XmCSourceWidget ((char*)&_XmStrings[4068])
#endif
#ifndef XmCSourceWindow
#define XmCSourceWindow ((char*)&_XmStrings[4081])
#endif
#ifndef XmCSpacing
#define XmCSpacing ((char*)&_XmStrings[4094])
#endif
#ifndef XmCStartTime
#define XmCStartTime ((char*)&_XmStrings[4102])
#endif
#ifndef XmCStateCursorIcon
#define XmCStateCursorIcon ((char*)&_XmStrings[4112])
#endif
#ifndef XmCStringDirection
#define XmCStringDirection ((char*)&_XmStrings[4128])
#endif
#ifndef XmCTearOffModel
#define XmCTearOffModel ((char*)&_XmStrings[4144])
#endif
#ifndef XmCTextFontList
#define XmCTextFontList ((char*)&_XmStrings[4157])
#endif
#ifndef XmCTextString
#define XmCTextString ((char*)&_XmStrings[4170])
#endif
#ifndef XmCTextValue
#define XmCTextValue ((char*)&_XmStrings[4181])
#endif
#ifndef XmCTitleString
#define XmCTitleString ((char*)&_XmStrings[4191])
#endif
#ifndef XmCTopCharacter
#define XmCTopCharacter ((char*)&_XmStrings[4203])
#endif
#ifndef XmCTopItemPosition
#define XmCTopItemPosition ((char*)&_XmStrings[4216])
#endif
#ifndef XmCTopLevelEnterCallback
#define XmCTopLevelEnterCallback ((char*)&_XmStrings[4232])
#endif
#ifndef XmCTopLevelLeaveCallback
#define XmCTopLevelLeaveCallback ((char*)&_XmStrings[4254])
#endif
#ifndef XmCTopShadowColor
#define XmCTopShadowColor ((char*)&_XmStrings[4276])
#endif
#ifndef XmCTopShadowPixmap
#define XmCTopShadowPixmap ((char*)&_XmStrings[4291])
#endif
#ifndef XmCTransferProc
#define XmCTransferProc ((char*)&_XmStrings[4307])
#endif
#ifndef XmCTransferStatus
#define XmCTransferStatus ((char*)&_XmStrings[4320])
#endif
#ifndef XmCTraversalOn
#define XmCTraversalOn ((char*)&_XmStrings[4335])
#endif
#ifndef XmCTraversalType
#define XmCTraversalType ((char*)&_XmStrings[4347])
#endif
#ifndef XmCTreeUpdateProc
#define XmCTreeUpdateProc ((char*)&_XmStrings[4361])
#endif
#ifndef XmCTroughColor
#define XmCTroughColor ((char*)&_XmStrings[4376])
#endif
#ifndef XmCUnitType
#define XmCUnitType ((char*)&_XmStrings[4388])
#endif
#ifndef XmCUnpostBehavior
#define XmCUnpostBehavior ((char*)&_XmStrings[4397])
#endif
#ifndef XmCUnselectPixmap
#define XmCUnselectPixmap ((char*)&_XmStrings[4412])
#endif
#ifndef XmCUpdateSliderSize
#define XmCUpdateSliderSize ((char*)&_XmStrings[4427])
#endif
#ifndef XmCUseAsyncGeometry
#define XmCUseAsyncGeometry ((char*)&_XmStrings[4444])
#endif
#ifndef XmCUserData
#define XmCUserData ((char*)&_XmStrings[4461])
#endif
#ifndef XmCValidCursorForeground
#define XmCValidCursorForeground ((char*)&_XmStrings[4470])
#endif
#ifndef XmCValueChangedCallback
#define XmCValueChangedCallback ((char*)&_XmStrings[4492])
#endif
#ifndef XmCValueWcs
#define XmCValueWcs ((char*)&_XmStrings[4513])
#endif
#ifndef XmCVerifyBell
#define XmCVerifyBell ((char*)&_XmStrings[4522])
#endif
#ifndef XmCVerticalAlignment
#define XmCVerticalAlignment ((char*)&_XmStrings[4533])
#endif
#ifndef XmCVerticalFontUnit
#define XmCVerticalFontUnit ((char*)&_XmStrings[4551])
#endif
#ifndef XmCVerticalScrollBar
#define XmCVerticalScrollBar ((char*)&_XmStrings[4568])
#endif
#ifndef XmCVisibleItemCount
#define XmCVisibleItemCount ((char*)&_XmStrings[4586])
#endif
#ifndef XmCVisibleWhenOff
#define XmCVisibleWhenOff ((char*)&_XmStrings[4603])
#endif
#ifndef XmCVisualPolicy
#define XmCVisualPolicy ((char*)&_XmStrings[4618])
#endif
#ifndef XmCWhichButton
#define XmCWhichButton ((char*)&_XmStrings[4631])
#endif
#ifndef XmCWordWrap
#define XmCWordWrap ((char*)&_XmStrings[4643])
#endif
#ifndef XmCWorkWindow
#define XmCWorkWindow ((char*)&_XmStrings[4652])
#endif
#ifndef XmCXmString
#define XmCXmString ((char*)&_XmStrings[4663])
#endif
#ifndef XmNaccelerator
#define XmNaccelerator ((char*)&_XmStrings[4672])
#endif
#ifndef XmNacceleratorText
#define XmNacceleratorText ((char*)&_XmStrings[4684])
#endif
#ifndef XmNactivateCallback
#define XmNactivateCallback ((char*)&_XmStrings[4700])
#endif
#ifndef XmNadjustLast
#define XmNadjustLast ((char*)&_XmStrings[4717])
#endif
#ifndef XmNadjustMargin
#define XmNadjustMargin ((char*)&_XmStrings[4728])
#endif
#ifndef XmNalignment
#define XmNalignment ((char*)&_XmStrings[4741])
#endif
#ifndef XmNallowOverlap
#define XmNallowOverlap ((char*)&_XmStrings[4751])
#endif
#ifndef XmNallowResize
#define XmNallowResize ((char*)&_XmStrings[4764])
#endif
#ifndef XmNallowUnusedSpace
#define XmNallowUnusedSpace ((char*)&_XmStrings[4776])
#endif
#ifndef XmNanimationMask
#define XmNanimationMask ((char*)&_XmStrings[4793])
#endif
#ifndef XmNanimationPixmap
#define XmNanimationPixmap ((char*)&_XmStrings[4807])
#endif
#ifndef XmNanimationPixmapDepth
#define XmNanimationPixmapDepth ((char*)&_XmStrings[4823])
#endif
#ifndef XmNanimationStyle
#define XmNanimationStyle ((char*)&_XmStrings[4844])
#endif
#ifndef XmNapplyCallback
#define XmNapplyCallback ((char*)&_XmStrings[4859])
#endif
#ifndef XmNapplyLabelString
#define XmNapplyLabelString ((char*)&_XmStrings[4873])
#endif
#ifndef XmNarmCallback
#define XmNarmCallback ((char*)&_XmStrings[4890])
#endif
#ifndef XmNarmColor
#define XmNarmColor ((char*)&_XmStrings[4902])
#endif
#ifndef XmNarmPixmap
#define XmNarmPixmap ((char*)&_XmStrings[4911])
#endif
#ifndef XmNarrowDirection
#define XmNarrowDirection ((char*)&_XmStrings[4921])
#endif
#ifndef XmNattachment
#define XmNattachment ((char*)&_XmStrings[4936])
#endif
#ifndef XmNaudibleWarning
#define XmNaudibleWarning ((char*)&_XmStrings[4947])
#endif
#ifndef XmNautoShowCursorPosition
#define XmNautoShowCursorPosition ((char*)&_XmStrings[4962])
#endif
#ifndef XmNautoUnmanage
#define XmNautoUnmanage ((char*)&_XmStrings[4985])
#endif
#ifndef XmNautomaticSelection
#define XmNautomaticSelection ((char*)&_XmStrings[4998])
#endif
#ifndef XmNavailability
#define XmNavailability ((char*)&_XmStrings[5017])
#endif
#ifndef XmNblendModel
#define XmNblendModel ((char*)&_XmStrings[5030])
#endif
#ifndef XmNblinkRate
#define XmNblinkRate ((char*)&_XmStrings[5041])
#endif
#ifndef XmNbottomAttachment
#define XmNbottomAttachment ((char*)&_XmStrings[5051])
#endif
#ifndef XmNbottomOffset
#define XmNbottomOffset ((char*)&_XmStrings[5068])
#endif
#ifndef XmNbottomPosition
#define XmNbottomPosition ((char*)&_XmStrings[5081])
#endif
#ifndef XmNbottomShadowColor
#define XmNbottomShadowColor ((char*)&_XmStrings[5096])
#endif
#ifndef XmNbottomShadowPixmap
#define XmNbottomShadowPixmap ((char*)&_XmStrings[5114])
#endif
#ifndef XmNbottomWidget
#define XmNbottomWidget ((char*)&_XmStrings[5133])
#endif
#ifndef XmNbrowseSelectionCallback
#define XmNbrowseSelectionCallback ((char*)&_XmStrings[5146])
#endif
#ifndef XmNbuttonAcceleratorText
#define XmNbuttonAcceleratorText ((char*)&_XmStrings[5170])
#endif
#ifndef XmNbuttonAccelerators
#define XmNbuttonAccelerators ((char*)&_XmStrings[5192])
#endif
#ifndef XmNbuttonCount
#define XmNbuttonCount ((char*)&_XmStrings[5211])
#endif
#ifndef XmNbuttonFontList
#define XmNbuttonFontList ((char*)&_XmStrings[5223])
#endif
#ifndef XmNbuttonMnemonicCharSets
#define XmNbuttonMnemonicCharSets ((char*)&_XmStrings[5238])
#endif
#ifndef XmNbuttonMnemonics
#define XmNbuttonMnemonics ((char*)&_XmStrings[5261])
#endif
#ifndef XmNbuttonSet
#define XmNbuttonSet ((char*)&_XmStrings[5277])
#endif
#ifndef XmNbuttonType
#define XmNbuttonType ((char*)&_XmStrings[5287])
#endif
#ifndef XmNbuttons
#define XmNbuttons ((char*)&_XmStrings[5298])
#endif
#ifndef XmNcancelButton
#define XmNcancelButton ((char*)&_XmStrings[5306])
#endif
#ifndef XmNcancelCallback
#define XmNcancelCallback ((char*)&_XmStrings[5319])
#endif
#ifndef XmNcancelLabelString
#define XmNcancelLabelString ((char*)&_XmStrings[5334])
#endif
#ifndef XmNcascadePixmap
#define XmNcascadePixmap ((char*)&_XmStrings[5352])
#endif
#ifndef XmNcascadingCallback
#define XmNcascadingCallback ((char*)&_XmStrings[5366])
#endif
#ifndef XmNchildHorizontalAlignment
#define XmNchildHorizontalAlignment ((char*)&_XmStrings[5384])
#endif
#ifndef XmNchildHorizontalSpacing
#define XmNchildHorizontalSpacing ((char*)&_XmStrings[5409])
#endif
#ifndef XmNchildPlacement
#define XmNchildPlacement ((char*)&_XmStrings[5432])
#endif
#ifndef XmNchildPosition
#define XmNchildPosition ((char*)&_XmStrings[5447])
#endif
#ifndef XmNchildType
#define XmNchildType ((char*)&_XmStrings[5461])
#endif
#ifndef XmNchildVerticalAlignment
#define XmNchildVerticalAlignment ((char*)&_XmStrings[5471])
#endif
#ifndef XmNclientData
#define XmNclientData ((char*)&_XmStrings[5494])
#endif
#ifndef XmNclipWindow
#define XmNclipWindow ((char*)&_XmStrings[5505])
#endif
#ifndef XmNcolumns
#define XmNcolumns ((char*)&_XmStrings[5516])
#endif
#ifndef XmNcommand
#define XmNcommand ((char*)&_XmStrings[5524])
#endif
#ifndef XmNcommandChangedCallback
#define XmNcommandChangedCallback ((char*)&_XmStrings[5532])
#endif
#ifndef XmNcommandEnteredCallback
#define XmNcommandEnteredCallback ((char*)&_XmStrings[5555])
#endif
#ifndef XmNcommandWindow
#define XmNcommandWindow ((char*)&_XmStrings[5578])
#endif
#ifndef XmNcommandWindowLocation
#define XmNcommandWindowLocation ((char*)&_XmStrings[5592])
#endif
#ifndef XmNconvertProc
#define XmNconvertProc ((char*)&_XmStrings[5614])
#endif
#ifndef XmNcursorBackground
#define XmNcursorBackground ((char*)&_XmStrings[5626])
#endif
#ifndef XmNcursorForeground
#define XmNcursorForeground ((char*)&_XmStrings[5643])
#endif
#ifndef XmNcursorPosition
#define XmNcursorPosition ((char*)&_XmStrings[5660])
#endif
#ifndef XmNcursorPositionVisible
#define XmNcursorPositionVisible ((char*)&_XmStrings[5675])
#endif
#ifndef XmNdarkThreshold
#define XmNdarkThreshold ((char*)&_XmStrings[5697])
#endif
#ifndef XmNdecimalPoints
#define XmNdecimalPoints ((char*)&_XmStrings[5711])
#endif
#ifndef XmNdecrementCallback
#define XmNdecrementCallback ((char*)&_XmStrings[5725])
#endif
#ifndef XmNdefaultActionCallback
#define XmNdefaultActionCallback ((char*)&_XmStrings[5743])
#endif
#ifndef XmNdefaultButton
#define XmNdefaultButton ((char*)&_XmStrings[5765])
#endif
#ifndef XmNdefaultButtonShadowThickness
#define XmNdefaultButtonShadowThickness ((char*)&_XmStrings[5779])
#endif
#ifndef XmNdefaultButtonType
#define XmNdefaultButtonType ((char*)&_XmStrings[5808])
#endif
#ifndef XmNdefaultCopyCursorIcon
#define XmNdefaultCopyCursorIcon ((char*)&_XmStrings[5826])
#endif
#ifndef XmNdefaultFontList
#define XmNdefaultFontList ((char*)&_XmStrings[5848])
#endif
#ifndef XmNdefaultInvalidCursorIcon
#define XmNdefaultInvalidCursorIcon ((char*)&_XmStrings[5864])
#endif
#ifndef XmNdefaultLinkCursorIcon
#define XmNdefaultLinkCursorIcon ((char*)&_XmStrings[5889])
#endif
#ifndef XmNdefaultMoveCursorIcon
#define XmNdefaultMoveCursorIcon ((char*)&_XmStrings[5911])
#endif
#ifndef XmNdefaultNoneCursorIcon
#define XmNdefaultNoneCursorIcon ((char*)&_XmStrings[5933])
#endif
#ifndef XmNdefaultPosition
#define XmNdefaultPosition ((char*)&_XmStrings[5955])
#endif
#ifndef XmNdefaultSourceCursorIcon
#define XmNdefaultSourceCursorIcon ((char*)&_XmStrings[5971])
#endif
#ifndef XmNdefaultValidCursorIcon
#define XmNdefaultValidCursorIcon ((char*)&_XmStrings[5995])
#endif
#ifndef XmNdeleteResponse
#define XmNdeleteResponse ((char*)&_XmStrings[6018])
#endif
#ifndef XmNdesktopParent
#define XmNdesktopParent ((char*)&_XmStrings[6033])
#endif
#ifndef XmNdialogStyle
#define XmNdialogStyle ((char*)&_XmStrings[6047])
#endif
#ifndef XmNdialogTitle
#define XmNdialogTitle ((char*)&_XmStrings[6059])
#endif
#ifndef XmNdialogType
#define XmNdialogType ((char*)&_XmStrings[6071])
#endif
#ifndef XmNdirListItemCount
#define XmNdirListItemCount ((char*)&_XmStrings[6082])
#endif
#ifndef XmNdirListItems
#define XmNdirListItems ((char*)&_XmStrings[6099])
#endif
#ifndef XmNdirListLabelString
#define XmNdirListLabelString ((char*)&_XmStrings[6112])
#endif
#ifndef XmNdirMask
#define XmNdirMask ((char*)&_XmStrings[6131])
#endif
#ifndef XmNdirSearchProc
#define XmNdirSearchProc ((char*)&_XmStrings[6139])
#endif
#ifndef XmNdirSpec
#define XmNdirSpec ((char*)&_XmStrings[6153])
#endif
#ifndef XmNdirectory
#define XmNdirectory ((char*)&_XmStrings[6161])
#endif
#ifndef XmNdirectoryValid
#define XmNdirectoryValid ((char*)&_XmStrings[6171])
#endif
#ifndef XmNdisarmCallback
#define XmNdisarmCallback ((char*)&_XmStrings[6186])
#endif
#ifndef XmNdoubleClickInterval
#define XmNdoubleClickInterval ((char*)&_XmStrings[6201])
#endif
#ifndef XmNdragCallback
#define XmNdragCallback ((char*)&_XmStrings[6221])
#endif
#ifndef XmNdragContextClass
#define XmNdragContextClass ((char*)&_XmStrings[6234])
#endif
#ifndef XmNdragDropFinishCallback
#define XmNdragDropFinishCallback ((char*)&_XmStrings[6251])
#endif
#ifndef XmNdragIconClass
#define XmNdragIconClass ((char*)&_XmStrings[6274])
#endif
#ifndef XmNdragInitiatorProtocolStyle
#define XmNdragInitiatorProtocolStyle ((char*)&_XmStrings[6288])
#endif
#ifndef XmNdragMotionCallback
#define XmNdragMotionCallback ((char*)&_XmStrings[6315])
#endif
#ifndef XmNdragOperations
#define XmNdragOperations ((char*)&_XmStrings[6334])
#endif
#ifndef XmNdragOverMode
#define XmNdragOverMode ((char*)&_XmStrings[6349])
#endif
#ifndef XmNdragProc
#define XmNdragProc ((char*)&_XmStrings[6362])
#endif
#ifndef XmNdragReceiverProtocolStyle
#define XmNdragReceiverProtocolStyle ((char*)&_XmStrings[6371])
#endif
#ifndef XmNdropFinishCallback
#define XmNdropFinishCallback ((char*)&_XmStrings[6397])
#endif
#ifndef XmNdropProc
#define XmNdropProc ((char*)&_XmStrings[6416])
#endif
#ifndef XmNdropRectangles
#define XmNdropRectangles ((char*)&_XmStrings[6425])
#endif
#ifndef XmNdropSiteActivity
#define XmNdropSiteActivity ((char*)&_XmStrings[6440])
#endif
#ifndef XmNdropSiteEnterCallback
#define XmNdropSiteEnterCallback ((char*)&_XmStrings[6457])
#endif
#ifndef XmNdropSiteLeaveCallback
#define XmNdropSiteLeaveCallback ((char*)&_XmStrings[6479])
#endif
#ifndef XmNdropSiteManagerClass
#define XmNdropSiteManagerClass ((char*)&_XmStrings[6501])
#endif
#ifndef XmNdropSiteOperations
#define XmNdropSiteOperations ((char*)&_XmStrings[6522])
#endif
#ifndef XmNdropSiteType
#define XmNdropSiteType ((char*)&_XmStrings[6541])
#endif
#ifndef XmNdropStartCallback
#define XmNdropStartCallback ((char*)&_XmStrings[6554])
#endif
#ifndef XmNdropTransferClass
#define XmNdropTransferClass ((char*)&_XmStrings[6572])
#endif
#ifndef XmNdropTransfers
#define XmNdropTransfers ((char*)&_XmStrings[6590])
#endif
#ifndef XmNeditMode
#define XmNeditMode ((char*)&_XmStrings[6604])
#endif
#ifndef XmNeditable
#define XmNeditable ((char*)&_XmStrings[6613])
#endif
#ifndef XmNentryAlignment
#define XmNentryAlignment ((char*)&_XmStrings[6622])
#endif
#ifndef XmNentryBorder
#define XmNentryBorder ((char*)&_XmStrings[6637])
#endif
#ifndef XmNentryCallback
#define XmNentryCallback ((char*)&_XmStrings[6649])
#endif
#ifndef XmNentryClass
#define XmNentryClass ((char*)&_XmStrings[6663])
#endif
#ifndef XmNentryVerticalAlignment
#define XmNentryVerticalAlignment ((char*)&_XmStrings[6674])
#endif
#ifndef XmNexportTargets
#define XmNexportTargets ((char*)&_XmStrings[6697])
#endif
#ifndef XmNexposeCallback
#define XmNexposeCallback ((char*)&_XmStrings[6711])
#endif
#ifndef XmNextendedSelectionCallback
#define XmNextendedSelectionCallback ((char*)&_XmStrings[6726])
#endif
#ifndef XmNextensionType
#define XmNextensionType ((char*)&_XmStrings[6752])
#endif
#ifndef XmNfileListItemCount
#define XmNfileListItemCount ((char*)&_XmStrings[6766])
#endif
#ifndef XmNfileListItems
#define XmNfileListItems ((char*)&_XmStrings[6784])
#endif
#ifndef XmNfileListLabelString
#define XmNfileListLabelString ((char*)&_XmStrings[6798])
#endif
#ifndef XmNfileSearchProc
#define XmNfileSearchProc ((char*)&_XmStrings[6818])
#endif
#ifndef XmNfileTypeMask
#define XmNfileTypeMask ((char*)&_XmStrings[6833])
#endif
#ifndef XmNfillOnArm
#define XmNfillOnArm ((char*)&_XmStrings[6846])
#endif
#ifndef XmNfillOnSelect
#define XmNfillOnSelect ((char*)&_XmStrings[6856])
#endif
#ifndef XmNfilterLabelString
#define XmNfilterLabelString ((char*)&_XmStrings[6869])
#endif
#ifndef XmNfocusCallback
#define XmNfocusCallback ((char*)&_XmStrings[6887])
#endif
#ifndef XmNfocusMovedCallback
#define XmNfocusMovedCallback ((char*)&_XmStrings[6901])
#endif
#ifndef XmNfocusPolicyChanged
#define XmNfocusPolicyChanged ((char*)&_XmStrings[6920])
#endif
#ifndef XmNfontList
#define XmNfontList ((char*)&_XmStrings[6939])
#endif
#ifndef XmNforegroundThreshold
#define XmNforegroundThreshold ((char*)&_XmStrings[6948])
#endif
#ifndef XmNfractionBase
#define XmNfractionBase ((char*)&_XmStrings[6968])
#endif
#ifndef XmNgainPrimaryCallback
#define XmNgainPrimaryCallback ((char*)&_XmStrings[6981])
#endif
#ifndef XmNhelpCallback
#define XmNhelpCallback ((char*)&_XmStrings[7001])
#endif
#ifndef XmNhelpLabelString
#define XmNhelpLabelString ((char*)&_XmStrings[7014])
#endif
#ifndef XmNhighlightColor
#define XmNhighlightColor ((char*)&_XmStrings[7030])
#endif
#ifndef XmNhighlightOnEnter
#define XmNhighlightOnEnter ((char*)&_XmStrings[7045])
#endif
#ifndef XmNhighlightPixmap
#define XmNhighlightPixmap ((char*)&_XmStrings[7062])
#endif
#ifndef XmNhighlightThickness
#define XmNhighlightThickness ((char*)&_XmStrings[7078])
#endif
#ifndef XmNhistoryItemCount
#define XmNhistoryItemCount ((char*)&_XmStrings[7097])
#endif
#ifndef XmNhistoryItems
#define XmNhistoryItems ((char*)&_XmStrings[7114])
#endif
#ifndef XmNhistoryMaxItems
#define XmNhistoryMaxItems ((char*)&_XmStrings[7127])
#endif
#ifndef XmNhistoryVisibleItemCount
#define XmNhistoryVisibleItemCount ((char*)&_XmStrings[7143])
#endif
#ifndef XmNhorizontalFontUnit
#define XmNhorizontalFontUnit ((char*)&_XmStrings[7167])
#endif
#ifndef XmNhorizontalScrollBar
#define XmNhorizontalScrollBar ((char*)&_XmStrings[7186])
#endif
#ifndef XmNhorizontalSpacing
#define XmNhorizontalSpacing ((char*)&_XmStrings[7206])
#endif
#ifndef XmNhotX
#define XmNhotX ((char*)&_XmStrings[7224])
#endif
#ifndef XmNhotY
#define XmNhotY ((char*)&_XmStrings[7229])
#endif
#ifndef XmNiccHandle
#define XmNiccHandle ((char*)&_XmStrings[7234])
#endif
#ifndef XmNimportTargets
#define XmNimportTargets ((char*)&_XmStrings[7244])
#endif
#ifndef XmNincrement
#define XmNincrement ((char*)&_XmStrings[7258])
#endif
#ifndef XmNincrementCallback
#define XmNincrementCallback ((char*)&_XmStrings[7268])
#endif
#ifndef XmNincremental
#define XmNincremental ((char*)&_XmStrings[7286])
#endif
#ifndef XmNindicatorOn
#define XmNindicatorOn ((char*)&_XmStrings[7298])
#endif
#ifndef XmNindicatorSize
#define XmNindicatorSize ((char*)&_XmStrings[7310])
#endif
#ifndef XmNindicatorType
#define XmNindicatorType ((char*)&_XmStrings[7324])
#endif
#ifndef XmNinitialDelay
#define XmNinitialDelay ((char*)&_XmStrings[7338])
#endif
#ifndef XmNinitialFocus
#define XmNinitialFocus ((char*)&_XmStrings[7351])
#endif
#ifndef XmNinputCallback
#define XmNinputCallback ((char*)&_XmStrings[7364])
#endif
#ifndef XmNinputCreate
#define XmNinputCreate ((char*)&_XmStrings[7378])
#endif
#ifndef XmNinputMethod
#define XmNinputMethod ((char*)&_XmStrings[7390])
#endif
#ifndef XmNinvalidCursorForeground
#define XmNinvalidCursorForeground ((char*)&_XmStrings[7402])
#endif
#ifndef XmNisAligned
#define XmNisAligned ((char*)&_XmStrings[7426])
#endif
#ifndef XmNisHomogeneous
#define XmNisHomogeneous ((char*)&_XmStrings[7436])
#endif
#ifndef XmNitemCount
#define XmNitemCount ((char*)&_XmStrings[7450])
#endif
#ifndef XmNitems
#define XmNitems ((char*)&_XmStrings[7460])
#endif
#ifndef XmNkeyboardFocusPolicy
#define XmNkeyboardFocusPolicy ((char*)&_XmStrings[7466])
#endif
#ifndef XmNlabelFontList
#define XmNlabelFontList ((char*)&_XmStrings[7486])
#endif
#ifndef XmNlabelInsensitivePixmap
#define XmNlabelInsensitivePixmap ((char*)&_XmStrings[7500])
#endif
#ifndef XmNlabelPixmap
#define XmNlabelPixmap ((char*)&_XmStrings[7523])
#endif
#ifndef XmNlabelString
#define XmNlabelString ((char*)&_XmStrings[7535])
#endif
#ifndef XmNlabelType
#define XmNlabelType ((char*)&_XmStrings[7547])
#endif
#ifndef XmNleftAttachment
#define XmNleftAttachment ((char*)&_XmStrings[7557])
#endif
#ifndef XmNleftOffset
#define XmNleftOffset ((char*)&_XmStrings[7572])
#endif
#ifndef XmNleftPosition
#define XmNleftPosition ((char*)&_XmStrings[7583])
#endif
#ifndef XmNleftWidget
#define XmNleftWidget ((char*)&_XmStrings[7596])
#endif
#ifndef XmNlightThreshold
#define XmNlightThreshold ((char*)&_XmStrings[7607])
#endif
#ifndef XmNlineSpace
#define XmNlineSpace ((char*)&_XmStrings[7622])
#endif
#ifndef XmNlistItemCount
#define XmNlistItemCount ((char*)&_XmStrings[7632])
#endif
#ifndef XmNlistItems
#define XmNlistItems ((char*)&_XmStrings[7646])
#endif
#ifndef XmNlistLabelString
#define XmNlistLabelString ((char*)&_XmStrings[7656])
#endif
#ifndef XmNlistMarginHeight
#define XmNlistMarginHeight ((char*)&_XmStrings[7672])
#endif
#ifndef XmNlistMarginWidth
#define XmNlistMarginWidth ((char*)&_XmStrings[7689])
#endif
#ifndef XmNlistSizePolicy
#define XmNlistSizePolicy ((char*)&_XmStrings[7705])
#endif
#ifndef XmNlistSpacing
#define XmNlistSpacing ((char*)&_XmStrings[7720])
#endif
#ifndef XmNlistUpdated
#define XmNlistUpdated ((char*)&_XmStrings[7732])
#endif
#ifndef XmNlistVisibleItemCount
#define XmNlistVisibleItemCount ((char*)&_XmStrings[7744])
#endif
#ifndef XmNlogicalParent
#define XmNlogicalParent ((char*)&_XmStrings[7765])
#endif
#ifndef XmNlosePrimaryCallback
#define XmNlosePrimaryCallback ((char*)&_XmStrings[7779])
#endif
#ifndef XmNlosingFocusCallback
#define XmNlosingFocusCallback ((char*)&_XmStrings[7799])
#endif
#ifndef XmNmainWindowMarginHeight
#define XmNmainWindowMarginHeight ((char*)&_XmStrings[7819])
#endif
#ifndef XmNmainWindowMarginWidth
#define XmNmainWindowMarginWidth ((char*)&_XmStrings[7842])
#endif
#ifndef XmNmapCallback
#define XmNmapCallback ((char*)&_XmStrings[7864])
#endif
#ifndef XmNmappingDelay
#define XmNmappingDelay ((char*)&_XmStrings[7876])
#endif
#ifndef XmNmargin
#define XmNmargin ((char*)&_XmStrings[7889])
#endif
#ifndef XmNmarginBottom
#define XmNmarginBottom ((char*)&_XmStrings[7896])
#endif
#ifndef XmNmarginHeight
#define XmNmarginHeight ((char*)&_XmStrings[7909])
#endif
#ifndef XmNmarginLeft
#define XmNmarginLeft ((char*)&_XmStrings[7922])
#endif
#ifndef XmNmarginRight
#define XmNmarginRight ((char*)&_XmStrings[7933])
#endif
#ifndef XmNmarginTop
#define XmNmarginTop ((char*)&_XmStrings[7945])
#endif
#ifndef XmNmarginWidth
#define XmNmarginWidth ((char*)&_XmStrings[7955])
#endif
#ifndef XmNmask
#define XmNmask ((char*)&_XmStrings[7967])
#endif
#ifndef XmNmaxLength
#define XmNmaxLength ((char*)&_XmStrings[7972])
#endif
#ifndef XmNmaximum
#define XmNmaximum ((char*)&_XmStrings[7982])
#endif
#ifndef XmNmenuAccelerator
#define XmNmenuAccelerator ((char*)&_XmStrings[7990])
#endif
#ifndef XmNmenuBar
#define XmNmenuBar ((char*)&_XmStrings[8006])
#endif
#ifndef XmNmenuCursor
#define XmNmenuCursor ((char*)&_XmStrings[8014])
#endif
#ifndef XmNmenuHelpWidget
#define XmNmenuHelpWidget ((char*)&_XmStrings[8025])
#endif
#ifndef XmNmenuHistory
#define XmNmenuHistory ((char*)&_XmStrings[8040])
#endif
#ifndef XmNmenuPost
#define XmNmenuPost ((char*)&_XmStrings[8052])
#endif
#ifndef XmNmessageAlignment
#define XmNmessageAlignment ((char*)&_XmStrings[8061])
#endif
#ifndef XmNmessageProc
#define XmNmessageProc ((char*)&_XmStrings[8078])
#endif
#ifndef XmNmessageString
#define XmNmessageString ((char*)&_XmStrings[8090])
#endif
#ifndef XmNmessageWindow
#define XmNmessageWindow ((char*)&_XmStrings[8104])
#endif
#ifndef XmNminimizeButtons
#define XmNminimizeButtons ((char*)&_XmStrings[8118])
#endif
#ifndef XmNminimum
#define XmNminimum ((char*)&_XmStrings[8134])
#endif
#ifndef XmNmnemonic
#define XmNmnemonic ((char*)&_XmStrings[8142])
#endif
#ifndef XmNmnemonicCharSet
#define XmNmnemonicCharSet ((char*)&_XmStrings[8151])
#endif
#ifndef XmNmodifyVerifyCallback
#define XmNmodifyVerifyCallback ((char*)&_XmStrings[8167])
#endif
#ifndef XmNmodifyVerifyCallbackWcs
#define XmNmodifyVerifyCallbackWcs ((char*)&_XmStrings[8188])
#endif
#ifndef XmNmotionVerifyCallback
#define XmNmotionVerifyCallback ((char*)&_XmStrings[8212])
#endif
#ifndef XmNmoveOpaque
#define XmNmoveOpaque ((char*)&_XmStrings[8233])
#endif
#ifndef XmNmultiClick
#define XmNmultiClick ((char*)&_XmStrings[8244])
#endif
#ifndef XmNmultipleSelectionCallback
#define XmNmultipleSelectionCallback ((char*)&_XmStrings[8255])
#endif
#ifndef XmNmustMatch
#define XmNmustMatch ((char*)&_XmStrings[8281])
#endif
#ifndef XmNmwmDecorations
#define XmNmwmDecorations ((char*)&_XmStrings[8291])
#endif
#ifndef XmNmwmFunctions
#define XmNmwmFunctions ((char*)&_XmStrings[8306])
#endif
#ifndef XmNmwmInputMode
#define XmNmwmInputMode ((char*)&_XmStrings[8319])
#endif
#ifndef XmNmwmMenu
#define XmNmwmMenu ((char*)&_XmStrings[8332])
#endif
#ifndef XmNmwmMessages
#define XmNmwmMessages ((char*)&_XmStrings[8340])
#endif
#ifndef XmNnavigationType
#define XmNnavigationType ((char*)&_XmStrings[8352])
#endif
#ifndef XmNneedsMotion
#define XmNneedsMotion ((char*)&_XmStrings[8367])
#endif
#ifndef XmNnoMatchCallback
#define XmNnoMatchCallback ((char*)&_XmStrings[8379])
#endif
#ifndef XmNnoMatchString
#define XmNnoMatchString ((char*)&_XmStrings[8395])
#endif
#ifndef XmNnoResize
#define XmNnoResize ((char*)&_XmStrings[8409])
#endif
#ifndef XmNnoneCursorForeground
#define XmNnoneCursorForeground ((char*)&_XmStrings[8418])
#endif
#ifndef XmNnotifyProc
#define XmNnotifyProc ((char*)&_XmStrings[8439])
#endif
#ifndef XmNnumColumns
#define XmNnumColumns ((char*)&_XmStrings[8450])
#endif
#ifndef XmNnumDropRectangles
#define XmNnumDropRectangles ((char*)&_XmStrings[8461])
#endif
#ifndef XmNnumDropTransfers
#define XmNnumDropTransfers ((char*)&_XmStrings[8479])
#endif
#ifndef XmNnumExportTargets
#define XmNnumExportTargets ((char*)&_XmStrings[8496])
#endif
#ifndef XmNnumImportTargets
#define XmNnumImportTargets ((char*)&_XmStrings[8513])
#endif
#ifndef XmNnumRectangles
#define XmNnumRectangles ((char*)&_XmStrings[8530])
#endif
#ifndef XmNoffsetX
#define XmNoffsetX ((char*)&_XmStrings[8544])
#endif
#ifndef XmNoffsetY
#define XmNoffsetY ((char*)&_XmStrings[8552])
#endif
#ifndef XmNokCallback
#define XmNokCallback ((char*)&_XmStrings[8560])
#endif
#ifndef XmNokLabelString
#define XmNokLabelString ((char*)&_XmStrings[8571])
#endif
#ifndef XmNoperationChangedCallback
#define XmNoperationChangedCallback ((char*)&_XmStrings[8585])
#endif
#ifndef XmNoperationCursorIcon
#define XmNoperationCursorIcon ((char*)&_XmStrings[8610])
#endif
#ifndef XmNoptionLabel
#define XmNoptionLabel ((char*)&_XmStrings[8630])
#endif
#ifndef XmNoptionMnemonic
#define XmNoptionMnemonic ((char*)&_XmStrings[8642])
#endif
#ifndef XmNoutputCreate
#define XmNoutputCreate ((char*)&_XmStrings[8657])
#endif
#ifndef XmNpacking
#define XmNpacking ((char*)&_XmStrings[8670])
#endif
#ifndef XmNpageDecrementCallback
#define XmNpageDecrementCallback ((char*)&_XmStrings[8678])
#endif
#ifndef XmNpageIncrement
#define XmNpageIncrement ((char*)&_XmStrings[8700])
#endif
#ifndef XmNpageIncrementCallback
#define XmNpageIncrementCallback ((char*)&_XmStrings[8714])
#endif
#ifndef XmNpaneMaximum
#define XmNpaneMaximum ((char*)&_XmStrings[8736])
#endif
#ifndef XmNpaneMinimum
#define XmNpaneMinimum ((char*)&_XmStrings[8748])
#endif
#ifndef XmNpattern
#define XmNpattern ((char*)&_XmStrings[8760])
#endif
#ifndef XmNpendingDelete
#define XmNpendingDelete ((char*)&_XmStrings[8768])
#endif
#ifndef XmNpopupEnabled
#define XmNpopupEnabled ((char*)&_XmStrings[8782])
#endif
#ifndef XmNpositionIndex
#define XmNpositionIndex ((char*)&_XmStrings[8795])
#endif
#ifndef XmNpostFromButton
#define XmNpostFromButton ((char*)&_XmStrings[8809])
#endif
#ifndef XmNpostFromCount
#define XmNpostFromCount ((char*)&_XmStrings[8824])
#endif
#ifndef XmNpostFromList
#define XmNpostFromList ((char*)&_XmStrings[8838])
#endif
#ifndef XmNpreeditType
#define XmNpreeditType ((char*)&_XmStrings[8851])
#endif
#ifndef XmNprocessingDirection
#define XmNprocessingDirection ((char*)&_XmStrings[8863])
#endif
#ifndef XmNpromptString
#define XmNpromptString ((char*)&_XmStrings[8883])
#endif
#ifndef XmNprotocolCallback
#define XmNprotocolCallback ((char*)&_XmStrings[8896])
#endif
#ifndef XmNpushButtonEnabled
#define XmNpushButtonEnabled ((char*)&_XmStrings[8913])
#endif
#ifndef XmNqualifySearchDataProc
#define XmNqualifySearchDataProc ((char*)&_XmStrings[8931])
#endif
#ifndef XmNradioAlwaysOne
#define XmNradioAlwaysOne ((char*)&_XmStrings[8953])
#endif
#ifndef XmNradioBehavior
#define XmNradioBehavior ((char*)&_XmStrings[8968])
#endif
#ifndef XmNrealizeCallback
#define XmNrealizeCallback ((char*)&_XmStrings[8982])
#endif
#ifndef XmNrecomputeSize
#define XmNrecomputeSize ((char*)&_XmStrings[8998])
#endif
#ifndef XmNrectangles
#define XmNrectangles ((char*)&_XmStrings[9012])
#endif
#ifndef XmNrefigureMode
#define XmNrefigureMode ((char*)&_XmStrings[9023])
#endif
#ifndef XmNrepeatDelay
#define XmNrepeatDelay ((char*)&_XmStrings[9036])
#endif
#ifndef XmNresizable
#define XmNresizable ((char*)&_XmStrings[9048])
#endif
#ifndef XmNresizeCallback
#define XmNresizeCallback ((char*)&_XmStrings[9058])
#endif
#ifndef XmNresizeHeight
#define XmNresizeHeight ((char*)&_XmStrings[9073])
#endif
#ifndef XmNresizePolicy
#define XmNresizePolicy ((char*)&_XmStrings[9086])
#endif
#ifndef XmNresizeWidth
#define XmNresizeWidth ((char*)&_XmStrings[9099])
#endif
#ifndef XmNrightAttachment
#define XmNrightAttachment ((char*)&_XmStrings[9111])
#endif
#ifndef XmNrightOffset
#define XmNrightOffset ((char*)&_XmStrings[9127])
#endif
#ifndef XmNrightPosition
#define XmNrightPosition ((char*)&_XmStrings[9139])
#endif
#ifndef XmNrightWidget
#define XmNrightWidget ((char*)&_XmStrings[9153])
#endif
#ifndef XmNrowColumnType
#define XmNrowColumnType ((char*)&_XmStrings[9165])
#endif
#ifndef XmNrows
#define XmNrows ((char*)&_XmStrings[9179])
#endif
#ifndef XmNrubberPositioning
#define XmNrubberPositioning ((char*)&_XmStrings[9184])
#endif
#ifndef XmNsashHeight
#define XmNsashHeight ((char*)&_XmStrings[9202])
#endif
#ifndef XmNsashIndent
#define XmNsashIndent ((char*)&_XmStrings[9213])
#endif
#ifndef XmNsashShadowThickness
#define XmNsashShadowThickness ((char*)&_XmStrings[9224])
#endif
#ifndef XmNsashWidth
#define XmNsashWidth ((char*)&_XmStrings[9244])
#endif
#ifndef XmNscaleHeight
#define XmNscaleHeight ((char*)&_XmStrings[9254])
#endif
#ifndef XmNscaleMultiple
#define XmNscaleMultiple ((char*)&_XmStrings[9266])
#endif
#ifndef XmNscaleWidth
#define XmNscaleWidth ((char*)&_XmStrings[9280])
#endif
#ifndef XmNscrollBarDisplayPolicy
#define XmNscrollBarDisplayPolicy ((char*)&_XmStrings[9291])
#endif
#ifndef XmNscrollBarPlacement
#define XmNscrollBarPlacement ((char*)&_XmStrings[9314])
#endif
#ifndef XmNscrollHorizontal
#define XmNscrollHorizontal ((char*)&_XmStrings[9333])
#endif
#ifndef XmNscrollLeftSide
#define XmNscrollLeftSide ((char*)&_XmStrings[9350])
#endif
#ifndef XmNscrollTopSide
#define XmNscrollTopSide ((char*)&_XmStrings[9365])
#endif
#ifndef XmNscrollVertical
#define XmNscrollVertical ((char*)&_XmStrings[9379])
#endif
#ifndef XmNscrolledWindowMarginHeight
#define XmNscrolledWindowMarginHeight ((char*)&_XmStrings[9394])
#endif
#ifndef XmNscrolledWindowMarginWidth
#define XmNscrolledWindowMarginWidth ((char*)&_XmStrings[9421])
#endif
#ifndef XmNscrollingPolicy
#define XmNscrollingPolicy ((char*)&_XmStrings[9447])
#endif
#ifndef XmNselectColor
#define XmNselectColor ((char*)&_XmStrings[9463])
#endif
#ifndef XmNselectInsensitivePixmap
#define XmNselectInsensitivePixmap ((char*)&_XmStrings[9475])
#endif
#ifndef XmNselectPixmap
#define XmNselectPixmap ((char*)&_XmStrings[9499])
#endif
#ifndef XmNselectThreshold
#define XmNselectThreshold ((char*)&_XmStrings[9512])
#endif
#ifndef XmNselectedItemCount
#define XmNselectedItemCount ((char*)&_XmStrings[9528])
#endif
#ifndef XmNselectedItems
#define XmNselectedItems ((char*)&_XmStrings[9546])
#endif
#ifndef XmNselectionArrayCount
#define XmNselectionArrayCount ((char*)&_XmStrings[9560])
#endif
#ifndef XmNselectionLabelString
#define XmNselectionLabelString ((char*)&_XmStrings[9580])
#endif
#ifndef XmNselectionPolicy
#define XmNselectionPolicy ((char*)&_XmStrings[9601])
#endif
#ifndef XmNseparatorOn
#define XmNseparatorOn ((char*)&_XmStrings[9617])
#endif
#ifndef XmNseparatorType
#define XmNseparatorType ((char*)&_XmStrings[9629])
#endif
#ifndef XmNset
#define XmNset ((char*)&_XmStrings[9643])
#endif
#ifndef XmNshadow
#define XmNshadow ((char*)&_XmStrings[9647])
#endif
#ifndef XmNshadowThickness
#define XmNshadowThickness ((char*)&_XmStrings[9654])
#endif
#ifndef XmNshadowType
#define XmNshadowType ((char*)&_XmStrings[9670])
#endif
#ifndef XmNshellUnitType
#define XmNshellUnitType ((char*)&_XmStrings[9681])
#endif
#ifndef XmNshowArrows
#define XmNshowArrows ((char*)&_XmStrings[9695])
#endif
#ifndef XmNshowAsDefault
#define XmNshowAsDefault ((char*)&_XmStrings[9706])
#endif
#ifndef XmNshowSeparator
#define XmNshowSeparator ((char*)&_XmStrings[9720])
#endif
#ifndef XmNshowValue
#define XmNshowValue ((char*)&_XmStrings[9734])
#endif
#ifndef XmNsimpleCallback
#define XmNsimpleCallback ((char*)&_XmStrings[9744])
#endif
#ifndef XmNsingleSelectionCallback
#define XmNsingleSelectionCallback ((char*)&_XmStrings[9759])
#endif
#ifndef XmNsizePolicy
#define XmNsizePolicy ((char*)&_XmStrings[9783])
#endif
#ifndef XmNskipAdjust
#define XmNskipAdjust ((char*)&_XmStrings[9794])
#endif
#ifndef XmNsliderSize
#define XmNsliderSize ((char*)&_XmStrings[9805])
#endif
#ifndef XmNsource
#define XmNsource ((char*)&_XmStrings[9816])
#endif
#ifndef XmNsourceCursorIcon
#define XmNsourceCursorIcon ((char*)&_XmStrings[9823])
#endif
#ifndef XmNsourceIsExternal
#define XmNsourceIsExternal ((char*)&_XmStrings[9840])
#endif
#ifndef XmNsourcePixmapIcon
#define XmNsourcePixmapIcon ((char*)&_XmStrings[9857])
#endif
#ifndef XmNsourceWidget
#define XmNsourceWidget ((char*)&_XmStrings[9874])
#endif
#ifndef XmNsourceWindow
#define XmNsourceWindow ((char*)&_XmStrings[9887])
#endif
#ifndef XmNspacing
#define XmNspacing ((char*)&_XmStrings[9900])
#endif
#ifndef XmNspotLocation
#define XmNspotLocation ((char*)&_XmStrings[9908])
#endif
#ifndef XmNstartTime
#define XmNstartTime ((char*)&_XmStrings[9921])
#endif
#ifndef XmNstateCursorIcon
#define XmNstateCursorIcon ((char*)&_XmStrings[9931])
#endif
#ifndef XmNstringDirection
#define XmNstringDirection ((char*)&_XmStrings[9947])
#endif
#ifndef XmNsubMenuId
#define XmNsubMenuId ((char*)&_XmStrings[9963])
#endif
#ifndef XmNsymbolPixmap
#define XmNsymbolPixmap ((char*)&_XmStrings[9973])
#endif
#ifndef XmNtearOffMenuActivateCallback
#define XmNtearOffMenuActivateCallback ((char*)&_XmStrings[9986])
#endif
#ifndef XmNtearOffMenuDeactivateCallback
#define XmNtearOffMenuDeactivateCallback ((char*)&_XmStrings[10014])
#endif
#ifndef XmNtearOffModel
#define XmNtearOffModel ((char*)&_XmStrings[10044])
#endif
#ifndef XmNtextAccelerators
#define XmNtextAccelerators ((char*)&_XmStrings[10057])
#endif
#ifndef XmNtextColumns
#define XmNtextColumns ((char*)&_XmStrings[10074])
#endif
#ifndef XmNtextFontList
#define XmNtextFontList ((char*)&_XmStrings[10086])
#endif
#ifndef XmNtextString
#define XmNtextString ((char*)&_XmStrings[10099])
#endif
#ifndef XmNtextTranslations
#define XmNtextTranslations ((char*)&_XmStrings[10110])
#endif
#ifndef XmNtextValue
#define XmNtextValue ((char*)&_XmStrings[10127])
#endif
#ifndef XmNtitleString
#define XmNtitleString ((char*)&_XmStrings[10137])
#endif
#ifndef XmNtoBottomCallback
#define XmNtoBottomCallback ((char*)&_XmStrings[10149])
#endif
#ifndef XmNtoPositionCallback
#define XmNtoPositionCallback ((char*)&_XmStrings[10166])
#endif
#ifndef XmNtoTopCallback
#define XmNtoTopCallback ((char*)&_XmStrings[10185])
#endif
#ifndef XmNtopAttachment
#define XmNtopAttachment ((char*)&_XmStrings[10199])
#endif
#ifndef XmNtopCharacter
#define XmNtopCharacter ((char*)&_XmStrings[10213])
#endif
#ifndef XmNtopItemPosition
#define XmNtopItemPosition ((char*)&_XmStrings[10226])
#endif
#ifndef XmNtopLevelEnterCallback
#define XmNtopLevelEnterCallback ((char*)&_XmStrings[10242])
#endif
#ifndef XmNtopLevelLeaveCallback
#define XmNtopLevelLeaveCallback ((char*)&_XmStrings[10264])
#endif
#ifndef XmNtopOffset
#define XmNtopOffset ((char*)&_XmStrings[10286])
#endif
#ifndef XmNtopPosition
#define XmNtopPosition ((char*)&_XmStrings[10296])
#endif
#ifndef XmNtopShadowColor
#define XmNtopShadowColor ((char*)&_XmStrings[10308])
#endif
#ifndef XmNtopShadowPixmap
#define XmNtopShadowPixmap ((char*)&_XmStrings[10323])
#endif
#ifndef XmNtopWidget
#define XmNtopWidget ((char*)&_XmStrings[10339])
#endif
#ifndef XmNtransferProc
#define XmNtransferProc ((char*)&_XmStrings[10349])
#endif
#ifndef XmNtransferStatus
#define XmNtransferStatus ((char*)&_XmStrings[10362])
#endif
#ifndef XmNtraversalCallback
#define XmNtraversalCallback ((char*)&_XmStrings[10377])
#endif
#ifndef XmNtraversalOn
#define XmNtraversalOn ((char*)&_XmStrings[10395])
#endif
#ifndef XmNtraversalType
#define XmNtraversalType ((char*)&_XmStrings[10407])
#endif
#ifndef XmNtraverseObscuredCallback
#define XmNtraverseObscuredCallback ((char*)&_XmStrings[10421])
#endif
#ifndef XmNtreeUpdateProc
#define XmNtreeUpdateProc ((char*)&_XmStrings[10446])
#endif
#ifndef XmNtroughColor
#define XmNtroughColor ((char*)&_XmStrings[10461])
#endif
#ifndef XmNunitType
#define XmNunitType ((char*)&_XmStrings[10473])
#endif
#ifndef XmNunmapCallback
#define XmNunmapCallback ((char*)&_XmStrings[10482])
#endif
#ifndef XmNunpostBehavior
#define XmNunpostBehavior ((char*)&_XmStrings[10496])
#endif
#ifndef XmNunselectPixmap
#define XmNunselectPixmap ((char*)&_XmStrings[10511])
#endif
#ifndef XmNupdateSliderSize
#define XmNupdateSliderSize ((char*)&_XmStrings[10526])
#endif
#ifndef XmNuseAsyncGeometry
#define XmNuseAsyncGeometry ((char*)&_XmStrings[10543])
#endif
#ifndef XmNuserData
#define XmNuserData ((char*)&_XmStrings[10560])
#endif
#ifndef XmNvalidCursorForeground
#define XmNvalidCursorForeground ((char*)&_XmStrings[10569])
#endif
#ifndef XmNvalueChangedCallback
#define XmNvalueChangedCallback ((char*)&_XmStrings[10591])
#endif
#ifndef XmNvalueWcs
#define XmNvalueWcs ((char*)&_XmStrings[10612])
#endif
#ifndef XmNverifyBell
#define XmNverifyBell ((char*)&_XmStrings[10621])
#endif
#ifndef XmNverticalFontUnit
#define XmNverticalFontUnit ((char*)&_XmStrings[10632])
#endif
#ifndef XmNverticalScrollBar
#define XmNverticalScrollBar ((char*)&_XmStrings[10649])
#endif
#ifndef XmNverticalSpacing
#define XmNverticalSpacing ((char*)&_XmStrings[10667])
#endif
#ifndef XmNvisibleItemCount
#define XmNvisibleItemCount ((char*)&_XmStrings[10683])
#endif
#ifndef XmNvisibleWhenOff
#define XmNvisibleWhenOff ((char*)&_XmStrings[10700])
#endif
#ifndef XmNvisualPolicy
#define XmNvisualPolicy ((char*)&_XmStrings[10715])
#endif
#ifndef XmNwhichButton
#define XmNwhichButton ((char*)&_XmStrings[10728])
#endif
#ifndef XmNwordWrap
#define XmNwordWrap ((char*)&_XmStrings[10740])
#endif
#ifndef XmNworkWindow
#define XmNworkWindow ((char*)&_XmStrings[10749])
#endif
#ifndef XmRAlignment
#define XmRAlignment ((char*)&_XmStrings[10760])
#endif
#ifndef XmRAnimationMask
#define XmRAnimationMask ((char*)&_XmStrings[10770])
#endif
#ifndef XmRAnimationPixmap
#define XmRAnimationPixmap ((char*)&_XmStrings[10784])
#endif
#ifndef XmRAnimationStyle
#define XmRAnimationStyle ((char*)&_XmStrings[10800])
#endif
#ifndef XmRArrowDirection
#define XmRArrowDirection ((char*)&_XmStrings[10815])
#endif
#ifndef XmRAtomList
#define XmRAtomList ((char*)&_XmStrings[10830])
#endif
#ifndef XmRAttachment
#define XmRAttachment ((char*)&_XmStrings[10839])
#endif
#ifndef XmRAudibleWarning
#define XmRAudibleWarning ((char*)&_XmStrings[10850])
#endif
#ifndef XmRAvailability
#define XmRAvailability ((char*)&_XmStrings[10865])
#endif
#ifndef XmRBackgroundPixmap
#define XmRBackgroundPixmap ((char*)&_XmStrings[10878])
#endif
#ifndef XmRBlendModel
#define XmRBlendModel ((char*)&_XmStrings[10895])
#endif
#ifndef XmRBooleanDimension
#define XmRBooleanDimension ((char*)&_XmStrings[10906])
#endif
#ifndef XmRBottomShadowPixmap
#define XmRBottomShadowPixmap ((char*)&_XmStrings[10923])
#endif
#ifndef XmRButtonType
#define XmRButtonType ((char*)&_XmStrings[10942])
#endif
#ifndef XmRCallbackProc
#define XmRCallbackProc ((char*)&_XmStrings[10953])
#endif
#ifndef XmRChar
#define XmRChar ((char*)&_XmStrings[10966])
#endif
#ifndef XmRCharSetTable
#define XmRCharSetTable ((char*)&_XmStrings[10971])
#endif
#ifndef XmRChildHorizontalAlignment
#define XmRChildHorizontalAlignment ((char*)&_XmStrings[10984])
#endif
#ifndef XmRChildPlacement
#define XmRChildPlacement ((char*)&_XmStrings[11009])
#endif
#ifndef XmRChildType
#define XmRChildType ((char*)&_XmStrings[11024])
#endif
#ifndef XmRChildVerticalAlignment
#define XmRChildVerticalAlignment ((char*)&_XmStrings[11034])
#endif
#ifndef XmRCommandWindowLocation
#define XmRCommandWindowLocation ((char*)&_XmStrings[11057])
#endif
#ifndef XmRCompoundText
#define XmRCompoundText ((char*)&_XmStrings[11079])
#endif
#ifndef XmRDefaultButtonType
#define XmRDefaultButtonType ((char*)&_XmStrings[11092])
#endif
#ifndef XmRDeleteResponse
#define XmRDeleteResponse ((char*)&_XmStrings[11110])
#endif
#ifndef XmRDialogStyle
#define XmRDialogStyle ((char*)&_XmStrings[11125])
#endif
#ifndef XmRDialogType
#define XmRDialogType ((char*)&_XmStrings[11137])
#endif
#ifndef XmRDoubleClickInterval
#define XmRDoubleClickInterval ((char*)&_XmStrings[11148])
#endif
#ifndef XmRDragInitiatorProtocolStyle
#define XmRDragInitiatorProtocolStyle ((char*)&_XmStrings[11168])
#endif
#ifndef XmRDragReceiverProtocolStyle
#define XmRDragReceiverProtocolStyle ((char*)&_XmStrings[11195])
#endif
#ifndef XmRDropSiteActivity
#define XmRDropSiteActivity ((char*)&_XmStrings[11221])
#endif
#ifndef XmRDropSiteOperations
#define XmRDropSiteOperations ((char*)&_XmStrings[11238])
#endif
#ifndef XmRDropSiteType
#define XmRDropSiteType ((char*)&_XmStrings[11257])
#endif
#ifndef XmRDropTransfers
#define XmRDropTransfers ((char*)&_XmStrings[11270])
#endif
#ifndef XmRExtensionType
#define XmRExtensionType ((char*)&_XmStrings[11284])
#endif
#ifndef XmRFileTypeMask
#define XmRFileTypeMask ((char*)&_XmStrings[11298])
#endif
#ifndef XmRFontList
#define XmRFontList ((char*)&_XmStrings[11311])
#endif
#ifndef XmRGadgetPixmap
#define XmRGadgetPixmap ((char*)&_XmStrings[11320])
#endif
#ifndef XmRHighlightPixmap
#define XmRHighlightPixmap ((char*)&_XmStrings[11333])
#endif
#ifndef XmRHorizontalDimension
#define XmRHorizontalDimension ((char*)&_XmStrings[11349])
#endif
#ifndef XmRHorizontalInt
#define XmRHorizontalInt ((char*)&_XmStrings[11369])
#endif
#ifndef XmRHorizontalPosition
#define XmRHorizontalPosition ((char*)&_XmStrings[11383])
#endif
#ifndef XmRIconAttachment
#define XmRIconAttachment ((char*)&_XmStrings[11402])
#endif
#ifndef XmRImportTargets
#define XmRImportTargets ((char*)&_XmStrings[11417])
#endif
#ifndef XmRIndicatorType
#define XmRIndicatorType ((char*)&_XmStrings[11431])
#endif
#ifndef XmRItemCount
#define XmRItemCount ((char*)&_XmStrings[11445])
#endif
#ifndef XmRItems
#define XmRItems ((char*)&_XmStrings[11455])
#endif
#ifndef XmRKeySym
#define XmRKeySym ((char*)&_XmStrings[11461])
#endif
#ifndef XmRKeySymTable
#define XmRKeySymTable ((char*)&_XmStrings[11468])
#endif
#ifndef XmRKeyboardFocusPolicy
#define XmRKeyboardFocusPolicy ((char*)&_XmStrings[11480])
#endif
#ifndef XmRLabelType
#define XmRLabelType ((char*)&_XmStrings[11500])
#endif
#ifndef XmRListMarginHeight
#define XmRListMarginHeight ((char*)&_XmStrings[11510])
#endif
#ifndef XmRListMarginWidth
#define XmRListMarginWidth ((char*)&_XmStrings[11527])
#endif
#ifndef XmRListSizePolicy
#define XmRListSizePolicy ((char*)&_XmStrings[11543])
#endif
#ifndef XmRListSpacing
#define XmRListSpacing ((char*)&_XmStrings[11558])
#endif
#ifndef XmRManBottomShadowPixmap
#define XmRManBottomShadowPixmap ((char*)&_XmStrings[11570])
#endif
#ifndef XmRManForegroundPixmap
#define XmRManForegroundPixmap ((char*)&_XmStrings[11592])
#endif
#ifndef XmRManHighlightPixmap
#define XmRManHighlightPixmap ((char*)&_XmStrings[11612])
#endif
#ifndef XmRManTopShadowPixmap
#define XmRManTopShadowPixmap ((char*)&_XmStrings[11631])
#endif
#ifndef XmRMenuWidget
#define XmRMenuWidget ((char*)&_XmStrings[11650])
#endif
#ifndef XmRMnemonic
#define XmRMnemonic ((char*)&_XmStrings[11661])
#endif
#ifndef XmRMultiClick
#define XmRMultiClick ((char*)&_XmStrings[11670])
#endif
#ifndef XmRNavigationType
#define XmRNavigationType ((char*)&_XmStrings[11681])
#endif
#ifndef XmRPacking
#define XmRPacking ((char*)&_XmStrings[11696])
#endif
#ifndef XmRPrimForegroundPixmap
#define XmRPrimForegroundPixmap ((char*)&_XmStrings[11704])
#endif
#ifndef XmRProc
#define XmRProc ((char*)&_XmStrings[11725])
#endif
#ifndef XmRProcessingDirection
#define XmRProcessingDirection ((char*)&_XmStrings[11730])
#endif
#ifndef XmRRectangleList
#define XmRRectangleList ((char*)&_XmStrings[11750])
#endif
#ifndef XmRResizePolicy
#define XmRResizePolicy ((char*)&_XmStrings[11764])
#endif
#ifndef XmRRowColumnType
#define XmRRowColumnType ((char*)&_XmStrings[11777])
#endif
#ifndef XmRScrollBarDisplayPolicy
#define XmRScrollBarDisplayPolicy ((char*)&_XmStrings[11791])
#endif
#ifndef XmRScrollBarPlacement
#define XmRScrollBarPlacement ((char*)&_XmStrings[11814])
#endif
#ifndef XmRScrollingPolicy
#define XmRScrollingPolicy ((char*)&_XmStrings[11833])
#endif
#ifndef XmRSelectedItemCount
#define XmRSelectedItemCount ((char*)&_XmStrings[11849])
#endif
#ifndef XmRSelectedItems
#define XmRSelectedItems ((char*)&_XmStrings[11867])
#endif
#ifndef XmRSelectionPolicy
#define XmRSelectionPolicy ((char*)&_XmStrings[11881])
#endif
#ifndef XmRSelectionType
#define XmRSelectionType ((char*)&_XmStrings[11897])
#endif
#ifndef XmRSeparatorType
#define XmRSeparatorType ((char*)&_XmStrings[11911])
#endif
#ifndef XmRShadowType
#define XmRShadowType ((char*)&_XmStrings[11925])
#endif
#ifndef XmRShellHorizDim
#define XmRShellHorizDim ((char*)&_XmStrings[11936])
#endif
#ifndef XmRShellHorizPos
#define XmRShellHorizPos ((char*)&_XmStrings[11950])
#endif
#ifndef XmRShellUnitType
#define XmRShellUnitType ((char*)&_XmStrings[11964])
#endif
#ifndef XmRShellVertDim
#define XmRShellVertDim ((char*)&_XmStrings[11978])
#endif
#ifndef XmRShellVertPos
#define XmRShellVertPos ((char*)&_XmStrings[11991])
#endif
#ifndef XmRSizePolicy
#define XmRSizePolicy ((char*)&_XmStrings[12004])
#endif
#ifndef XmRStringDirection
#define XmRStringDirection ((char*)&_XmStrings[12015])
#endif
#ifndef XmRTearOffModel
#define XmRTearOffModel ((char*)&_XmStrings[12031])
#endif
#ifndef XmRTopShadowPixmap
#define XmRTopShadowPixmap ((char*)&_XmStrings[12044])
#endif
#ifndef XmRTransferStatus
#define XmRTransferStatus ((char*)&_XmStrings[12060])
#endif
#ifndef XmRTraversalType
#define XmRTraversalType ((char*)&_XmStrings[12075])
#endif
#ifndef XmRUnitType
#define XmRUnitType ((char*)&_XmStrings[12089])
#endif
#ifndef XmRUnpostBehavior
#define XmRUnpostBehavior ((char*)&_XmStrings[12098])
#endif
#ifndef XmRValueWcs
#define XmRValueWcs ((char*)&_XmStrings[12113])
#endif
#ifndef XmRVerticalAlignment
#define XmRVerticalAlignment ((char*)&_XmStrings[12122])
#endif
#ifndef XmRVerticalDimension
#define XmRVerticalDimension ((char*)&_XmStrings[12140])
#endif
#ifndef XmRVerticalInt
#define XmRVerticalInt ((char*)&_XmStrings[12158])
#endif
#ifndef XmRVerticalPosition
#define XmRVerticalPosition ((char*)&_XmStrings[12170])
#endif
#ifndef XmRVirtualBinding
#define XmRVirtualBinding ((char*)&_XmStrings[12187])
#endif
#ifndef XmRVisibleItemCount
#define XmRVisibleItemCount ((char*)&_XmStrings[12202])
#endif
#ifndef XmRVisualPolicy
#define XmRVisualPolicy ((char*)&_XmStrings[12219])
#endif
#ifndef XmRWhichButton
#define XmRWhichButton ((char*)&_XmStrings[12232])
#endif
#ifndef XmRXmBackgroundPixmap
#define XmRXmBackgroundPixmap ((char*)&_XmStrings[12244])
#endif
#ifndef XmRXmString
#define XmRXmString ((char*)&_XmStrings[12263])
#endif
#ifndef XmRXmStringCharSet
#define XmRXmStringCharSet ((char*)&_XmStrings[12272])
#endif
#ifndef XmRXmStringTable
#define XmRXmStringTable ((char*)&_XmStrings[12288])
#endif
#ifndef XmVosfActivate
#define XmVosfActivate ((char*)&_XmStrings[12302])
#endif
#ifndef XmVosfAddMode
#define XmVosfAddMode ((char*)&_XmStrings[12314])
#endif
#ifndef XmVosfBackSpace
#define XmVosfBackSpace ((char*)&_XmStrings[12325])
#endif
#ifndef XmVosfBeginLine
#define XmVosfBeginLine ((char*)&_XmStrings[12338])
#endif
#ifndef XmVosfCancel
#define XmVosfCancel ((char*)&_XmStrings[12351])
#endif
#ifndef XmVosfClear
#define XmVosfClear ((char*)&_XmStrings[12361])
#endif
#ifndef XmVosfCopy
#define XmVosfCopy ((char*)&_XmStrings[12370])
#endif
#ifndef XmVosfCut
#define XmVosfCut ((char*)&_XmStrings[12378])
#endif
#ifndef XmVosfDelete
#define XmVosfDelete ((char*)&_XmStrings[12385])
#endif
#ifndef XmVosfDown
#define XmVosfDown ((char*)&_XmStrings[12395])
#endif
#ifndef XmVosfEndLine
#define XmVosfEndLine ((char*)&_XmStrings[12403])
#endif
#ifndef XmVosfHelp
#define XmVosfHelp ((char*)&_XmStrings[12414])
#endif
#ifndef XmVosfInsert
#define XmVosfInsert ((char*)&_XmStrings[12422])
#endif
#ifndef XmVosfLeft
#define XmVosfLeft ((char*)&_XmStrings[12432])
#endif
#ifndef XmVosfMenu
#define XmVosfMenu ((char*)&_XmStrings[12440])
#endif
#ifndef XmVosfMenuBar
#define XmVosfMenuBar ((char*)&_XmStrings[12448])
#endif
#ifndef XmVosfPageDown
#define XmVosfPageDown ((char*)&_XmStrings[12459])
#endif
#ifndef XmVosfPageLeft
#define XmVosfPageLeft ((char*)&_XmStrings[12471])
#endif
#ifndef XmVosfPageRight
#define XmVosfPageRight ((char*)&_XmStrings[12483])
#endif
#ifndef XmVosfPageUp
#define XmVosfPageUp ((char*)&_XmStrings[12496])
#endif
#ifndef XmVosfPaste
#define XmVosfPaste ((char*)&_XmStrings[12506])
#endif
#ifndef XmVosfPrimaryPaste
#define XmVosfPrimaryPaste ((char*)&_XmStrings[12515])
#endif
#ifndef XmVosfQuickPaste
#define XmVosfQuickPaste ((char*)&_XmStrings[12531])
#endif
#ifndef XmVosfRight
#define XmVosfRight ((char*)&_XmStrings[12545])
#endif
#ifndef XmVosfSelect
#define XmVosfSelect ((char*)&_XmStrings[12554])
#endif
#ifndef XmVosfUndo
#define XmVosfUndo ((char*)&_XmStrings[12564])
#endif
#ifndef XmVosfUp
#define XmVosfUp ((char*)&_XmStrings[12572])
#endif
#ifndef XmSFONTLIST_DEFAULT_TAG_STRING
#define XmSFONTLIST_DEFAULT_TAG_STRING ((char*)&_XmStrings[12578])
#endif
#ifndef XmSXmFONTLIST_DEFAULT_TAG_STRING
#define XmSXmFONTLIST_DEFAULT_TAG_STRING ((char*)&_XmStrings[12606])
#endif
#ifndef XmRTopItemPosition
#define XmRTopItemPosition ((char*)&_XmStrings[12636])
#endif
#ifndef XmNtearOffTitle
#define XmNtearOffTitle ((char*)&_XmStrings[12652])
#endif
#ifndef XmCTearOffTitle
#define XmCTearOffTitle ((char*)&_XmStrings[12665])
#endif
#ifndef XmNpopupHandlerCallback
#define XmNpopupHandlerCallback ((char*)&_XmStrings[12678])
#endif
#ifndef XmNconvertCallback
#define XmNconvertCallback ((char*)&_XmStrings[12699])
#endif
#ifndef XmNdestinationCallback
#define XmNdestinationCallback ((char*)&_XmStrings[12715])
#endif
#ifndef XmNselectedItem
#define XmNselectedItem ((char*)&_XmStrings[12735])
#endif
#ifndef XmCSelectedItem
#define XmCSelectedItem ((char*)&_XmStrings[12748])
#endif
#ifndef XmNselectionCallback
#define XmNselectionCallback ((char*)&_XmStrings[12761])
#endif
#ifndef XmNmatchBehavior
#define XmNmatchBehavior ((char*)&_XmStrings[12779])
#endif
#ifndef XmCMatchBehavior
#define XmCMatchBehavior ((char*)&_XmStrings[12793])
#endif
#ifndef XmNnoFontCallback
#define XmNnoFontCallback ((char*)&_XmStrings[12807])
#endif
#ifndef XmNtextPath
#define XmNtextPath ((char*)&_XmStrings[12822])
#endif
#ifndef XmNeditingPath
#define XmNeditingPath ((char*)&_XmStrings[12831])
#endif
#ifndef XmCEditingPath
#define XmCEditingPath ((char*)&_XmStrings[12843])
#endif
#ifndef XmNbidirectionalCursor
#define XmNbidirectionalCursor ((char*)&_XmStrings[12855])
#endif
#ifndef XmCBidirectionalCursor
#define XmCBidirectionalCursor ((char*)&_XmStrings[12875])
#endif
#ifndef XmNcollapsedStatePixmap
#define XmNcollapsedStatePixmap ((char*)&_XmStrings[12895])
#endif
#ifndef XmNdetailColumnHeading
#define XmNdetailColumnHeading ((char*)&_XmStrings[12916])
#endif
#ifndef XmNdetailCount
#define XmNdetailCount ((char*)&_XmStrings[12936])
#endif
#ifndef XmNdetailTabList
#define XmNdetailTabList ((char*)&_XmStrings[12948])
#endif
#ifndef XmNexpandedStatePixmap
#define XmNexpandedStatePixmap ((char*)&_XmStrings[12962])
#endif
#ifndef XmNlargeCellHeight
#define XmNlargeCellHeight ((char*)&_XmStrings[12982])
#endif
#ifndef XmNlargeCellWidth
#define XmNlargeCellWidth ((char*)&_XmStrings[12998])
#endif
#ifndef XmNlayoutType
#define XmNlayoutType ((char*)&_XmStrings[13013])
#endif
#ifndef XmNoutlineIndentation
#define XmNoutlineIndentation ((char*)&_XmStrings[13024])
#endif
#ifndef XmNoutlineLineStyle
#define XmNoutlineLineStyle ((char*)&_XmStrings[13043])
#endif
#ifndef XmNprimaryOwnership
#define XmNprimaryOwnership ((char*)&_XmStrings[13060])
#endif
#ifndef XmNselectionTechnique
#define XmNselectionTechnique ((char*)&_XmStrings[13077])
#endif
#ifndef XmNsmallCellHeight
#define XmNsmallCellHeight ((char*)&_XmStrings[13096])
#endif
#ifndef XmNsmallCellWidth
#define XmNsmallCellWidth ((char*)&_XmStrings[13112])
#endif
#ifndef XmNspatialStyle
#define XmNspatialStyle ((char*)&_XmStrings[13127])
#endif
#ifndef XmNentryParent
#define XmNentryParent ((char*)&_XmStrings[13140])
#endif
#ifndef XmNlargeIconX
#define XmNlargeIconX ((char*)&_XmStrings[13152])
#endif
#ifndef XmNlargeIconY
#define XmNlargeIconY ((char*)&_XmStrings[13163])
#endif
#ifndef XmNsmallIconX
#define XmNsmallIconX ((char*)&_XmStrings[13174])
#endif
#ifndef XmNsmallIconY
#define XmNsmallIconY ((char*)&_XmStrings[13185])
#endif
#ifndef XmCCollapsedStatePixmap
#define XmCCollapsedStatePixmap ((char*)&_XmStrings[13196])
#endif
#ifndef XmCDetailColumnHeading
#define XmCDetailColumnHeading ((char*)&_XmStrings[13217])
#endif
#ifndef XmCDetailCount
#define XmCDetailCount ((char*)&_XmStrings[13237])
#endif
#ifndef XmCDetailMask
#define XmCDetailMask ((char*)&_XmStrings[13249])
#endif
#ifndef XmCEntryViewType
#define XmCEntryViewType ((char*)&_XmStrings[13260])
#endif
#ifndef XmCLineStyle
#define XmCLineStyle ((char*)&_XmStrings[13274])
#endif
#ifndef XmCDetailTabList
#define XmCDetailTabList ((char*)&_XmStrings[13284])
#endif
#ifndef XmCExpandedStatePixmap
#define XmCExpandedStatePixmap ((char*)&_XmStrings[13298])
#endif
#ifndef XmCIncludeModel
#define XmCIncludeModel ((char*)&_XmStrings[13318])
#endif
#ifndef XmCCellHeight
#define XmCCellHeight ((char*)&_XmStrings[13331])
#endif
#ifndef XmCCellWidth
#define XmCCellWidth ((char*)&_XmStrings[13342])
#endif
#ifndef XmCLayoutType
#define XmCLayoutType ((char*)&_XmStrings[13352])
#endif
#ifndef XmCOutlineIndentation
#define XmCOutlineIndentation ((char*)&_XmStrings[13363])
#endif
#ifndef XmCPlaceModel
#define XmCPlaceModel ((char*)&_XmStrings[13382])
#endif
#ifndef XmCPrimaryOwnership
#define XmCPrimaryOwnership ((char*)&_XmStrings[13393])
#endif
#ifndef XmCSelectionTechnique
#define XmCSelectionTechnique ((char*)&_XmStrings[13410])
#endif
#ifndef XmCSpatialStyle
#define XmCSpatialStyle ((char*)&_XmStrings[13429])
#endif
#ifndef XmCEntryDetail
#define XmCEntryDetail ((char*)&_XmStrings[13442])
#endif
#ifndef XmCExpandState
#define XmCExpandState ((char*)&_XmStrings[13454])
#endif
#ifndef XmNlargeIcon
#define XmNlargeIcon ((char*)&_XmStrings[13466])
#endif
#ifndef XmNlargeIconMask
#define XmNlargeIconMask ((char*)&_XmStrings[13476])
#endif
#ifndef XmNlargeIconPixmap
#define XmNlargeIconPixmap ((char*)&_XmStrings[13490])
#endif
#ifndef XmNsmallIcon
#define XmNsmallIcon ((char*)&_XmStrings[13506])
#endif
#ifndef XmNsmallIconMask
#define XmNsmallIconMask ((char*)&_XmStrings[13516])
#endif
#ifndef XmNsmallIconPixmap
#define XmNsmallIconPixmap ((char*)&_XmStrings[13530])
#endif
#ifndef XmCIcon
#define XmCIcon ((char*)&_XmStrings[13546])
#endif
#ifndef XmCViewType
#define XmCViewType ((char*)&_XmStrings[13551])
#endif
#ifndef XmCVisualEmphasis
#define XmCVisualEmphasis ((char*)&_XmStrings[13560])
#endif
#ifndef XmNcurrentPageNumber
#define XmNcurrentPageNumber ((char*)&_XmStrings[13575])
#endif
#ifndef XmNfirstPageNumber
#define XmNfirstPageNumber ((char*)&_XmStrings[13593])
#endif
#ifndef XmNlastPageNumber
#define XmNlastPageNumber ((char*)&_XmStrings[13609])
#endif
#ifndef XmNbackPagePlacement
#define XmNbackPagePlacement ((char*)&_XmStrings[13624])
#endif
#ifndef XmNbackPageNumber
#define XmNbackPageNumber ((char*)&_XmStrings[13642])
#endif
#ifndef XmNbackPageSize
#define XmNbackPageSize ((char*)&_XmStrings[13657])
#endif
#ifndef XmNbackPageForeground
#define XmNbackPageForeground ((char*)&_XmStrings[13670])
#endif
#ifndef XmNbackPageBackground
#define XmNbackPageBackground ((char*)&_XmStrings[13689])
#endif
#ifndef XmNframeBackground
#define XmNframeBackground ((char*)&_XmStrings[13708])
#endif
#ifndef XmNbindingType
#define XmNbindingType ((char*)&_XmStrings[13724])
#endif
#ifndef XmNbindingPixmap
#define XmNbindingPixmap ((char*)&_XmStrings[13736])
#endif
#ifndef XmNbindingWidth
#define XmNbindingWidth ((char*)&_XmStrings[13750])
#endif
#ifndef XmNmajorTabSpacing
#define XmNmajorTabSpacing ((char*)&_XmStrings[13763])
#endif
#ifndef XmNminorTabSpacing
#define XmNminorTabSpacing ((char*)&_XmStrings[13779])
#endif
#ifndef XmNinnerMarginWidth
#define XmNinnerMarginWidth ((char*)&_XmStrings[13795])
#endif
#ifndef XmNinnerMarginHeight
#define XmNinnerMarginHeight ((char*)&_XmStrings[13812])
#endif
#ifndef XmNframeShadowThickness
#define XmNframeShadowThickness ((char*)&_XmStrings[13830])
#endif
#ifndef XmNpageNumber
#define XmNpageNumber ((char*)&_XmStrings[13851])
#endif
#ifndef XmCCurrentPageNumber
#define XmCCurrentPageNumber ((char*)&_XmStrings[13862])
#endif
#ifndef XmCFirstPageNumber
#define XmCFirstPageNumber ((char*)&_XmStrings[13880])
#endif
#ifndef XmCLastPageNumber
#define XmCLastPageNumber ((char*)&_XmStrings[13896])
#endif
#ifndef XmCBackPagePlacement
#define XmCBackPagePlacement ((char*)&_XmStrings[13911])
#endif
#ifndef XmCBackPageNumber
#define XmCBackPageNumber ((char*)&_XmStrings[13929])
#endif
#ifndef XmCBackPageSize
#define XmCBackPageSize ((char*)&_XmStrings[13944])
#endif
#ifndef XmCBackPageForeground
#define XmCBackPageForeground ((char*)&_XmStrings[13957])
#endif
#ifndef XmCBackPageBackground
#define XmCBackPageBackground ((char*)&_XmStrings[13976])
#endif
#ifndef XmCFrameBackground
#define XmCFrameBackground ((char*)&_XmStrings[13995])
#endif
#ifndef XmCBindingType
#define XmCBindingType ((char*)&_XmStrings[14011])
#endif
#ifndef XmCBindingPixmap
#define XmCBindingPixmap ((char*)&_XmStrings[14023])
#endif
#ifndef XmCBindingWidth
#define XmCBindingWidth ((char*)&_XmStrings[14037])
#endif
#ifndef XmCMajorTabSpacing
#define XmCMajorTabSpacing ((char*)&_XmStrings[14050])
#endif
#ifndef XmCMinorTabSpacing
#define XmCMinorTabSpacing ((char*)&_XmStrings[14066])
#endif
#ifndef XmCInnerMarginWidth
#define XmCInnerMarginWidth ((char*)&_XmStrings[14082])
#endif
#ifndef XmCInnerMarginHeight
#define XmCInnerMarginHeight ((char*)&_XmStrings[14099])
#endif
#ifndef XmCPageChangeCallback
#define XmCPageChangeCallback ((char*)&_XmStrings[14117])
#endif
#ifndef XmCPageNumber
#define XmCPageNumber ((char*)&_XmStrings[14136])
#endif
#ifndef XmRArrowLayout
#define XmRArrowLayout ((char*)&_XmStrings[14147])
#endif
#ifndef XmRArrowSensitivity
#define XmRArrowSensitivity ((char*)&_XmStrings[14159])
#endif
#ifndef XmRSpinBoxChildType
#define XmRSpinBoxChildType ((char*)&_XmStrings[14176])
#endif
#ifndef XmNarrowLayout
#define XmNarrowLayout ((char*)&_XmStrings[14193])
#endif
#ifndef XmCArrowLayout
#define XmCArrowLayout ((char*)&_XmStrings[14205])
#endif
#ifndef XmNarrowSensitivity
#define XmNarrowSensitivity ((char*)&_XmStrings[14217])
#endif
#ifndef XmCArrowSensitivity
#define XmCArrowSensitivity ((char*)&_XmStrings[14234])
#endif
#ifndef XmNdefaultArrowSensitivity
#define XmNdefaultArrowSensitivity ((char*)&_XmStrings[14251])
#endif
#ifndef XmCDefaultArrowSensitivity
#define XmCDefaultArrowSensitivity ((char*)&_XmStrings[14275])
#endif
#ifndef XmNarrowSize
#define XmNarrowSize ((char*)&_XmStrings[14299])
#endif
#ifndef XmCArrowSize
#define XmCArrowSize ((char*)&_XmStrings[14309])
#endif
#ifndef XmNspinBoxChildType
#define XmNspinBoxChildType ((char*)&_XmStrings[14319])
#endif
#ifndef XmCSpinBoxChildType
#define XmCSpinBoxChildType ((char*)&_XmStrings[14336])
#endif
#ifndef XmNposition
#define XmNposition ((char*)&_XmStrings[14353])
#endif
#ifndef XmNnumValues
#define XmNnumValues ((char*)&_XmStrings[14362])
#endif
#ifndef XmCNumValues
#define XmCNumValues ((char*)&_XmStrings[14372])
#endif
#ifndef XmNvalues
#define XmNvalues ((char*)&_XmStrings[14382])
#endif
#ifndef XmCValues
#define XmCValues ((char*)&_XmStrings[14389])
#endif
#ifndef XmNminimumValue
#define XmNminimumValue ((char*)&_XmStrings[14396])
#endif
#ifndef XmCMinimumValue
#define XmCMinimumValue ((char*)&_XmStrings[14409])
#endif
#ifndef XmNmaximumValue
#define XmNmaximumValue ((char*)&_XmStrings[14422])
#endif
#ifndef XmCMaximumValue
#define XmCMaximumValue ((char*)&_XmStrings[14435])
#endif
#ifndef XmNincrementValue
#define XmNincrementValue ((char*)&_XmStrings[14448])
#endif
#ifndef XmCIncrementValue
#define XmCIncrementValue ((char*)&_XmStrings[14463])
#endif
#ifndef XmRAutomaticSelection
#define XmRAutomaticSelection ((char*)&_XmStrings[14478])
#endif
#ifndef XmRLineStyle
#define XmRLineStyle ((char*)&_XmStrings[14497])
#endif
#ifndef XmREntryViewType
#define XmREntryViewType ((char*)&_XmStrings[14507])
#endif
#ifndef XmRDirection
#define XmRDirection ((char*)&_XmStrings[14521])
#endif
#ifndef XmRLayoutType
#define XmRLayoutType ((char*)&_XmStrings[14531])
#endif
#ifndef XmRPrimaryOwnership
#define XmRPrimaryOwnership ((char*)&_XmStrings[14542])
#endif
#ifndef XmRSelectionTechnique
#define XmRSelectionTechnique ((char*)&_XmStrings[14559])
#endif
#ifndef XmRSpatialStyle
#define XmRSpatialStyle ((char*)&_XmStrings[14578])
#endif
#ifndef XmRTabList
#define XmRTabList ((char*)&_XmStrings[14591])
#endif
#ifndef XmRViewType
#define XmRViewType ((char*)&_XmStrings[14599])
#endif
#ifndef XmRVisualEmphasis
#define XmRVisualEmphasis ((char*)&_XmStrings[14608])
#endif
#ifndef XmRBindingType
#define XmRBindingType ((char*)&_XmStrings[14623])
#endif
#ifndef XmRNBChildType
#define XmRNBChildType ((char*)&_XmStrings[14635])
#endif
#ifndef XmNentryViewType
#define XmNentryViewType ((char*)&_XmStrings[14647])
#endif
#ifndef XmNinsensitiveStippleBitmap
#define XmNinsensitiveStippleBitmap ((char*)&_XmStrings[14661])
#endif
#ifndef XmNlayoutDirection
#define XmNlayoutDirection ((char*)&_XmStrings[14686])
#endif
#ifndef XmNviewType
#define XmNviewType ((char*)&_XmStrings[14702])
#endif
#ifndef XmNvisualEmphasis
#define XmNvisualEmphasis ((char*)&_XmStrings[14711])
#endif
#ifndef XmCLayoutDirection
#define XmCLayoutDirection ((char*)&_XmStrings[14726])
#endif
#ifndef XmNsnapBackMultiple
#define XmNsnapBackMultiple ((char*)&_XmStrings[14742])
#endif
#ifndef XmNslidingMode
#define XmNslidingMode ((char*)&_XmStrings[14759])
#endif
#ifndef XmNsliderVisual
#define XmNsliderVisual ((char*)&_XmStrings[14771])
#endif
#ifndef XmNautoDragModel
#define XmNautoDragModel ((char*)&_XmStrings[14784])
#endif
#ifndef XmNcolorCalculationProc
#define XmNcolorCalculationProc ((char*)&_XmStrings[14798])
#endif
#ifndef XmNbitmapConversionModel
#define XmNbitmapConversionModel ((char*)&_XmStrings[14819])
#endif
#ifndef XmNcolorAllocationProc
#define XmNcolorAllocationProc ((char*)&_XmStrings[14841])
#endif
#ifndef XmNselectionMode
#define XmNselectionMode ((char*)&_XmStrings[14861])
#endif
#ifndef XmNselectedPositions
#define XmNselectedPositions ((char*)&_XmStrings[14875])
#endif
#ifndef XmNselectedPositionCount
#define XmNselectedPositionCount ((char*)&_XmStrings[14893])
#endif
#ifndef XmCSnapBackMultiple
#define XmCSnapBackMultiple ((char*)&_XmStrings[14915])
#endif
#ifndef XmCSliderVisual
#define XmCSliderVisual ((char*)&_XmStrings[14932])
#endif
#ifndef XmCSlidingMode
#define XmCSlidingMode ((char*)&_XmStrings[14945])
#endif
#ifndef XmCAutoDragModel
#define XmCAutoDragModel ((char*)&_XmStrings[14957])
#endif
#ifndef XmCColorCalculationProc
#define XmCColorCalculationProc ((char*)&_XmStrings[14971])
#endif
#ifndef XmCBitmapConversionModel
#define XmCBitmapConversionModel ((char*)&_XmStrings[14992])
#endif
#ifndef XmCColorAllocationProc
#define XmCColorAllocationProc ((char*)&_XmStrings[15014])
#endif
#ifndef XmCInsensitiveStippleBitmap
#define XmCInsensitiveStippleBitmap ((char*)&_XmStrings[15034])
#endif
#ifndef XmCSelectionMode
#define XmCSelectionMode ((char*)&_XmStrings[15059])
#endif
#ifndef XmCSelectedPositions
#define XmCSelectedPositions ((char*)&_XmStrings[15073])
#endif
#ifndef XmCSelectedPositionCount
#define XmCSelectedPositionCount ((char*)&_XmStrings[15091])
#endif
#ifndef XmRSlidingMode
#define XmRSlidingMode ((char*)&_XmStrings[15113])
#endif
#ifndef XmRShowArrows
#define XmRShowArrows ((char*)&_XmStrings[15125])
#endif
#ifndef XmRSliderVisual
#define XmRSliderVisual ((char*)&_XmStrings[15136])
#endif
#ifndef XmRShowValue
#define XmRShowValue ((char*)&_XmStrings[15149])
#endif
#ifndef XmRAutoDragModel
#define XmRAutoDragModel ((char*)&_XmStrings[15159])
#endif
#ifndef XmRSWChildType
#define XmRSWChildType ((char*)&_XmStrings[15173])
#endif
#ifndef XmRBitmapConversionModel
#define XmRBitmapConversionModel ((char*)&_XmStrings[15185])
#endif
#ifndef XmRSelectionMode
#define XmRSelectionMode ((char*)&_XmStrings[15207])
#endif
#ifndef XmNinputPolicy
#define XmNinputPolicy ((char*)&_XmStrings[15221])
#endif
#ifndef XmCInputPolicy
#define XmCInputPolicy ((char*)&_XmStrings[15233])
#endif
#ifndef XmRInputPolicy
#define XmRInputPolicy ((char*)&_XmStrings[15245])
#endif
#ifndef XmNtoggleMode
#define XmNtoggleMode ((char*)&_XmStrings[15257])
#endif
#ifndef XmCToggleMode
#define XmCToggleMode ((char*)&_XmStrings[15268])
#endif
#ifndef XmRToggleMode
#define XmRToggleMode ((char*)&_XmStrings[15279])
#endif
#ifndef XmRIndicatorOn
#define XmRIndicatorOn ((char*)&_XmStrings[15290])
#endif
#ifndef XmRSet
#define XmRSet ((char*)&_XmStrings[15302])
#endif
#ifndef XmNindeterminatePixmap
#define XmNindeterminatePixmap ((char*)&_XmStrings[15306])
#endif
#ifndef XmCIndeterminatePixmap
#define XmCIndeterminatePixmap ((char*)&_XmStrings[15326])
#endif
#ifndef XmNunselectColor
#define XmNunselectColor ((char*)&_XmStrings[15346])
#endif
#ifndef XmCUnselectColor
#define XmCUnselectColor ((char*)&_XmStrings[15360])
#endif
#ifndef XmNselectedPosition
#define XmNselectedPosition ((char*)&_XmStrings[15374])
#endif
#ifndef XmNarrowSpacing
#define XmNarrowSpacing ((char*)&_XmStrings[15391])
#endif
#ifndef XmCArrowSpacing
#define XmCArrowSpacing ((char*)&_XmStrings[15404])
#endif
#ifndef XmRMatchBehavior
#define XmRMatchBehavior ((char*)&_XmStrings[15417])
#endif
#ifndef XmRComboBoxType
#define XmRComboBoxType ((char*)&_XmStrings[15431])
#endif
#ifndef XmCSelectedPosition
#define XmCSelectedPosition ((char*)&_XmStrings[15444])
#endif
#ifndef XmNenableWarp
#define XmNenableWarp ((char*)&_XmStrings[15461])
#endif
#ifndef XmCEnableWarp
#define XmCEnableWarp ((char*)&_XmStrings[15472])
#endif
#ifndef XmREnableWarp
#define XmREnableWarp ((char*)&_XmStrings[15483])
#endif
#ifndef XmNmotifVersion
#define XmNmotifVersion ((char*)&_XmStrings[15494])
#endif
#ifndef XmCMotifVersion
#define XmCMotifVersion ((char*)&_XmStrings[15507])
#endif
#ifndef XmNdefaultGlyphPixmap
#define XmNdefaultGlyphPixmap ((char*)&_XmStrings[15520])
#endif
#ifndef XmCDefaultGlyphPixmap
#define XmCDefaultGlyphPixmap ((char*)&_XmStrings[15539])
#endif
#ifndef XmCRendition
#define XmCRendition ((char*)&_XmStrings[15558])
#endif
#ifndef XmNtag
#define XmNtag ((char*)&_XmStrings[15568])
#endif
#ifndef XmCTag
#define XmCTag ((char*)&_XmStrings[15572])
#endif
#ifndef XmNfontName
#define XmNfontName ((char*)&_XmStrings[15576])
#endif
#ifndef XmCFontName
#define XmCFontName ((char*)&_XmStrings[15585])
#endif
#ifndef XmNfontType
#define XmNfontType ((char*)&_XmStrings[15594])
#endif
#ifndef XmCFontType
#define XmCFontType ((char*)&_XmStrings[15603])
#endif
#ifndef XmRFontType
#define XmRFontType ((char*)&_XmStrings[15612])
#endif
#ifndef XmNloadModel
#define XmNloadModel ((char*)&_XmStrings[15621])
#endif
#ifndef XmCLoadModel
#define XmCLoadModel ((char*)&_XmStrings[15631])
#endif
#ifndef XmRLoadModel
#define XmRLoadModel ((char*)&_XmStrings[15641])
#endif
#ifndef XmNtabList
#define XmNtabList ((char*)&_XmStrings[15651])
#endif
#ifndef XmCTabList
#define XmCTabList ((char*)&_XmStrings[15659])
#endif
#ifndef XmRRenditionPixel
#define XmRRenditionPixel ((char*)&_XmStrings[15667])
#endif
#ifndef XmNunderlineType
#define XmNunderlineType ((char*)&_XmStrings[15682])
#endif
#ifndef XmCUnderlineType
#define XmCUnderlineType ((char*)&_XmStrings[15696])
#endif
#ifndef XmNstrikethruType
#define XmNstrikethruType ((char*)&_XmStrings[15710])
#endif
#ifndef XmCStrikethruType
#define XmCStrikethruType ((char*)&_XmStrings[15725])
#endif
#ifndef XmRLineType
#define XmRLineType ((char*)&_XmStrings[15740])
#endif
#ifndef XmNrenderTable
#define XmNrenderTable ((char*)&_XmStrings[15749])
#endif
#ifndef XmCRenderTable
#define XmCRenderTable ((char*)&_XmStrings[15761])
#endif
#ifndef XmRRenderTable
#define XmRRenderTable ((char*)&_XmStrings[15773])
#endif
#ifndef XmNbuttonRenderTable
#define XmNbuttonRenderTable ((char*)&_XmStrings[15785])
#endif
#ifndef XmCButtonRenderTable
#define XmCButtonRenderTable ((char*)&_XmStrings[15803])
#endif
#ifndef XmRButtonRenderTable
#define XmRButtonRenderTable ((char*)&_XmStrings[15821])
#endif
#ifndef XmNlabelRenderTable
#define XmNlabelRenderTable ((char*)&_XmStrings[15839])
#endif
#ifndef XmCLabelRenderTable
#define XmCLabelRenderTable ((char*)&_XmStrings[15856])
#endif
#ifndef XmRLabelRenderTable
#define XmRLabelRenderTable ((char*)&_XmStrings[15873])
#endif
#ifndef XmNtextRenderTable
#define XmNtextRenderTable ((char*)&_XmStrings[15890])
#endif
#ifndef XmCTextRenderTable
#define XmCTextRenderTable ((char*)&_XmStrings[15906])
#endif
#ifndef XmRTextRenderTable
#define XmRTextRenderTable ((char*)&_XmStrings[15922])
#endif
#ifndef XmNdragStartCallback
#define XmNdragStartCallback ((char*)&_XmStrings[15938])
#endif
#ifndef XmNnoRenditionCallback
#define XmNnoRenditionCallback ((char*)&_XmStrings[15956])
#endif
#ifndef XmSXmAS_IS
#define XmSXmAS_IS ((char*)&_XmStrings[15976])
#endif
#ifndef XmMIsWhiteSpaceMethod
#define XmMIsWhiteSpaceMethod ((char*)&_XmStrings[15984])
#endif
#ifndef XmMIsScanBreakMethod
#define XmMIsScanBreakMethod ((char*)&_XmStrings[16003])
#endif
#ifndef XmMCharDirection
#define XmMCharDirection ((char*)&_XmStrings[16021])
#endif
#ifndef XmMInitialCharsDirection
#define XmMInitialCharsDirection ((char*)&_XmStrings[16035])
#endif
#ifndef XmNpatternType
#define XmNpatternType ((char*)&_XmStrings[16057])
#endif
#ifndef XmNsubstitute
#define XmNsubstitute ((char*)&_XmStrings[16069])
#endif
#ifndef XmNinvokeParseProc
#define XmNinvokeParseProc ((char*)&_XmStrings[16080])
#endif
#ifndef XmNincludeStatus
#define XmNincludeStatus ((char*)&_XmStrings[16096])
#endif
#ifndef XmVosfBackTab
#define XmVosfBackTab ((char*)&_XmStrings[16110])
#endif
#ifndef XmVosfBeginData
#define XmVosfBeginData ((char*)&_XmStrings[16121])
#endif
#ifndef XmVosfDeselectAll
#define XmVosfDeselectAll ((char*)&_XmStrings[16134])
#endif
#ifndef XmVosfEndData
#define XmVosfEndData ((char*)&_XmStrings[16149])
#endif
#ifndef XmVosfEscape
#define XmVosfEscape ((char*)&_XmStrings[16160])
#endif
#ifndef XmVosfExtend
#define XmVosfExtend ((char*)&_XmStrings[16170])
#endif
#ifndef XmVosfLeftLine
#define XmVosfLeftLine ((char*)&_XmStrings[16180])
#endif
#ifndef XmVosfNext
#define XmVosfNext ((char*)&_XmStrings[16192])
#endif
#ifndef XmVosfNextField
#define XmVosfNextField ((char*)&_XmStrings[16200])
#endif
#ifndef XmVosfNextMenu
#define XmVosfNextMenu ((char*)&_XmStrings[16213])
#endif
#ifndef XmVosfNextMinor
#define XmVosfNextMinor ((char*)&_XmStrings[16225])
#endif
#ifndef XmVosfPrevField
#define XmVosfPrevField ((char*)&_XmStrings[16238])
#endif
#ifndef XmVosfPrevMenu
#define XmVosfPrevMenu ((char*)&_XmStrings[16251])
#endif
#ifndef XmVosfPrior
#define XmVosfPrior ((char*)&_XmStrings[16263])
#endif
#ifndef XmVosfPriorMinor
#define XmVosfPriorMinor ((char*)&_XmStrings[16272])
#endif
#ifndef XmVosfReselect
#define XmVosfReselect ((char*)&_XmStrings[16286])
#endif
#ifndef XmVosfRestore
#define XmVosfRestore ((char*)&_XmStrings[16298])
#endif
#ifndef XmVosfRightLine
#define XmVosfRightLine ((char*)&_XmStrings[16309])
#endif
#ifndef XmVosfSelectAll
#define XmVosfSelectAll ((char*)&_XmStrings[16322])
#endif
#ifndef XmVosfSwitchDirection
#define XmVosfSwitchDirection ((char*)&_XmStrings[16335])
#endif
#ifndef XmNnotebookChildType
#define XmNnotebookChildType ((char*)&_XmStrings[16354])
#endif
#ifndef XmCNotebookChildType
#define XmCNotebookChildType ((char*)&_XmStrings[16372])
#endif
#ifndef XmRNotebookChildType
#define XmRNotebookChildType ((char*)&_XmStrings[16390])
#endif
#ifndef XmNscrolledWindowChildType
#define XmNscrolledWindowChildType ((char*)&_XmStrings[16408])
#endif
#ifndef XmCScrolledWindowChildType
#define XmCScrolledWindowChildType ((char*)&_XmStrings[16432])
#endif
#ifndef XmRScrolledWindowChildType
#define XmRScrolledWindowChildType ((char*)&_XmStrings[16456])
#endif
#ifndef XmNselectedObjects
#define XmNselectedObjects ((char*)&_XmStrings[16480])
#endif
#ifndef XmCSelectedObjects
#define XmCSelectedObjects ((char*)&_XmStrings[16496])
#endif
#ifndef XmNselectedObjectCount
#define XmNselectedObjectCount ((char*)&_XmStrings[16512])
#endif
#ifndef XmCSelectedObjectCount
#define XmCSelectedObjectCount ((char*)&_XmStrings[16532])
#endif
#ifndef XmNcomboBoxType
#define XmNcomboBoxType ((char*)&_XmStrings[16552])
#endif
#ifndef XmCComboBoxType
#define XmCComboBoxType ((char*)&_XmStrings[16565])
#endif
#ifndef XmNtabValue
#define XmNtabValue ((char*)&_XmStrings[16578])
#endif
#ifndef XmNoffsetModel
#define XmNoffsetModel ((char*)&_XmStrings[16587])
#endif
#ifndef XmNdecimal
#define XmNdecimal ((char*)&_XmStrings[16599])
#endif
#ifndef XmNdetail
#define XmNdetail ((char*)&_XmStrings[16607])
#endif
#ifndef XmCDetail
#define XmCDetail ((char*)&_XmStrings[16614])
#endif
#ifndef XmNdetailCount
#define XmNdetailCount ((char*)&_XmStrings[16621])
#endif
#ifndef XmCDetailCount
#define XmCDetailCount ((char*)&_XmStrings[16633])
#endif
#ifndef XmNcontainerID
#define XmNcontainerID ((char*)&_XmStrings[16645])
#endif
#ifndef XmCContainerID
#define XmCContainerID ((char*)&_XmStrings[16657])
#endif
#ifndef XmSCLIENT_WINDOW
#define XmSCLIENT_WINDOW ((char*)&_XmStrings[16669])
#endif
#ifndef XmSCLIP_TEMPORARY
#define XmSCLIP_TEMPORARY ((char*)&_XmStrings[16683])
#endif
#ifndef XmSCLIPBOARD
#define XmSCLIPBOARD ((char*)&_XmStrings[16698])
#endif
#ifndef XmSCOMPOUND_TEXT
#define XmSCOMPOUND_TEXT ((char*)&_XmStrings[16708])
#endif
#ifndef XmSDELETE
#define XmSDELETE ((char*)&_XmStrings[16722])
#endif
#ifndef XmSFILE
#define XmSFILE ((char*)&_XmStrings[16729])
#endif
#ifndef XmSFILE_NAME
#define XmSFILE_NAME ((char*)&_XmStrings[16734])
#endif
#ifndef XmSINCR
#define XmSINCR ((char*)&_XmStrings[16744])
#endif
#ifndef XmSINSERT_PROPERTY
#define XmSINSERT_PROPERTY ((char*)&_XmStrings[16749])
#endif
#ifndef XmSINSERT_SELECTION
#define XmSINSERT_SELECTION ((char*)&_XmStrings[16765])
#endif
#ifndef XmSLENGTH
#define XmSLENGTH ((char*)&_XmStrings[16782])
#endif
#ifndef XmSLINK_SELECTION
#define XmSLINK_SELECTION ((char*)&_XmStrings[16789])
#endif
#ifndef XmS_MOTIF_ATOM_0
#define XmS_MOTIF_ATOM_0 ((char*)&_XmStrings[16804])
#endif
#ifndef XmS_MOTIF_BINDINGS
#define XmS_MOTIF_BINDINGS ((char*)&_XmStrings[16818])
#endif
#ifndef XmS_MOTIF_DEFAULT_BINDINGS
#define XmS_MOTIF_DEFAULT_BINDINGS ((char*)&_XmStrings[16834])
#endif
#ifndef XmS_MOTIF_CANCEL_DROP_EFFECT
#define XmS_MOTIF_CANCEL_DROP_EFFECT ((char*)&_XmStrings[16858])
#endif
#ifndef XmS_MOTIF_CLIP_HEADER
#define XmS_MOTIF_CLIP_HEADER ((char*)&_XmStrings[16884])
#endif
#ifndef XmS_MOTIF_CLIP_DATA_REQUEST
#define XmS_MOTIF_CLIP_DATA_REQUEST ((char*)&_XmStrings[16903])
#endif
#ifndef XmS_MOTIF_CLIP_DATA_DELETE
#define XmS_MOTIF_CLIP_DATA_DELETE ((char*)&_XmStrings[16928])
#endif
#ifndef XmS_MOTIF_CLIP_ITEM
#define XmS_MOTIF_CLIP_ITEM ((char*)&_XmStrings[16952])
#endif
#ifndef XmS_MOTIF_CLIP_LOCK
#define XmS_MOTIF_CLIP_LOCK ((char*)&_XmStrings[16969])
#endif
#ifndef XmS_MOTIF_CLIP_LOCK_ACCESS_VALID
#define XmS_MOTIF_CLIP_LOCK_ACCESS_VALID ((char*)&_XmStrings[16986])
#endif
#ifndef XmS_MOTIF_CLIP_MESSAGE
#define XmS_MOTIF_CLIP_MESSAGE ((char*)&_XmStrings[17016])
#endif
#ifndef XmS_MOTIF_CLIP_NEXT_ID
#define XmS_MOTIF_CLIP_NEXT_ID ((char*)&_XmStrings[17036])
#endif
#ifndef XmS_MOTIF_CLIP_TIME
#define XmS_MOTIF_CLIP_TIME ((char*)&_XmStrings[17056])
#endif
#ifndef XmS_MOTIF_CLIPBOARD_TARGETS
#define XmS_MOTIF_CLIPBOARD_TARGETS ((char*)&_XmStrings[17073])
#endif
#ifndef XmS_MOTIF_COMPOUND_STRING
#define XmS_MOTIF_COMPOUND_STRING ((char*)&_XmStrings[17098])
#endif
#ifndef XmS_MOTIF_DEFERRED_CLIPBOARD_TARGETS
#define XmS_MOTIF_DEFERRED_CLIPBOARD_TARGETS ((char*)&_XmStrings[17121])
#endif
#ifndef XmS_MOTIF_DESTINATION
#define XmS_MOTIF_DESTINATION ((char*)&_XmStrings[17155])
#endif
#ifndef XmS_MOTIF_DRAG_OFFSET
#define XmS_MOTIF_DRAG_OFFSET ((char*)&_XmStrings[17174])
#endif
#ifndef XmS_MOTIF_DROP
#define XmS_MOTIF_DROP ((char*)&_XmStrings[17193])
#endif
#ifndef XmS_MOTIF_ENCODING_REGISTRY
#define XmS_MOTIF_ENCODING_REGISTRY ((char*)&_XmStrings[17205])
#endif
#ifndef XmS_MOTIF_EXPORT_TARGETS
#define XmS_MOTIF_EXPORT_TARGETS ((char*)&_XmStrings[17230])
#endif
#ifndef XmS_MOTIF_LOSE_SELECTION
#define XmS_MOTIF_LOSE_SELECTION ((char*)&_XmStrings[17252])
#endif
#ifndef XmS_MOTIF_RENDER_TABLE
#define XmS_MOTIF_RENDER_TABLE ((char*)&_XmStrings[17274])
#endif
#ifndef XmS_MOTIF_WM_QUERY
#define XmS_MOTIF_WM_QUERY ((char*)&_XmStrings[17294])
#endif
#ifndef XmS_MOTIF_WM_ALL_CLIENTS
#define XmS_MOTIF_WM_ALL_CLIENTS ((char*)&_XmStrings[17310])
#endif
#ifndef XmSMULTIPLE
#define XmSMULTIPLE ((char*)&_XmStrings[17332])
#endif
#ifndef XmSNULL
#define XmSNULL ((char*)&_XmStrings[17341])
#endif
#ifndef XmSTARGETS
#define XmSTARGETS ((char*)&_XmStrings[17346])
#endif
#ifndef XmSTEXT
#define XmSTEXT ((char*)&_XmStrings[17354])
#endif
#ifndef XmSTIMESTAMP
#define XmSTIMESTAMP ((char*)&_XmStrings[17359])
#endif
#ifndef XmSWM_STATE
#define XmSWM_STATE ((char*)&_XmStrings[17369])
#endif
#ifndef XmSTRANSFER_SUCCESS
#define XmSTRANSFER_SUCCESS ((char*)&_XmStrings[17378])
#endif
#ifndef XmSTRANSFER_FAILURE
#define XmSTRANSFER_FAILURE ((char*)&_XmStrings[17397])
#endif
#ifndef XmNpathMode
#define XmNpathMode ((char*)&_XmStrings[17416])
#endif
#ifndef XmRPathMode
#define XmRPathMode ((char*)&_XmStrings[17425])
#endif
#ifndef XmCPathMode
#define XmCPathMode ((char*)&_XmStrings[17434])
#endif
#ifndef XmNfileFilterStyle
#define XmNfileFilterStyle ((char*)&_XmStrings[17443])
#endif
#ifndef XmRFileFilterStyle
#define XmRFileFilterStyle ((char*)&_XmStrings[17459])
#endif
#ifndef XmCFileFilterStyle
#define XmCFileFilterStyle ((char*)&_XmStrings[17475])
#endif
#ifndef XmNdirTextLabelString
#define XmNdirTextLabelString ((char*)&_XmStrings[17491])
#endif
#ifndef XmCDirTextLabelString
#define XmCDirTextLabelString ((char*)&_XmStrings[17510])
#endif
#ifndef XmNenableBtn1Transfer
#define XmNenableBtn1Transfer ((char*)&_XmStrings[17529])
#endif
#ifndef XmCEnableBtn1Transfer
#define XmCEnableBtn1Transfer ((char*)&_XmStrings[17548])
#endif
#ifndef XmNenableButtonTab
#define XmNenableButtonTab ((char*)&_XmStrings[17567])
#endif
#ifndef XmCEnableButtonTab
#define XmCEnableButtonTab ((char*)&_XmStrings[17583])
#endif
#ifndef XmNenableEtchedInMenu
#define XmNenableEtchedInMenu ((char*)&_XmStrings[17599])
#endif
#ifndef XmCEnableEtchedInMenu
#define XmCEnableEtchedInMenu ((char*)&_XmStrings[17618])
#endif
#ifndef XmNdefaultButtonEmphasis
#define XmNdefaultButtonEmphasis ((char*)&_XmStrings[17637])
#endif
#ifndef XmCDefaultButtonEmphasis
#define XmCDefaultButtonEmphasis ((char*)&_XmStrings[17659])
#endif
#ifndef XmRDefaultButtonEmphasis
#define XmRDefaultButtonEmphasis ((char*)&_XmStrings[17681])
#endif
#ifndef XmNenableToggleColor
#define XmNenableToggleColor ((char*)&_XmStrings[17703])
#endif
#ifndef XmCEnableToggleColor
#define XmCEnableToggleColor ((char*)&_XmStrings[17721])
#endif
#ifndef XmNenableToggleVisual
#define XmNenableToggleVisual ((char*)&_XmStrings[17739])
#endif
#ifndef XmCEnableToggleVisual
#define XmCEnableToggleVisual ((char*)&_XmStrings[17758])
#endif
#ifndef XmNenableDragIcon
#define XmNenableDragIcon ((char*)&_XmStrings[17777])
#endif
#ifndef XmCEnableDragIcon
#define XmCEnableDragIcon ((char*)&_XmStrings[17792])
#endif
#ifndef XmNenableUnselectableDrag
#define XmNenableUnselectableDrag ((char*)&_XmStrings[17807])
#endif
#ifndef XmCEnableUnselectableDrag
#define XmCEnableUnselectableDrag ((char*)&_XmStrings[17830])
#endif
#ifndef XmNdragOverActiveMode
#define XmNdragOverActiveMode ((char*)&_XmStrings[17853])
#endif
#ifndef XmCDragOverActiveMode
#define XmCDragOverActiveMode ((char*)&_XmStrings[17872])
#endif
#ifndef XmNinstallColormap
#define XmNinstallColormap ((char*)&_XmStrings[17891])
#endif
#ifndef XmCInstallColormap
#define XmCInstallColormap ((char*)&_XmStrings[17907])
#endif
#ifndef XmCOwnerEvents
#define XmCOwnerEvents ((char*)&_XmStrings[17923])
#endif
#ifndef XmNownerEvents
#define XmNownerEvents ((char*)&_XmStrings[17935])
#endif
#ifndef XmCGrabStyle
#define XmCGrabStyle ((char*)&_XmStrings[17947])
#endif
#ifndef XmNgrabStyle
#define XmNgrabStyle ((char*)&_XmStrings[17957])
#endif
#ifndef XmNforegroundState
#define XmNforegroundState ((char*)&_XmStrings[17967])
#endif
#ifndef XmNbackgroundState
#define XmNbackgroundState ((char*)&_XmStrings[17983])
#endif
#ifndef XmCGroundState
#define XmCGroundState ((char*)&_XmStrings[17999])
#endif
#ifndef XmRGroundState
#define XmRGroundState ((char*)&_XmStrings[18011])
#endif
#ifndef XmRSelectColor
#define XmRSelectColor ((char*)&_XmStrings[18023])
#endif
#ifndef XmRLargeIconPixmap
#define XmRLargeIconPixmap ((char*)&_XmStrings[18035])
#endif
#ifndef XmRSmallIconPixmap
#define XmRSmallIconPixmap ((char*)&_XmStrings[18051])
#endif
#ifndef XmNoutlineState
#define XmNoutlineState ((char*)&_XmStrings[18067])
#endif
#ifndef XmCOutlineState
#define XmCOutlineState ((char*)&_XmStrings[18080])
#endif
#ifndef XmROutlineState
#define XmROutlineState ((char*)&_XmStrings[18093])
#endif
#ifndef XmNspatialIncludeModel
#define XmNspatialIncludeModel ((char*)&_XmStrings[18106])
#endif
#ifndef XmCSpatialIncludeModel
#define XmCSpatialIncludeModel ((char*)&_XmStrings[18126])
#endif
#ifndef XmRSpatialIncludeModel
#define XmRSpatialIncludeModel ((char*)&_XmStrings[18146])
#endif
#ifndef XmNspatialResizeModel
#define XmNspatialResizeModel ((char*)&_XmStrings[18166])
#endif
#ifndef XmCSpatialResizeModel
#define XmCSpatialResizeModel ((char*)&_XmStrings[18185])
#endif
#ifndef XmRSpatialResizeModel
#define XmRSpatialResizeModel ((char*)&_XmStrings[18204])
#endif
#ifndef XmNspatialSnapModel
#define XmNspatialSnapModel ((char*)&_XmStrings[18223])
#endif
#ifndef XmCSpatialSnapModel
#define XmCSpatialSnapModel ((char*)&_XmStrings[18240])
#endif
#ifndef XmRSpatialSnapModel
#define XmRSpatialSnapModel ((char*)&_XmStrings[18257])
#endif
#ifndef XmNdetailColumnHeadingCount
#define XmNdetailColumnHeadingCount ((char*)&_XmStrings[18274])
#endif
#ifndef XmCDetailColumnHeadingCount
#define XmCDetailColumnHeadingCount ((char*)&_XmStrings[18299])
#endif
#ifndef XmNdetailOrder
#define XmNdetailOrder ((char*)&_XmStrings[18324])
#endif
#ifndef XmCDetailOrder
#define XmCDetailOrder ((char*)&_XmStrings[18336])
#endif
#ifndef XmRCardinalList
#define XmRCardinalList ((char*)&_XmStrings[18348])
#endif
#ifndef XmNdetailOrderCount
#define XmNdetailOrderCount ((char*)&_XmStrings[18361])
#endif
#ifndef XmCDetailOrderCount
#define XmCDetailOrderCount ((char*)&_XmStrings[18378])
#endif
#ifndef XmNoutlineColumnWidth
#define XmNoutlineColumnWidth ((char*)&_XmStrings[18395])
#endif
#ifndef XmCOutlineColumnWidth
#define XmCOutlineColumnWidth ((char*)&_XmStrings[18414])
#endif
#ifndef XmNoutlineChangedCallback
#define XmNoutlineChangedCallback ((char*)&_XmStrings[18433])
#endif
#ifndef XmCOutlineChangedCallback
#define XmCOutlineChangedCallback ((char*)&_XmStrings[18456])
#endif
#ifndef XmNoutlineButtonPolicy
#define XmNoutlineButtonPolicy ((char*)&_XmStrings[18479])
#endif
#ifndef XmCOutlineButtonPolicy
#define XmCOutlineButtonPolicy ((char*)&_XmStrings[18499])
#endif
#ifndef XmROutlineButtonPolicy
#define XmROutlineButtonPolicy ((char*)&_XmStrings[18519])
#endif
#ifndef XmCDefaultVirtualBindings
#define XmCDefaultVirtualBindings ((char*)&_XmStrings[18539])
#endif
#ifndef XmNdefaultVirtualBindings
#define XmNdefaultVirtualBindings ((char*)&_XmStrings[18562])
#endif
#ifndef XmCResizable
#define XmCResizable ((char*)&_XmStrings[18585])
#endif
#ifndef XmRDynamicPixmap
#define XmRDynamicPixmap ((char*)&_XmStrings[18595])
#endif
#ifndef XmNpageChangedCallback
#define XmNpageChangedCallback ((char*)&_XmStrings[18609])
#endif
#ifndef XmNarea
#define XmNarea ((char*)&_XmStrings[18629])
#endif
#ifndef XmNdetailShadowThickness
#define XmNdetailShadowThickness ((char*)&_XmStrings[18634])
#endif
#ifndef XmNsliderMark
#define XmNsliderMark ((char*)&_XmStrings[18656])
#endif
#ifndef XmCSliderMark
#define XmCSliderMark ((char*)&_XmStrings[18667])
#endif
#ifndef XmRSliderMark
#define XmRSliderMark ((char*)&_XmStrings[18678])
#endif
#ifndef XmREnableBtn1Transfer
#define XmREnableBtn1Transfer ((char*)&_XmStrings[18689])
#endif
#ifndef XmNrenditionBackground
#define XmNrenditionBackground ((char*)&_XmStrings[18708])
#endif
#ifndef XmNrenditionForeground
#define XmNrenditionForeground ((char*)&_XmStrings[18728])
#endif
#ifndef XmCRenditionBackground
#define XmCRenditionBackground ((char*)&_XmStrings[18748])
#endif
#ifndef XmCRenditionForeground
#define XmCRenditionForeground ((char*)&_XmStrings[18768])
#endif
#ifndef XmNindeterminateInsensitivePixmap
#define XmNindeterminateInsensitivePixmap ((char*)&_XmStrings[18788])
#endif
#ifndef XmCIndeterminateInsensitivePixmap
#define XmCIndeterminateInsensitivePixmap ((char*)&_XmStrings[18819])
#endif
#ifndef XmNframeChildType
#define XmNframeChildType ((char*)&_XmStrings[18850])
#endif
#ifndef XmCFrameChildType
#define XmCFrameChildType ((char*)&_XmStrings[18865])
#endif
#ifndef XmNtextField
#define XmNtextField ((char*)&_XmStrings[18880])
#endif
#ifndef XmCTextField
#define XmCTextField ((char*)&_XmStrings[18890])
#endif
#ifndef XmNenableThinThickness
#define XmNenableThinThickness ((char*)&_XmStrings[18900])
#endif
#ifndef XmCEnableThinThickness
#define XmCEnableThinThickness ((char*)&_XmStrings[18920])
#endif
#ifndef XmNprimaryColorSetId
#define XmNprimaryColorSetId ((char*)&_XmStrings[18940])
#endif
#ifndef XmCPrimaryColorSetId
#define XmCPrimaryColorSetId ((char*)&_XmStrings[18958])
#endif
#ifndef XmNsecondaryColorSetId
#define XmNsecondaryColorSetId ((char*)&_XmStrings[18976])
#endif
#ifndef XmCSecondaryColorSetId
#define XmCSecondaryColorSetId ((char*)&_XmStrings[18996])
#endif
#ifndef XmNtextColorSetId
#define XmNtextColorSetId ((char*)&_XmStrings[19016])
#endif
#ifndef XmCTextColorSetId
#define XmCTextColorSetId ((char*)&_XmStrings[19031])
#endif
#ifndef XmNactiveColorSetId
#define XmNactiveColorSetId ((char*)&_XmStrings[19046])
#endif
#ifndef XmCActiveColorSetId
#define XmCActiveColorSetId ((char*)&_XmStrings[19063])
#endif
#ifndef XmNinactiveColorSetId
#define XmNinactiveColorSetId ((char*)&_XmStrings[19080])
#endif
#ifndef XmCInactiveColorSetId
#define XmCInactiveColorSetId ((char*)&_XmStrings[19099])
#endif
#ifndef XmNuseColorObj
#define XmNuseColorObj ((char*)&_XmStrings[19118])
#endif
#ifndef XmCUseColorObj
#define XmCUseColorObj ((char*)&_XmStrings[19130])
#endif
#ifndef XmNuseTextColor
#define XmNuseTextColor ((char*)&_XmStrings[19142])
#endif
#ifndef XmCUseTextColor
#define XmCUseTextColor ((char*)&_XmStrings[19155])
#endif
#ifndef XmNuseTextColorForList
#define XmNuseTextColorForList ((char*)&_XmStrings[19168])
#endif
#ifndef XmCUseTextColorForList
#define XmCUseTextColorForList ((char*)&_XmStrings[19188])
#endif
#ifndef XmNuseMask
#define XmNuseMask ((char*)&_XmStrings[19208])
#endif
#ifndef XmCUseMask
#define XmCUseMask ((char*)&_XmStrings[19216])
#endif
#ifndef XmNuseMultiColorIcons
#define XmNuseMultiColorIcons ((char*)&_XmStrings[19224])
#endif
#ifndef XmCUseMultiColorIcons
#define XmCUseMultiColorIcons ((char*)&_XmStrings[19243])
#endif
#ifndef XmNuseIconFileCache
#define XmNuseIconFileCache ((char*)&_XmStrings[19262])
#endif
#ifndef XmCUseIconFileCache
#define XmCUseIconFileCache ((char*)&_XmStrings[19279])
#endif
#ifndef XmSPIXEL_SET
#define XmSPIXEL_SET ((char*)&_XmStrings[19296])
#endif
#ifndef XmSCUSTOMIZE_DATA
#define XmSCUSTOMIZE_DATA ((char*)&_XmStrings[19307])
#endif
#ifndef XmSCOLOR_SRV_NAME
#define XmSCOLOR_SRV_NAME ((char*)&_XmStrings[19323])
#endif
#ifndef XmNlist
#define XmNlist ((char*)&_XmStrings[19335])
#endif
#ifndef XmCList
#define XmCList ((char*)&_XmStrings[19340])
#endif
#ifndef XmNarrowOrientation
#define XmNarrowOrientation ((char*)&_XmStrings[19345])
#endif
#ifndef XmCArrowOrientation
#define XmCArrowOrientation ((char*)&_XmStrings[19362])
#endif
#ifndef XmRArrowOrientation
#define XmRArrowOrientation ((char*)&_XmStrings[19379])
#endif
#ifndef XmNpositionType
#define XmNpositionType ((char*)&_XmStrings[19396])
#endif
#ifndef XmCPositionType
#define XmCPositionType ((char*)&_XmStrings[19409])
#endif
#ifndef XmRPositionType
#define XmRPositionType ((char*)&_XmStrings[19422])
#endif
#ifndef XmNwrap
#define XmNwrap ((char*)&_XmStrings[19435])
#endif
#ifndef XmCWrap
#define XmCWrap ((char*)&_XmStrings[19440])
#endif
#ifndef XmNpositionMode
#define XmNpositionMode ((char*)&_XmStrings[19445])
#endif
#ifndef XmCPositionMode
#define XmCPositionMode ((char*)&_XmStrings[19458])
#endif
#ifndef XmRPositionMode
#define XmRPositionMode ((char*)&_XmStrings[19471])
#endif
#ifndef XmNprintOrientation
#define XmNprintOrientation ((char*)&_XmStrings[19484])
#endif
#ifndef XmCPrintOrientation
#define XmCPrintOrientation ((char*)&_XmStrings[19501])
#endif
#ifndef XmNprintOrientations
#define XmNprintOrientations ((char*)&_XmStrings[19518])
#endif
#ifndef XmCPrintOrientations
#define XmCPrintOrientations ((char*)&_XmStrings[19536])
#endif
#ifndef XmNprintResolution
#define XmNprintResolution ((char*)&_XmStrings[19554])
#endif
#ifndef XmCPrintResolution
#define XmCPrintResolution ((char*)&_XmStrings[19570])
#endif
#ifndef XmNprintResolutions
#define XmNprintResolutions ((char*)&_XmStrings[19586])
#endif
#ifndef XmCPrintResolutions
#define XmCPrintResolutions ((char*)&_XmStrings[19603])
#endif
#ifndef XmNdefaultPixmapResolution
#define XmNdefaultPixmapResolution ((char*)&_XmStrings[19620])
#endif
#ifndef XmCDefaultPixmapResolution
#define XmCDefaultPixmapResolution ((char*)&_XmStrings[19644])
#endif
#ifndef XmNstartJobCallback
#define XmNstartJobCallback ((char*)&_XmStrings[19668])
#endif
#ifndef XmNendJobCallback
#define XmNendJobCallback ((char*)&_XmStrings[19685])
#endif
#ifndef XmNpageSetupCallback
#define XmNpageSetupCallback ((char*)&_XmStrings[19700])
#endif
#ifndef XmNpdmNotificationCallback
#define XmNpdmNotificationCallback ((char*)&_XmStrings[19718])
#endif
#ifndef XmNminX
#define XmNminX ((char*)&_XmStrings[19742])
#endif
#ifndef XmNminY
#define XmNminY ((char*)&_XmStrings[19747])
#endif
#ifndef XmNmaxX
#define XmNmaxX ((char*)&_XmStrings[19752])
#endif
#ifndef XmNmaxY
#define XmNmaxY ((char*)&_XmStrings[19757])
#endif
#ifndef XmCMinX
#define XmCMinX ((char*)&_XmStrings[19762])
#endif
#ifndef XmCMinY
#define XmCMinY ((char*)&_XmStrings[19767])
#endif
#ifndef XmCMaxX
#define XmCMaxX ((char*)&_XmStrings[19772])
#endif
#ifndef XmCMaxY
#define XmCMaxY ((char*)&_XmStrings[19777])
#endif
#ifndef XmNpreeditStartCallback
#define XmNpreeditStartCallback ((char*)&_XmStrings[19782])
#endif
#ifndef XmNpreeditDoneCallback
#define XmNpreeditDoneCallback ((char*)&_XmStrings[19803])
#endif
#ifndef XmNpreeditDrawCallback
#define XmNpreeditDrawCallback ((char*)&_XmStrings[19823])
#endif
#ifndef XmNpreeditCaretCallback
#define XmNpreeditCaretCallback ((char*)&_XmStrings[19843])
#endif
#ifndef XmNverifyPreedit
#define XmNverifyPreedit ((char*)&_XmStrings[19864])
#endif
#ifndef XmCVerifyPreedit
#define XmCVerifyPreedit ((char*)&_XmStrings[19878])
#endif
#ifndef XmNenableMultiKeyBindings
#define XmNenableMultiKeyBindings ((char*)&_XmStrings[19892])
#endif
#ifndef XmCEnableMultiKeyBindings
#define XmCEnableMultiKeyBindings ((char*)&_XmStrings[19915])
#endif
#ifndef XmRButtonFontList
#define XmRButtonFontList ((char*)&_XmStrings[19938])
#endif
#ifndef XmRLabelFontList
#define XmRLabelFontList ((char*)&_XmStrings[19953])
#endif
#ifndef XmRTextFontList
#define XmRTextFontList ((char*)&_XmStrings[19967])
#endif
#ifndef XmSPIXEL_SET_PROP
#define XmSPIXEL_SET_PROP ((char*)&_XmStrings[19980])
#endif
#ifndef XmS50_foreground
#define XmS50_foreground ((char*)&_XmStrings[19994])
#endif
#ifndef XmSunspecified_pixmap
#define XmSunspecified_pixmap ((char*)&_XmStrings[20008])
#endif
#endif /* XMSTRINGDEFINES */

#ifdef __cplusplus
}  /* Close scope of 'extern "C"' declaration */
#endif

#include <X11/StringDefs.h>

#ifdef __cplusplus
extern "C" {
#endif

#define XmSTRING_DEFAULT_CHARSET	XmS
#define XmSTRING_ISO8859_1		"ISO8859-1"
#define XmFONTLIST_DEFAULT_TAG		XmSFONTLIST_DEFAULT_TAG_STRING
#define XmFONTLIST_DEFAULT_TAG_STRING	XmSXmFONTLIST_DEFAULT_TAG_STRING

#define XmVaCASCADEBUTTON		"cascadeButton"
#define XmVaCHECKBUTTON			"checkButton"
#define XmVaDOUBLE_SEPARATOR		"doubleSeparator"
#define XmVaPUSHBUTTON			"pushButton"
#define XmVaRADIOBUTTON			"radioButton"
#define XmVaSEPARATOR			"separator"
#define XmVaSINGLE_SEPARATOR		"singleSeparator"
#define XmVaTOGGLEBUTTON		"checkButton"

#ifndef XmVaTITLE
#define XmVaTITLE			XtNtitle
#endif

#ifndef XtCKeyboardFocusPolicy
#define XtCKeyboardFocusPolicy		XmCKeyboardFocusPolicy
#endif

#ifndef XtCShellUnitType
#define XtCShellUnitType		XmCShellUnitType
#endif

#ifndef XtNkeyboardFocusPolicy
#define XtNkeyboardFocusPolicy		XmNkeyboardFocusPolicy
#endif

#ifndef XtNshellUnitType
#define XtNshellUnitType		XmNshellUnitType
#endif

#ifndef XtRKeyboardFocusPolicy
#define XtRKeyboardFocusPolicy		XmRKeyboardFocusPolicy
#endif

#ifndef XmRPrimBottomShadowPixmap
#define XmRPrimBottomShadowPixmap       XmRBottomShadowPixmap
#endif

#ifndef XmRPrimHighlightPixmap
#define XmRPrimHighlightPixmap          XmRHighlightPixmap
#endif

#ifndef XmRPrimTopShadowPixmap
#define XmRPrimTopShadowPixmap          XmRTopShadowPixmap
#endif

#ifndef XmCAccelerators
#define XmCAccelerators			XtCAccelerators
#endif

#ifndef XmCAllowShellResize
#define XmCAllowShellResize		XtCAllowShellResize
#endif

#ifndef XmCArgc
#define XmCArgc				XtCArgc
#endif

#ifndef XmCArgv
#define XmCArgv				XtCArgv
#endif

#ifndef XmCBackground
#define XmCBackground			XtCBackground
#endif

#ifndef XmCBaseHeight
#define XmCBaseHeight			XtCBaseHeight
#endif

#ifndef XmCBaseHeight
#define XmCBaseHeight			XtCBaseHeight
#endif

#ifndef XmCBaseWidth
#define XmCBaseWidth			XtCBaseWidth
#endif

#ifndef XmCBaseWidth
#define XmCBaseWidth			XtCBaseWidth
#endif

#ifndef XmCBitmap
#define XmCBitmap			XtCBitmap
#endif

#ifndef XmCBoolean
#define XmCBoolean			XtCBoolean
#endif

#ifndef XmCBorderColor
#define XmCBorderColor			XtCBorderColor
#endif

#ifndef XmCBorderWidth
#define XmCBorderWidth			XtCBorderWidth
#endif

#ifndef XmCCallback
#define XmCCallback			XtCCallback
#endif

#ifndef XmCColor
#define XmCColor			XtCColor
#endif

#ifndef XmCColormap
#define XmCColormap			XtCColormap
#endif

#ifndef XmCCreatePopupChildProc
#define XmCCreatePopupChildProc		XtCCreatePopupChildProc
#endif

#ifndef XmCCursor
#define XmCCursor			XtCCursor
#endif

#ifndef XmCDepth
#define XmCDepth			XtCDepth
#endif

#ifndef XmCDimension
#define XmCDimension			XtRDimension
#endif

#ifndef XmCEditMode
#define XmCEditMode			XtREditMode
#endif

#ifndef XmCEditType
#define XmCEditType			XtCEditType
#endif

#ifndef XmCEventBindings
#define XmCEventBindings		XtCEventBindings
#endif

#ifndef XmCFile
#define XmCFile				XtCFile
#endif

#ifndef XmCFont
#define XmCFont				XtCFont
#endif

#ifndef XmCFontSet
#define XmCFontSet			XtCFontSet
#endif

#ifndef XmCForeground
#define XmCForeground			XtCForeground
#endif

#ifndef XmCFraction
#define XmCFraction			XtCFraction
#endif 

#ifndef XmCFunction
#define XmCFunction			XtCFunction
#endif 

#ifndef XmCGeometry
#define XmCGeometry			XtCGeometry
#endif 

#ifndef XmCHSpace
#define XmCHSpace			XtCHSpace
#endif 

#ifndef XmCHeight
#define XmCHeight			XtCHeight
#endif 

#ifndef XmCHeightInc
#define XmCHeightInc			XtCHeightInc
#endif 

#ifndef XmCIconMask
#define XmCIconMask			XtCIconMask
#endif 

#ifndef XmCIconName
#define XmCIconName			XtCIconName
#endif 

#ifndef XmCIconNameEncoding
#define XmCIconNameEncoding		XtCIconNameEncoding
#endif 

#ifndef XmCIconPixmap
#define XmCIconPixmap			XtCIconPixmap
#endif 

#ifndef XmCIconWindow
#define XmCIconWindow			XtCIconWindow
#endif 

#ifndef XmCIconX
#define XmCIconX			XtCIconX
#endif 

#ifndef XmCIconY
#define XmCIconY			XtCIconY
#endif 

#ifndef XmCIconic
#define XmCIconic			XtCIconic
#endif 

#ifndef XmCIndex
#define XmCIndex			XtCIndex
#endif 

#ifndef XmCInitialResourcesPersistent
#define XmCInitialResourcesPersistent	XtCInitialResourcesPersistent
#endif 

#ifndef XmCInitialState
#define XmCInitialState			XtCInitialState
#endif 

#ifndef XmCInput
#define XmCInput			XtCInput
#endif 

#ifndef XmCInsertPosition
#define XmCInsertPosition		XtCInsertPosition
#endif 

#ifndef XmCInterval
#define XmCInterval			XtCInterval
#endif 

#ifndef XmCJustify
#define XmCJustify			XtCJustify
#endif 

#ifndef XmCLabel
#define XmCLabel			XtCLabel
#endif 

#ifndef XmCLength
#define XmCLength			XtCLength
#endif 

#ifndef XmCMappedWhenManaged
#define XmCMappedWhenManaged		XtCMappedWhenManaged
#endif 

#ifndef XmCMargin
#define XmCMargin			XtCMargin
#endif 


#ifndef XmCMaxAspectX
#define XmCMaxAspectX			XtCMaxAspectX
#endif 


#ifndef XmCMaxAspectY
#define XmCMaxAspectY			XtCMaxAspectY
#endif 

#ifndef XmCMaxHeight
#define XmCMaxHeight			XtCMaxHeight
#endif 

#ifndef XmCMaxWidth
#define XmCMaxWidth			XtCMaxWidth
#endif

#ifndef XmCMenuEntry
#define XmCMenuEntry			XtCMenuEntry
#endif

#ifndef XmCMinAspectX
#define XmCMinAspectX			XtCMinAspectX
#endif

#ifndef XmCMinAspectY
#define XmCMinAspectY			XtCMinAspectY
#endif

#ifndef XmCMinHeight
#define XmCMinHeight			XtCMinHeight
#endif

#ifndef XmCMinWidth
#define XmCMinWidth			XtCMinWidth
#endif

#ifndef XmCNotify
#define XmCNotify			XtCNotify
#endif

#ifndef XmCOrientation
#define XmCOrientation			XtCOrientation
#endif

#ifndef XmCOverrideRedirect
#define XmCOverrideRedirect		XtCOverrideRedirect
#endif

#ifndef XmCParameter
#define XmCParameter			XtCParameter
#endif 

#ifndef XmCPixmap
#define XmCPixmap			XtCPixmap
#endif


#ifndef XmCPosition
#define XmCPosition			XtCPosition
#endif

#ifndef XmCReadOnly
#define XmCReadOnly			XtCReadOnly
#endif

#ifndef XmCResize
#define XmCResize			XtCResize
#endif

#ifndef XmCReverseVideo
#define XmCReverseVideo			XtCReverseVideo
#endif

#ifndef XmCSaveUnder
#define XmCSaveUnder			XtCSaveUnder
#endif

#ifndef XmCScreen
#define XmCScreen			XtCScreen
#endif

#ifndef XmCScrollDCursor
#define XmCScrollDCursor		XtCScrollDCursor
#endif

#ifndef XmCScrollHCursor
#define XmCScrollHCursor		XtCScrollHCursor
#endif

#ifndef XmCScrollLCursor
#define XmCScrollLCursor		XtCScrollLCursor
#endif

#ifndef XmCScrollProc
#define XmCScrollProc			XtCScrollProc
#endif

#ifndef XmCScrollRCursor
#define XmCScrollRCursor		XtCScrollRCursor
#endif

#ifndef XmCScrollUCursor
#define XmCScrollUCursor		XtCScrollUCursor
#endif

#ifndef XmCScrollVCursor
#define XmCScrollVCursor		XtCScrollVCursor
#endif

#ifndef XmCSelection
#define XmCSelection			XtCSelection
#endif

#ifndef XmCSelectionArray
#define XmCSelectionArray		XtCSelectionArray
#endif

#ifndef XmCSensitive
#define XmCSensitive			XtCSensitive
#endif

#ifndef XmCSpace
#define XmCSpace			XtCSpace
#endif

#ifndef XmCString
#define XmCString			XtCString
#endif

#ifndef XmCTextOptions
#define XmCTextOptions			XtCTextOptions
#endif

#ifndef XmCTextPosition
#define XmCTextPosition			XtCTextPosition
#endif

#ifndef XmCTextSink
#define XmCTextSink			XtCTextSink
#endif

#ifndef XmCTextSource
#define XmCTextSource			XtCTextSource
#endif

#ifndef XmCThickness
#define XmCThickness			XtCThickness
#endif

#ifndef XmCThumb
#define XmCThumb			XtCThumb
#endif

#ifndef XmCTitle
#define XmCTitle			XtCTitle
#endif

#ifndef XmCTitleEncoding
#define XmCTitleEncoding		XtCTitleEncoding
#endif

#ifndef XmCTransient
#define XmCTransient			XtCTransient
#endif

#ifndef XmCTransientFor
#define XmCTransientFor			XtCTransientFor
#endif

#ifndef XmCTranslations
#define XmCTranslations			XtCTranslations
#endif

#ifndef XmCVSpace
#define XmCVSpace			XtCVSpace
#endif


#ifndef XmCValue
#define XmCValue			XtCValue
#endif

#ifndef XmCVisual
#define XmCVisual			XtCVisual
#endif

#ifndef XmCWaitForWm
#define XmCWaitForWm			XtCWaitForWm
#endif

#ifndef XmCWidget
#define XmCWidget			XtRWidget
#endif

#ifndef XmCWidth
#define XmCWidth			XtCWidth
#endif

#ifndef XmCWidthInc
#define XmCWidthInc			XtCWidthInc
#endif

#ifndef XmCWinGravity
#define XmCWinGravity			XtCWinGravity
#endif

#ifndef XmCWindow
#define XmCWindow			XtCWindow
#endif

#ifndef XmCWindowGroup
#define XmCWindowGroup			XtCWindowGroup
#endif

#ifndef XmCWmTimeout
#define XmCWmTimeout			XtCWmTimeout
#endif

#ifndef XmCX
#define XmCX				XtCX
#endif

#ifndef XmCY
#define XmCY				XtCY
#endif

#ifndef XmNaccelerators
#define XmNaccelerators			XtNaccelerators
#endif

#ifndef XmNallowShellResize
#define XmNallowShellResize		XtNallowShellResize
#endif

#ifndef XmNancestorSensitive
#define XmNancestorSensitive		XtNancestorSensitive
#endif

#ifndef XmNargc
#define XmNargc				XtNargc
#endif

#ifndef XmNargv
#define XmNargv				XtNargv
#endif

#ifndef XmNbackground
#define XmNbackground			XtNbackground
#endif

#ifndef XmNbackgroundPixmap
#define XmNbackgroundPixmap		XtNbackgroundPixmap
#endif

#ifndef XmNbaseHeight
#define XmNbaseHeight			XtNbaseHeight
#endif

#ifndef XmNbaseHeight
#define XmNbaseHeight			XtNbaseHeight
#endif

#ifndef XmNbaseWidth
#define XmNbaseWidth			XtNbaseWidth
#endif

#ifndef XmNbaseWidth
#define XmNbaseWidth			XtNbaseWidth
#endif

#ifndef XmNbitmap
#define XmNbitmap			XtNbitmap
#endif

#ifndef XmNborder
#define XmNborder			XtNborder
#endif

#ifndef XmNborderColor
#define XmNborderColor			XtNborderColor
#endif

#ifndef XmNborderPixmap
#define XmNborderPixmap			XtNborderPixmap
#endif

#ifndef XmNborderWidth
#define XmNborderWidth			XtNborderWidth
#endif

#ifndef XmNcallback
#define XmNcallback			XtNcallback
#endif

#ifndef XmNchildren
#define XmNchildren			XtNchildren
#endif

#ifndef XmNcolormap
#define XmNcolormap			XtNcolormap
#endif

#ifndef XmNcreatePopupChildProc
#define XmNcreatePopupChildProc		XtNcreatePopupChildProc
#endif

#ifndef XmNdepth
#define XmNdepth			XtNdepth
#endif

#ifndef XmNdestroyCallback
#define XmNdestroyCallback		XtNdestroyCallback
#endif

#ifndef XmNeditType
#define XmNeditType			XtNeditType
#endif

#ifndef XmNfile
#define XmNfile				XtNfile
#endif

#ifndef XmNfont
#define XmNfont				XtNfont
#endif

#ifndef XmNfontSet
#define XmNfontSet		        XtNfontSet
#endif

#ifndef XmNforceBars
#define XmNforceBars			XtNforceBars
#endif

#ifndef XmNforeground
#define XmNforeground			XtNforeground
#endif

#ifndef XmNfunction
#define XmNfunction			XtNfunction
#endif

#ifndef XmNgeometry
#define XmNgeometry			XtNgeometry
#endif

#ifndef XmNheight
#define XmNheight			XtNheight
#endif

#ifndef XmNheightInc
#define XmNheightInc			XtNheightInc
#endif

#ifndef XmNhighlight
#define XmNhighlight			XtNhighlight
#endif

#ifndef XmNiconMask
#define XmNiconMask			XtNiconMask
#endif

#ifndef XmNiconName
#define XmNiconName			XtNiconName
#endif

#ifndef XmNiconNameEncoding
#define XmNiconNameEncoding		XtNiconNameEncoding
#endif

#ifndef XmNiconPixmap
#define XmNiconPixmap			XtNiconPixmap
#endif

#ifndef XmNiconWindow
#define XmNiconWindow			XtNiconWindow
#endif

#ifndef XmNiconX
#define XmNiconX			XtNiconX
#endif

#ifndef XmNiconY
#define XmNiconY			XtNiconY
#endif

#ifndef XmNiconic
#define XmNiconic			XtNiconic
#endif

#ifndef XmNindex
#define XmNindex			XtNindex
#endif

#ifndef XmNinitialResourcesPersistent
#define XmNinitialResourcesPersistent	XtNinitialResourcesPersistent
#endif

#ifndef XmNinitialState
#define XmNinitialState			XtNinitialState
#endif

#ifndef XmNinnerHeight
#define XmNinnerHeight			XtNinnerHeight
#endif

#ifndef XmNinnerWidth
#define XmNinnerWidth			XtNinnerWidth
#endif

#ifndef XmNinnerWindow
#define XmNinnerWindow			XtNinnerWindow
#endif

#ifndef XmNinput
#define XmNinput			XtNinput
#endif

#ifndef XmNinsertPosition
#define XmNinsertPosition		XtNinsertPosition
#endif

#ifndef XmNinternalHeight
#define XmNinternalHeight		XtNinternalHeight
#endif

#ifndef XmNinternalWidth
#define XmNinternalWidth		XtNinternalWidth
#endif

#ifndef XmNjumpProc
#define XmNjumpProc			XtNjumpProc
#endif

#ifndef XmNjustify
#define XmNjustify			XtNjustify
#endif

#ifndef XmNlength
#define XmNlength			XtNlength
#endif

#ifndef XmNlowerRight
#define XmNlowerRight			XtNlowerRight
#endif

#ifndef XmNmappedWhenManaged
#define XmNmappedWhenManaged		XtNmappedWhenManaged
#endif

#ifndef XmNmaxAspectX
#define XmNmaxAspectX			XtNmaxAspectX
#endif

#ifndef XmNmaxAspectY
#define XmNmaxAspectY			XtNmaxAspectY
#endif

#ifndef XmNmaxHeight
#define XmNmaxHeight			XtNmaxHeight
#endif

#ifndef XmNmaxWidth
#define XmNmaxWidth			XtNmaxWidth
#endif

#ifndef XmNmenuEntry
#define XmNmenuEntry			XtNmenuEntry
#endif

#ifndef XmNminAspectX
#define XmNminAspectX			XtNminAspectX
#endif

#ifndef XmNminAspectY
#define XmNminAspectY			XtNminAspectY
#endif

#ifndef XmNminHeight
#define XmNminHeight			XtNminHeight
#endif

#ifndef XmNminWidth
#define XmNminWidth			XtNminWidth
#endif

#ifndef XmNname
#define XmNname				XtNname
#endif

#ifndef XmNnotify
#define XmNnotify			XtNnotify
#endif

#ifndef XmNnumChildren
#define XmNnumChildren			XtNnumChildren
#endif

#ifndef XmNorientation
#define XmNorientation			XtNorientation
#endif

#ifndef XmNoverrideRedirect
#define XmNoverrideRedirect		XtNoverrideRedirect
#endif

#ifndef XmNparameter
#define XmNparameter			XtNparameter
#endif

#ifndef XmNpixmap
#define XmNpixmap			XtNpixmap
#endif

#ifndef XmNpopdownCallback
#define XmNpopdownCallback		XtNpopdownCallback
#endif

#ifndef XmNpopupCallback
#define XmNpopupCallback		XtNpopupCallback
#endif

#ifndef XmNresize
#define XmNresize			XtNresize
#endif

#ifndef XmNreverseVideo
#define XmNreverseVideo			XtNreverseVideo
#endif

#ifndef XmNsaveUnder
#define XmNsaveUnder			XtNsaveUnder
#endif

#ifndef XmNscreen
#define XmNscreen			XtNscreen
#endif

#ifndef XmNscrollDCursor
#define XmNscrollDCursor		XtNscrollDCursor
#endif

#ifndef XmNscrollHCursor
#define XmNscrollHCursor		XtNscrollHCursor
#endif

#ifndef XmNscrollLCursor
#define XmNscrollLCursor		XtNscrollLCursor
#endif

#ifndef XmNscrollProc
#define XmNscrollProc			XtNscrollProc
#endif

#ifndef XmNscrollRCursor
#define XmNscrollRCursor		XtNscrollRCursor
#endif

#ifndef XmNscrollUCursor
#define XmNscrollUCursor		XtNscrollUCursor
#endif

#ifndef XmNscrollVCursor
#define XmNscrollVCursor		XtNscrollVCursor
#endif

#ifndef XmNselection
#define XmNselection			XtNselection
#endif

#ifndef XmNselectionArray
#define XmNselectionArray		XtNselectionArray
#endif

#ifndef XmNsensitive
#define XmNsensitive			XtNsensitive
#endif

#ifndef XmNshown
#define XmNshown			XtNshown
#endif

#ifndef XmNspace
#define XmNspace			XtNspace
#endif

#ifndef XmNstring
#define XmNstring			XtNstring
#endif

#ifndef XmNtextOptions
#define XmNtextOptions			XtNtextOptions
#endif

#ifndef XmNtextSink
#define XmNtextSink			XtNtextSink
#endif

#ifndef XmNtextSource
#define XmNtextSource			XtNtextSource
#endif

#ifndef XmNthickness
#define XmNthickness			XtNthickness
#endif

#ifndef XmNthumb
#define XmNthumb			XtNthumb
#endif

#ifndef XmNthumbProc
#define XmNthumbProc			XtNthumbProc
#endif

#ifndef XmNtitle
#define XmNtitle			XtNtitle
#endif

#ifndef XmNtitleEncoding
#define XmNtitleEncoding		XtNtitleEncoding
#endif

#ifndef XmNtop
#define XmNtop				XtNtop
#endif

#ifndef XmNtransient
#define XmNtransient			XtNtransient
#endif

#ifndef XmNtransientFor
#define XmNtransientFor			XtNtransientFor
#endif

#ifndef XmNtransientFor
#define XmNtransientFor			XtNtransientFor
#endif

#ifndef XmNtranslations
#define XmNtranslations			XtNtranslations
#endif

#ifndef XmNupdate
#define XmNupdate			XtNupdate
#endif

#ifndef XmNuseBottom
#define XmNuseBottom			XtNuseBottom
#endif

#ifndef XmNuseRight
#define XmNuseRight			XtNuseRight
#endif

#ifndef XmNvalue
#define XmNvalue			XtNvalue
#endif

#ifndef XmNvisual
#define XmNvisual			XtNvisual
#endif

#ifndef XmNwaitForWm
#define XmNwaitForWm			XtNwaitForWm
#endif

#ifndef XmNwidth
#define XmNwidth			XtNwidth
#endif

#ifndef XmNwidthInc
#define XmNwidthInc			XtNwidthInc
#endif

#ifndef XmNwinGravity
#define XmNwinGravity			XtNwinGravity
#endif

#ifndef XmNwindow
#define XmNwindow			XtNwindow
#endif

#ifndef XmNwindowGroup
#define XmNwindowGroup			XtNwindowGroup
#endif

#ifndef XmNwmTimeout
#define XmNwmTimeout			XtNwmTimeout
#endif

#ifndef XmNx
#define XmNx				XtNx
#endif

#ifndef XmNy
#define XmNy				XtNy
#endif

#ifndef XmRAcceleratorTable
#define XmRAcceleratorTable		XtRAcceleratorTable
#endif

#ifndef XmRAtom
#define XmRAtom				XtRAtom
#endif

#ifndef XmRBitmap
#define XmRBitmap			XtRBitmap
#endif

#ifndef XmRBool
#define XmRBool				XtRBool
#endif

#ifndef XmRBoolean
#define XmRBoolean			XtRBoolean
#endif

#ifndef XmRCallProc
#define XmRCallProc			XtRCallProc
#endif

#ifndef XmRCallback
#define XmRCallback			XtRCallback
#endif

#ifndef XmRCardinal
#define XmRCardinal			XtRCardinal
#endif

#ifndef XmRColor
#define XmRColor			XtRColor
#endif

#ifndef XmRColormap
#define XmRColormap			XtRColormap
#endif

#ifndef XmRCursor
#define XmRCursor			XtRCursor
#endif

#ifndef XmRDimension
#define XmRDimension			XtRDimension
#endif

#ifndef XmRDisplay
#define XmRDisplay			XtRDisplay
#endif

#ifndef XmREditMode
#define XmREditMode			XtREditMode
#endif

#ifndef XmREnum
#define XmREnum			        XtREnum
#endif

#ifndef XmRFile
#define XmRFile				XtRFile
#endif

#ifndef XmRFloat
#define XmRFloat			XtRFloat
#endif

#ifndef XmRFont
#define XmRFont				XtRFont
#endif

#ifndef XmRFontSet
#define XmRFontSet		        XtRFontSet
#endif

#ifndef XmRFontStruct
#define XmRFontStruct			XtRFontStruct
#endif

#ifndef XmRFunction
#define XmRFunction			XtRFunction
#endif

#ifndef XmRGeometry
#define XmRGeometry			XtRGeometry
#endif

#ifndef XmRImmediate
#define XmRImmediate			XtRImmediate
#endif

#ifndef XmRInitialState
#define XmRInitialState		        XtRInitialState
#endif

#ifndef XmRInt
#define XmRInt				XtRInt
#endif

#ifndef XmRJustify
#define XmRJustify			XtRJustify
#endif

#ifndef XmRLongBoolean
#define XmRLongBoolean		        XtRLongBoolean
#endif

#ifndef XmROrientation
#define XmROrientation			XtROrientation
#endif

#ifndef XmRObject
#define XmRObject		        XtRObject
#endif

#ifndef XmRPixel
#define XmRPixel			XtRPixel
#endif

#ifndef XmRPixmap
#define XmRPixmap			XtRPixmap
#endif

#ifndef XmRPointer
#define XmRPointer			XtRPointer
#endif

#ifndef XmRPosition
#define XmRPosition			XtRPosition
#endif

#ifndef XmRScreen
#define XmRScreen	                XtRScreen
#endif

#ifndef XmRShort
#define XmRShort			XtRShort
#endif

#ifndef XmRString
#define XmRString			XtRString
#endif

#ifndef XmRStringArray
#define XmRStringArray		        XtRStringArray
#endif

#ifndef XmRStringTable
#define XmRStringTable			XtRStringTable
#endif

#ifndef XmRTextPosition
#define XmRTextPosition			XtCTextPosition
#endif

#ifndef XmRTranslationTable
#define XmRTranslationTable		XtRTranslationTable
#endif

#ifndef XmRUnsignedChar
#define XmRUnsignedChar			XtRUnsignedChar
#endif

#ifndef XmRVisual
#define XmRVisual		        XtRVisual
#endif

#ifndef XmRWidget
#define XmRWidget			XtRWidget
#endif

#ifndef XmRWidgetClass
#define XmRWidgetClass			XtRWidgetClass
#endif

#ifndef XmRWidgetList
#define XmRWidgetList			XtRWidgetList
#endif

#ifndef XmRWindow
#define XmRWindow			XtRWindow
#endif

#ifndef XmNtoolTipString
#define XmNtoolTipString 		"toolTipString"
#endif

#ifndef XmCToolTipString
#define XmCToolTipString 		"ToolTipString"
#endif

#ifndef XmNtoolTipPostDelay
#define XmNtoolTipPostDelay 		"toolTipPostDelay"
#endif

#ifndef XmCToolTipPostDelay
#define XmCToolTipPostDelay 		"ToolTipPostDelay"
#endif

#ifndef XmNtoolTipPostDuration
#define XmNtoolTipPostDuration 		"toolTipPostDuration"
#endif

#ifndef XmCToolTipPostDuration
#define XmCToolTipPostDuration 		"ToolTipPostDuration"
#endif

#ifndef XmNtoolTipEnable
#define XmNtoolTipEnable 		"toolTipEnable"
#endif

#ifndef XmCToolTipEnable
#define XmCToolTipEnable 		"ToolTipEnable"
#endif

#ifndef XmNanimate
#define XmNanimate			"animate"
#endif

#ifndef XmCAnimate
#define XmCAnimate			"Animate"
#endif

#ifdef __cplusplus
}  /* Close scope of 'extern "C"' declaration */
#endif

#endif /* _XmStrDefs_h_ */
